/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 47 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"

#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 51 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 54 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 57 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 60 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 63 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 66 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 751 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 69 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 74 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 77 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 89 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 101 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 104 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 107 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 110 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 113 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 116 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"


class sipQtCharts_QBarSet : public ::QtCharts::QBarSet
{
public:
    sipQtCharts_QBarSet(const ::QString, ::QObject*);
    virtual ~sipQtCharts_QBarSet();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QBarSet(const sipQtCharts_QBarSet &);
    sipQtCharts_QBarSet &operator = (const sipQtCharts_QBarSet &);

    char sipPyMethods[7];
};

sipQtCharts_QBarSet::sipQtCharts_QBarSet(const ::QString a0, ::QObject*a1): ::QtCharts::QBarSet(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QBarSet::~sipQtCharts_QBarSet()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QBarSet::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QBarSet);

    return ::QtCharts::QBarSet::metaObject();
}

int sipQtCharts_QBarSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QBarSet::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QBarSet, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QBarSet::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QBarSet, _clname, &sipCpp) ? sipCpp : ::QtCharts::QBarSet::qt_metacast(_clname));
}

bool sipQtCharts_QBarSet::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QBarSet::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QBarSet::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QBarSet::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QBarSet::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBarSet::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBarSet::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBarSet::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBarSet::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBarSet::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBarSet::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QBarSet::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBarSet::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QBarSet::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_append, "append(self, value: float)\n"
"append(self, values: Iterable[float])");

extern "C" {static PyObject *meth_QtCharts_QBarSet_append(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_append(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, &a0))
        {
            sipCpp->append(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QList< ::qreal>* a0;
        int a0State = 0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QList_2400, &a0, &a0State))
        {
            sipCpp->append(*a0);
            sipReleaseType(const_cast< ::QList< ::qreal> *>(a0), sipType_QList_2400, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_append, doc_QtCharts_QBarSet_append);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_insert, "insert(self, index: int, value: float)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_insert(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_insert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::qreal a1;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bid", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, &a0, &a1))
        {
            sipCpp->insert(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_insert, doc_QtCharts_QBarSet_insert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_replace, "replace(self, index: int, value: float)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_replace(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_replace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::qreal a1;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bid", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, &a0, &a1))
        {
            sipCpp->replace(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_replace, doc_QtCharts_QBarSet_replace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_count, "count(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QBarSet_count(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_count, doc_QtCharts_QBarSet_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_sum, "sum(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QBarSet_sum(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_sum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->sum();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_sum, doc_QtCharts_QBarSet_sum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_setPen, doc_QtCharts_QBarSet_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QBarSet_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_pen, doc_QtCharts_QBarSet_pen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_setBrush, doc_QtCharts_QBarSet_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QBarSet_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_brush, doc_QtCharts_QBarSet_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_setLabelBrush, "setLabelBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_setLabelBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_setLabelBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setLabelBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_setLabelBrush, doc_QtCharts_QBarSet_setLabelBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_labelBrush, "labelBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QBarSet_labelBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_labelBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->labelBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_labelBrush, doc_QtCharts_QBarSet_labelBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_setLabelFont, "setLabelFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_setLabelFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_setLabelFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setLabelFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_setLabelFont, doc_QtCharts_QBarSet_setLabelFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_labelFont, "labelFont(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QBarSet_labelFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_labelFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->labelFont());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_labelFont, doc_QtCharts_QBarSet_labelFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_setLabel, "setLabel(self, label: str|None)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_setLabel(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_setLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLabel(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_setLabel, doc_QtCharts_QBarSet_setLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_label, "label(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QBarSet_label(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_label(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->label());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_label, doc_QtCharts_QBarSet_label);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_remove, "remove(self, index: int, count: int = 1)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_remove(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_remove(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1 = 1;
        ::QtCharts::QBarSet *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_count,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|i", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, &a0, &a1))
        {
            sipCpp->remove(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_remove, doc_QtCharts_QBarSet_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_at, "at(self, index: int) -> float");

extern "C" {static PyObject *meth_QtCharts_QBarSet_at(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_at(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, &a0))
        {
            ::qreal sipRes;

            sipRes = sipCpp->at(a0);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_at, doc_QtCharts_QBarSet_at);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_color, "color(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QBarSet_color(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_color(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->color());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_color, doc_QtCharts_QBarSet_color);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_setColor, "setColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_setColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_setColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_setColor, doc_QtCharts_QBarSet_setColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_borderColor, "borderColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QBarSet_borderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_borderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->borderColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_borderColor, doc_QtCharts_QBarSet_borderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_setBorderColor, "setBorderColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_setBorderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_setBorderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setBorderColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_setBorderColor, doc_QtCharts_QBarSet_setBorderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_labelColor, "labelColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QBarSet_labelColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_labelColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->labelColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_labelColor, doc_QtCharts_QBarSet_labelColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBarSet_setLabelColor, "setLabelColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QBarSet_setLabelColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBarSet_setLabelColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QBarSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBarSet, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setLabelColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName_setLabelColor, doc_QtCharts_QBarSet_setLabelColor);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QtCharts_QBarSet___getitem__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QBarSet___getitem__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QtCharts::QBarSet *sipCpp = reinterpret_cast< ::QtCharts::QBarSet *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QBarSet));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            ::qreal sipRes = 0;
            int sipIsErr = 0;

#line 59 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
            SIP_SSIZE_T idx = sipConvertFromSequenceIndex(a0, sipCpp->count());
            
            if (idx < 0)
                sipIsErr = 1;
            else
                sipRes = sipCpp->operator[]((int)idx);
#line 974 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"

            if (sipIsErr)
                return 0;

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarSet, sipName___getitem__, SIP_NULLPTR);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QtCharts_QBarSet___len__(PyObject *);}
static Py_ssize_t slot_QtCharts_QBarSet___len__(PyObject *sipSelf)
{
    ::QtCharts::QBarSet *sipCpp = reinterpret_cast< ::QtCharts::QBarSet *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QBarSet));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 1004 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBarSet.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtCharts_QBarSet___lshift__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QBarSet___lshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBarSet* a0;
        ::qreal a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9d", sipType_QtCharts_QBarSet, &a0, &a1))
        {
            ::QtCharts::QBarSet*sipRes;

            sipRes = &(*a0 << a1);

            return sipConvertFromType(sipRes, sipType_QtCharts_QBarSet, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtChart, lshift_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QBarSet(void *, const sipTypeDef *);}
static void *cast_QtCharts_QBarSet(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QBarSet *sipCpp = reinterpret_cast< ::QtCharts::QBarSet *>(sipCppV);

    if (targetType == sipType_QtCharts_QBarSet)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QBarSet(void *, int);}
static void release_QtCharts_QBarSet(void *sipCppV, int)
{
    ::QtCharts::QBarSet *sipCpp = reinterpret_cast< ::QtCharts::QBarSet *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtCharts_QBarSet(sipSimpleWrapper *);}
static void dealloc_QtCharts_QBarSet(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QBarSet *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QBarSet(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QBarSet(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QBarSet(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QBarSet *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQtCharts_QBarSet(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QBarSet[] = {{10, 0, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QtCharts_QBarSet[] = {
    {(void *)slot_QtCharts_QBarSet___getitem__, getitem_slot},
    {(void *)slot_QtCharts_QBarSet___len__, len_slot},
    {(void *)slot_QtCharts_QBarSet___lshift__, lshift_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QtCharts_QBarSet[] = {
    {sipName_append, meth_QtCharts_QBarSet_append, METH_VARARGS, doc_QtCharts_QBarSet_append},
    {sipName_at, meth_QtCharts_QBarSet_at, METH_VARARGS, doc_QtCharts_QBarSet_at},
    {sipName_borderColor, meth_QtCharts_QBarSet_borderColor, METH_VARARGS, doc_QtCharts_QBarSet_borderColor},
    {sipName_brush, meth_QtCharts_QBarSet_brush, METH_VARARGS, doc_QtCharts_QBarSet_brush},
    {sipName_color, meth_QtCharts_QBarSet_color, METH_VARARGS, doc_QtCharts_QBarSet_color},
    {sipName_count, meth_QtCharts_QBarSet_count, METH_VARARGS, doc_QtCharts_QBarSet_count},
    {sipName_insert, meth_QtCharts_QBarSet_insert, METH_VARARGS, doc_QtCharts_QBarSet_insert},
    {sipName_label, meth_QtCharts_QBarSet_label, METH_VARARGS, doc_QtCharts_QBarSet_label},
    {sipName_labelBrush, meth_QtCharts_QBarSet_labelBrush, METH_VARARGS, doc_QtCharts_QBarSet_labelBrush},
    {sipName_labelColor, meth_QtCharts_QBarSet_labelColor, METH_VARARGS, doc_QtCharts_QBarSet_labelColor},
    {sipName_labelFont, meth_QtCharts_QBarSet_labelFont, METH_VARARGS, doc_QtCharts_QBarSet_labelFont},
    {sipName_pen, meth_QtCharts_QBarSet_pen, METH_VARARGS, doc_QtCharts_QBarSet_pen},
    {sipName_remove, SIP_MLMETH_CAST(meth_QtCharts_QBarSet_remove), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QBarSet_remove},
    {sipName_replace, meth_QtCharts_QBarSet_replace, METH_VARARGS, doc_QtCharts_QBarSet_replace},
    {sipName_setBorderColor, meth_QtCharts_QBarSet_setBorderColor, METH_VARARGS, doc_QtCharts_QBarSet_setBorderColor},
    {sipName_setBrush, meth_QtCharts_QBarSet_setBrush, METH_VARARGS, doc_QtCharts_QBarSet_setBrush},
    {sipName_setColor, meth_QtCharts_QBarSet_setColor, METH_VARARGS, doc_QtCharts_QBarSet_setColor},
    {sipName_setLabel, meth_QtCharts_QBarSet_setLabel, METH_VARARGS, doc_QtCharts_QBarSet_setLabel},
    {sipName_setLabelBrush, meth_QtCharts_QBarSet_setLabelBrush, METH_VARARGS, doc_QtCharts_QBarSet_setLabelBrush},
    {sipName_setLabelColor, meth_QtCharts_QBarSet_setLabelColor, METH_VARARGS, doc_QtCharts_QBarSet_setLabelColor},
    {sipName_setLabelFont, meth_QtCharts_QBarSet_setLabelFont, METH_VARARGS, doc_QtCharts_QBarSet_setLabelFont},
    {sipName_setPen, meth_QtCharts_QBarSet_setPen, METH_VARARGS, doc_QtCharts_QBarSet_setPen},
    {sipName_sum, meth_QtCharts_QBarSet_sum, METH_VARARGS, doc_QtCharts_QBarSet_sum}
};

PyDoc_STRVAR(doc_QtCharts_QBarSet, "\1QBarSet(name: str|None, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QBarSet[] = {
    {"doubleClicked(int)", "\1doubleClicked(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"released(int)", "\1released(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed(int)", "\1pressed(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelColorChanged(QColor)", "\1labelColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"borderColorChanged(QColor)", "\1borderColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorChanged(QColor)", "\1colorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(bool,int)", "\1hovered(self, status: bool, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked(int)", "\1clicked(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"valueChanged(int)", "\1valueChanged(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"valuesRemoved(int,int)", "\1valuesRemoved(self, index: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"valuesAdded(int,int)", "\1valuesAdded(self, index: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelFontChanged()", "\1labelFontChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelBrushChanged()", "\1labelBrushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelChanged()", "\1labelChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"brushChanged()", "\1brushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"penChanged()", "\1penChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QBarSet = {
    &::QtCharts::QBarSet::staticMetaObject,
    0,
    signals_QtCharts_QBarSet,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBarSet = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QBarSet,
        SIP_NULLPTR,
        &plugin_QtCharts_QBarSet,
    },
    {
        sipNameNr_QBarSet,
        {0, 0, 1},
        23, methods_QtCharts_QBarSet,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QBarSet,
    -1,
    -1,
    supers_QtCharts_QBarSet,
    slots_QtCharts_QBarSet,
    init_type_QtCharts_QBarSet,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QBarSet,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtCharts_QBarSet,
    cast_QtCharts_QBarSet,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QtCharts::QBarSet),
};
