/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvbarmodelmapper.sip"
#include <qvbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvboxplotmodelmapper.sip"
#include <qvboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvcandlestickmodelmapper.sip"
#include <qvcandlestickmodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvpiemodelmapper.sip"
#include <qvpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvxymodelmapper.sip"
#include <qvxymodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qxylegendmarker.sip"
#include <qxylegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qxyseries.sip"
#include <qxyseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qxyseries.sip"
#include <qxyseries.h>
#line 125 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 129 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 132 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 98 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 135 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 138 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 141 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 144 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 147 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 150 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 153 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 158 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 197 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 206 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 211 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 214 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 217 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 220 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 223 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 226 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 229 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 232 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 235 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 238 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 241 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 244 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 247 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 250 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 253 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 256 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"


PyDoc_STRVAR(doc_QtCharts_QXYSeries_append, "append(self, x: float, y: float)\n"
"append(self, point: QPointF|QPoint)\n"
"append(self, points: Iterable[QPointF|QPoint])");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_append(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_append(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::qreal a1;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0, &a1))
        {
            sipCpp->append(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->append(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const QList< ::QPointF>* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QList_0100QPointF, &a0, &a0State))
        {
            sipCpp->append(*a0);
            sipReleaseType(const_cast<QList< ::QPointF> *>(a0), sipType_QList_0100QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_append, doc_QtCharts_QXYSeries_append);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_replace, "replace(self, oldX: float, oldY: float, newX: float, newY: float)\n"
"replace(self, oldPoint: QPointF|QPoint, newPoint: QPointF|QPoint)\n"
"replace(self, points: Iterable[QPointF|QPoint])\n"
"replace(self, index: int, newX: float, newY: float)\n"
"replace(self, index: int, newPoint: QPointF|QPoint)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_replace(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_replace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::qreal a1;
        ::qreal a2;
        ::qreal a3;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->replace(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QPointF* a0;
        int a0State = 0;
        const ::QPointF* a1;
        int a1State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QPointF, &a0, &a0State, sipType_QPointF, &a1, &a1State))
        {
            sipCpp->replace(*a0, *a1);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);
            sipReleaseType(const_cast< ::QPointF *>(a1), sipType_QPointF, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        QList< ::QPointF>* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QList_0100QPointF, &a0, &a0State))
        {
            sipCpp->replace(*a0);
            sipReleaseType(a0, sipType_QList_0100QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        ::qreal a1;
        ::qreal a2;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bidd", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->replace(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const ::QPointF* a1;
        int a1State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0, sipType_QPointF, &a1, &a1State))
        {
            sipCpp->replace(a0, *a1);
            sipReleaseType(const_cast< ::QPointF *>(a1), sipType_QPointF, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_replace, doc_QtCharts_QXYSeries_replace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_remove, "remove(self, x: float, y: float)\n"
"remove(self, point: QPointF|QPoint)\n"
"remove(self, index: int)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_remove(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_remove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::qreal a1;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0, &a1))
        {
            sipCpp->remove(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->remove(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0))
        {
            sipCpp->remove(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_remove, doc_QtCharts_QXYSeries_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_insert, "insert(self, index: int, point: QPointF|QPoint)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_insert(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_insert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QPointF* a1;
        int a1State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0, sipType_QPointF, &a1, &a1State))
        {
            sipCpp->insert(a0, *a1);
            sipReleaseType(const_cast< ::QPointF *>(a1), sipType_QPointF, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_insert, doc_QtCharts_QXYSeries_insert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_clear, "clear(self)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_clear(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_clear, doc_QtCharts_QXYSeries_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_count, "count(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_count(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_count, doc_QtCharts_QXYSeries_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_points, "points(self) -> list[QPointF]");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_points(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_points(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            QList< ::QPointF>*sipRes;

            sipRes = new QList< ::QPointF>(sipCpp->points());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_points, doc_QtCharts_QXYSeries_points);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QtCharts::QXYSeries::setPen(*a0) : sipCpp->setPen(*a0));
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setPen, doc_QtCharts_QXYSeries_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_pen, doc_QtCharts_QXYSeries_pen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QtCharts::QXYSeries::setBrush(*a0) : sipCpp->setBrush(*a0));
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setBrush, doc_QtCharts_QXYSeries_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_brush, doc_QtCharts_QXYSeries_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setColor, "setColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QtCharts::QXYSeries::setColor(*a0) : sipCpp->setColor(*a0));
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setColor, doc_QtCharts_QXYSeries_setColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_color, "color(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_color(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_color(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor((sipSelfWasArg ? sipCpp->::QtCharts::QXYSeries::color() : sipCpp->color()));

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_color, doc_QtCharts_QXYSeries_color);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setPointsVisible, "setPointsVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setPointsVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setPointsVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QXYSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0))
        {
            sipCpp->setPointsVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setPointsVisible, doc_QtCharts_QXYSeries_setPointsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_pointsVisible, "pointsVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_pointsVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_pointsVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->pointsVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_pointsVisible, doc_QtCharts_QXYSeries_pointsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_at, "at(self, index: int) -> QPointF");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_at(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_at(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->at(a0));

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_at, doc_QtCharts_QXYSeries_at);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setPointLabelsFormat, "setPointLabelsFormat(self, format: str|None)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setPointLabelsFormat(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setPointLabelsFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPointLabelsFormat(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setPointLabelsFormat, doc_QtCharts_QXYSeries_setPointLabelsFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_pointLabelsFormat, "pointLabelsFormat(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_pointLabelsFormat(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_pointLabelsFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->pointLabelsFormat());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_pointLabelsFormat, doc_QtCharts_QXYSeries_pointLabelsFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setPointLabelsVisible, "setPointLabelsVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setPointLabelsVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setPointLabelsVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QXYSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0))
        {
            sipCpp->setPointLabelsVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setPointLabelsVisible, doc_QtCharts_QXYSeries_setPointLabelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_pointLabelsVisible, "pointLabelsVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_pointLabelsVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_pointLabelsVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->pointLabelsVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_pointLabelsVisible, doc_QtCharts_QXYSeries_pointLabelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setPointLabelsFont, "setPointLabelsFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setPointLabelsFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setPointLabelsFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setPointLabelsFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setPointLabelsFont, doc_QtCharts_QXYSeries_setPointLabelsFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_pointLabelsFont, "pointLabelsFont(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_pointLabelsFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_pointLabelsFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->pointLabelsFont());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_pointLabelsFont, doc_QtCharts_QXYSeries_pointLabelsFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setPointLabelsColor, "setPointLabelsColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setPointLabelsColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setPointLabelsColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setPointLabelsColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setPointLabelsColor, doc_QtCharts_QXYSeries_setPointLabelsColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_pointLabelsColor, "pointLabelsColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_pointLabelsColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_pointLabelsColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->pointLabelsColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_pointLabelsColor, doc_QtCharts_QXYSeries_pointLabelsColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_removePoints, "removePoints(self, index: int, count: int)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_removePoints(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_removePoints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0, &a1))
        {
            sipCpp->removePoints(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_removePoints, doc_QtCharts_QXYSeries_removePoints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_pointsVector, "pointsVector(self) -> list[QPointF]");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_pointsVector(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_pointsVector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            QVector< ::QPointF>*sipRes;

            sipRes = new QVector< ::QPointF>(sipCpp->pointsVector());

            return sipConvertFromNewType(sipRes, sipType_QVector_0100QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_pointsVector, doc_QtCharts_QXYSeries_pointsVector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_setPointLabelsClipping, "setPointLabelsClipping(self, enable: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_setPointLabelsClipping(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_setPointLabelsClipping(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QXYSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_enable,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp, &a0))
        {
            sipCpp->setPointLabelsClipping(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_setPointLabelsClipping, doc_QtCharts_QXYSeries_setPointLabelsClipping);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QXYSeries_pointLabelsClipping, "pointLabelsClipping(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QXYSeries_pointLabelsClipping(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QXYSeries_pointLabelsClipping(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QXYSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QXYSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->pointLabelsClipping();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXYSeries, sipName_pointLabelsClipping, doc_QtCharts_QXYSeries_pointLabelsClipping);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QtCharts_QXYSeries___lshift__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QXYSeries___lshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QXYSeries* a0;
        const ::QPointF* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QtCharts_QXYSeries, &a0, sipType_QPointF, &a1, &a1State))
        {
            ::QtCharts::QXYSeries*sipRes;

            sipRes = &(*a0 << *a1);
            sipReleaseType(const_cast< ::QPointF *>(a1), sipType_QPointF, a1State);

            return sipConvertFromType(sipRes, sipType_QtCharts_QXYSeries, SIP_NULLPTR);
        }
    }

    {
        ::QtCharts::QXYSeries* a0;
        const QList< ::QPointF>* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QtCharts_QXYSeries, &a0, sipType_QList_0100QPointF, &a1, &a1State))
        {
            ::QtCharts::QXYSeries*sipRes;

            sipRes = &(*a0 << *a1);
            sipReleaseType(const_cast<QList< ::QPointF> *>(a1), sipType_QList_0100QPointF, a1State);

            return sipConvertFromType(sipRes, sipType_QtCharts_QXYSeries, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtChart, lshift_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static Py_ssize_t slot_QtCharts_QXYSeries___len__(PyObject *);}
static Py_ssize_t slot_QtCharts_QXYSeries___len__(PyObject *sipSelf)
{
    ::QtCharts::QXYSeries *sipCpp = reinterpret_cast< ::QtCharts::QXYSeries *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QXYSeries));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 1213 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQXYSeries.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QXYSeries(void *, const sipTypeDef *);}
static void *cast_QtCharts_QXYSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QXYSeries *sipCpp = reinterpret_cast< ::QtCharts::QXYSeries *>(sipCppV);

    if (targetType == sipType_QtCharts_QXYSeries)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtCharts_QAbstractSeries)->ctd_cast(static_cast< ::QtCharts::QAbstractSeries *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QXYSeries(void *, int);}
static void release_QtCharts_QXYSeries(void *sipCppV, int)
{
    ::QtCharts::QXYSeries *sipCpp = reinterpret_cast< ::QtCharts::QXYSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtCharts_QXYSeries(sipSimpleWrapper *);}
static void dealloc_QtCharts_QXYSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QXYSeries(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QXYSeries[] = {{13, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QtCharts_QXYSeries[] = {
    {(void *)slot_QtCharts_QXYSeries___lshift__, lshift_slot},
    {(void *)slot_QtCharts_QXYSeries___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QtCharts_QXYSeries[] = {
    {sipName_append, meth_QtCharts_QXYSeries_append, METH_VARARGS, doc_QtCharts_QXYSeries_append},
    {sipName_at, meth_QtCharts_QXYSeries_at, METH_VARARGS, doc_QtCharts_QXYSeries_at},
    {sipName_brush, meth_QtCharts_QXYSeries_brush, METH_VARARGS, doc_QtCharts_QXYSeries_brush},
    {sipName_clear, meth_QtCharts_QXYSeries_clear, METH_VARARGS, doc_QtCharts_QXYSeries_clear},
    {sipName_color, meth_QtCharts_QXYSeries_color, METH_VARARGS, doc_QtCharts_QXYSeries_color},
    {sipName_count, meth_QtCharts_QXYSeries_count, METH_VARARGS, doc_QtCharts_QXYSeries_count},
    {sipName_insert, meth_QtCharts_QXYSeries_insert, METH_VARARGS, doc_QtCharts_QXYSeries_insert},
    {sipName_pen, meth_QtCharts_QXYSeries_pen, METH_VARARGS, doc_QtCharts_QXYSeries_pen},
    {sipName_pointLabelsClipping, meth_QtCharts_QXYSeries_pointLabelsClipping, METH_VARARGS, doc_QtCharts_QXYSeries_pointLabelsClipping},
    {sipName_pointLabelsColor, meth_QtCharts_QXYSeries_pointLabelsColor, METH_VARARGS, doc_QtCharts_QXYSeries_pointLabelsColor},
    {sipName_pointLabelsFont, meth_QtCharts_QXYSeries_pointLabelsFont, METH_VARARGS, doc_QtCharts_QXYSeries_pointLabelsFont},
    {sipName_pointLabelsFormat, meth_QtCharts_QXYSeries_pointLabelsFormat, METH_VARARGS, doc_QtCharts_QXYSeries_pointLabelsFormat},
    {sipName_pointLabelsVisible, meth_QtCharts_QXYSeries_pointLabelsVisible, METH_VARARGS, doc_QtCharts_QXYSeries_pointLabelsVisible},
    {sipName_points, meth_QtCharts_QXYSeries_points, METH_VARARGS, doc_QtCharts_QXYSeries_points},
    {sipName_pointsVector, meth_QtCharts_QXYSeries_pointsVector, METH_VARARGS, doc_QtCharts_QXYSeries_pointsVector},
    {sipName_pointsVisible, meth_QtCharts_QXYSeries_pointsVisible, METH_VARARGS, doc_QtCharts_QXYSeries_pointsVisible},
    {sipName_remove, meth_QtCharts_QXYSeries_remove, METH_VARARGS, doc_QtCharts_QXYSeries_remove},
    {sipName_removePoints, meth_QtCharts_QXYSeries_removePoints, METH_VARARGS, doc_QtCharts_QXYSeries_removePoints},
    {sipName_replace, meth_QtCharts_QXYSeries_replace, METH_VARARGS, doc_QtCharts_QXYSeries_replace},
    {sipName_setBrush, meth_QtCharts_QXYSeries_setBrush, METH_VARARGS, doc_QtCharts_QXYSeries_setBrush},
    {sipName_setColor, meth_QtCharts_QXYSeries_setColor, METH_VARARGS, doc_QtCharts_QXYSeries_setColor},
    {sipName_setPen, meth_QtCharts_QXYSeries_setPen, METH_VARARGS, doc_QtCharts_QXYSeries_setPen},
    {sipName_setPointLabelsClipping, SIP_MLMETH_CAST(meth_QtCharts_QXYSeries_setPointLabelsClipping), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QXYSeries_setPointLabelsClipping},
    {sipName_setPointLabelsColor, meth_QtCharts_QXYSeries_setPointLabelsColor, METH_VARARGS, doc_QtCharts_QXYSeries_setPointLabelsColor},
    {sipName_setPointLabelsFont, meth_QtCharts_QXYSeries_setPointLabelsFont, METH_VARARGS, doc_QtCharts_QXYSeries_setPointLabelsFont},
    {sipName_setPointLabelsFormat, meth_QtCharts_QXYSeries_setPointLabelsFormat, METH_VARARGS, doc_QtCharts_QXYSeries_setPointLabelsFormat},
    {sipName_setPointLabelsVisible, SIP_MLMETH_CAST(meth_QtCharts_QXYSeries_setPointLabelsVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QXYSeries_setPointLabelsVisible},
    {sipName_setPointsVisible, SIP_MLMETH_CAST(meth_QtCharts_QXYSeries_setPointsVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QXYSeries_setPointsVisible}
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QXYSeries[] = {
    {"penChanged(QPen)", "\1penChanged(self, pen: QPen|QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointsRemoved(int,int)", "\1pointsRemoved(self, index: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsClippingChanged(bool)", "\1pointLabelsClippingChanged(self, clipping: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"doubleClicked(QPointF)", "\1doubleClicked(self, point: QPointF|QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"released(QPointF)", "\1released(self, point: QPointF|QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed(QPointF)", "\1pressed(self, point: QPointF|QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsColorChanged(QColor)", "\1pointLabelsColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsFontChanged(QFont)", "\1pointLabelsFontChanged(self, font: QFont)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsVisibilityChanged(bool)", "\1pointLabelsVisibilityChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsFormatChanged(QString)", "\1pointLabelsFormatChanged(self, format: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(QPointF,bool)", "\1hovered(self, point: QPointF|QPoint, state: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointsReplaced()", "\1pointsReplaced(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointAdded(int)", "\1pointAdded(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointRemoved(int)", "\1pointRemoved(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointReplaced(int)", "\1pointReplaced(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorChanged(QColor)", "\1colorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked(QPointF)", "\1clicked(self, point: QPointF|QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QXYSeries = {
    &::QtCharts::QXYSeries::staticMetaObject,
    0,
    signals_QtCharts_QXYSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QXYSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QXYSeries,
        SIP_NULLPTR,
        &plugin_QtCharts_QXYSeries,
    },
    {
        sipNameNr_QXYSeries,
        {0, 0, 1},
        28, methods_QtCharts_QXYSeries,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtCharts_QXYSeries,
    slots_QtCharts_QXYSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QXYSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtCharts_QXYSeries,
    cast_QtCharts_QXYSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
