/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 31 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 35 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 38 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 41 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 44 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 47 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 50 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 53 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 61 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 64 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 67 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 70 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 73 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 76 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 79 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 82 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 85 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 88 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 91 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 94 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 97 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 100 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractAxis.cpp"


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_type, "type(self) -> QAbstractAxis.AxisType");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_type(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QtCharts::QAbstractAxis::AxisType sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractAxis, sipName_type);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QAbstractAxis_AxisType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_type, doc_QtCharts_QAbstractAxis_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_isVisible, "isVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_isVisible, doc_QtCharts_QAbstractAxis_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setVisible, "setVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setVisible, doc_QtCharts_QAbstractAxis_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_isLineVisible, "isLineVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_isLineVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_isLineVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLineVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_isLineVisible, doc_QtCharts_QAbstractAxis_isLineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLineVisible, "setLineVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLineVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLineVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setLineVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLineVisible, doc_QtCharts_QAbstractAxis_setLineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLinePen, "setLinePen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLinePen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLinePen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setLinePen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLinePen, doc_QtCharts_QAbstractAxis_setLinePen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_linePen, "linePen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_linePen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_linePen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->linePen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_linePen, doc_QtCharts_QAbstractAxis_linePen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLinePenColor, "setLinePenColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLinePenColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLinePenColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setLinePenColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLinePenColor, doc_QtCharts_QAbstractAxis_setLinePenColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_linePenColor, "linePenColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_linePenColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_linePenColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->linePenColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_linePenColor, doc_QtCharts_QAbstractAxis_linePenColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_isGridLineVisible, "isGridLineVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_isGridLineVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_isGridLineVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isGridLineVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_isGridLineVisible, doc_QtCharts_QAbstractAxis_isGridLineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setGridLineVisible, "setGridLineVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setGridLineVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setGridLineVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setGridLineVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setGridLineVisible, doc_QtCharts_QAbstractAxis_setGridLineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setGridLinePen, "setGridLinePen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setGridLinePen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setGridLinePen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setGridLinePen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setGridLinePen, doc_QtCharts_QAbstractAxis_setGridLinePen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_gridLinePen, "gridLinePen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_gridLinePen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_gridLinePen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->gridLinePen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_gridLinePen, doc_QtCharts_QAbstractAxis_gridLinePen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_labelsVisible, "labelsVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_labelsVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_labelsVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->labelsVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_labelsVisible, doc_QtCharts_QAbstractAxis_labelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLabelsVisible, "setLabelsVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLabelsVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLabelsVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setLabelsVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLabelsVisible, doc_QtCharts_QAbstractAxis_setLabelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLabelsBrush, "setLabelsBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLabelsBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLabelsBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setLabelsBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLabelsBrush, doc_QtCharts_QAbstractAxis_setLabelsBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_labelsBrush, "labelsBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_labelsBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_labelsBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->labelsBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_labelsBrush, doc_QtCharts_QAbstractAxis_labelsBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLabelsFont, "setLabelsFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLabelsFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLabelsFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setLabelsFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLabelsFont, doc_QtCharts_QAbstractAxis_setLabelsFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_labelsFont, "labelsFont(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_labelsFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_labelsFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->labelsFont());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_labelsFont, doc_QtCharts_QAbstractAxis_labelsFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLabelsAngle, "setLabelsAngle(self, angle: int)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLabelsAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLabelsAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setLabelsAngle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLabelsAngle, doc_QtCharts_QAbstractAxis_setLabelsAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_labelsAngle, "labelsAngle(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_labelsAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_labelsAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->labelsAngle();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_labelsAngle, doc_QtCharts_QAbstractAxis_labelsAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLabelsColor, "setLabelsColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLabelsColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLabelsColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setLabelsColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLabelsColor, doc_QtCharts_QAbstractAxis_setLabelsColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_labelsColor, "labelsColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_labelsColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_labelsColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->labelsColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_labelsColor, doc_QtCharts_QAbstractAxis_labelsColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_shadesVisible, "shadesVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_shadesVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_shadesVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->shadesVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_shadesVisible, doc_QtCharts_QAbstractAxis_shadesVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setShadesVisible, "setShadesVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setShadesVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setShadesVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setShadesVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setShadesVisible, doc_QtCharts_QAbstractAxis_setShadesVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setShadesPen, "setShadesPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setShadesPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setShadesPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setShadesPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setShadesPen, doc_QtCharts_QAbstractAxis_setShadesPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_shadesPen, "shadesPen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_shadesPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_shadesPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->shadesPen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_shadesPen, doc_QtCharts_QAbstractAxis_shadesPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setShadesBrush, "setShadesBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setShadesBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setShadesBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setShadesBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setShadesBrush, doc_QtCharts_QAbstractAxis_setShadesBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_shadesBrush, "shadesBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_shadesBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_shadesBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->shadesBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_shadesBrush, doc_QtCharts_QAbstractAxis_shadesBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setShadesColor, "setShadesColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setShadesColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setShadesColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setShadesColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setShadesColor, doc_QtCharts_QAbstractAxis_setShadesColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_shadesColor, "shadesColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_shadesColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_shadesColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->shadesColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_shadesColor, doc_QtCharts_QAbstractAxis_shadesColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setShadesBorderColor, "setShadesBorderColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setShadesBorderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setShadesBorderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setShadesBorderColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setShadesBorderColor, doc_QtCharts_QAbstractAxis_setShadesBorderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_shadesBorderColor, "shadesBorderColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_shadesBorderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_shadesBorderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->shadesBorderColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_shadesBorderColor, doc_QtCharts_QAbstractAxis_shadesBorderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setMin, "setMin(self, min: Any)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setMin(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setMin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            sipCpp->setMin(*a0);
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setMin, doc_QtCharts_QAbstractAxis_setMin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setMax, "setMax(self, max: Any)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setMax(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setMax(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            sipCpp->setMax(*a0);
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setMax, doc_QtCharts_QAbstractAxis_setMax);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setRange, "setRange(self, min: Any, max: Any)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setRange(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariant* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QVariant, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setRange(*a0, *a1);
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setRange, doc_QtCharts_QAbstractAxis_setRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_show, "show(self)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_show(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_show(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            sipCpp->show();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_show, doc_QtCharts_QAbstractAxis_show);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_hide, "hide(self)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_hide(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_hide(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            sipCpp->hide();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_hide, doc_QtCharts_QAbstractAxis_hide);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_orientation, "orientation(self) -> Qt.Orientation");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_orientation(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_orientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::Qt::Orientation sipRes;

            sipRes = sipCpp->orientation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_Orientation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_orientation, doc_QtCharts_QAbstractAxis_orientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_isTitleVisible, "isTitleVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_isTitleVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_isTitleVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isTitleVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_isTitleVisible, doc_QtCharts_QAbstractAxis_isTitleVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setTitleVisible, "setTitleVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setTitleVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setTitleVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setTitleVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setTitleVisible, doc_QtCharts_QAbstractAxis_setTitleVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setTitleBrush, "setTitleBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setTitleBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setTitleBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setTitleBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setTitleBrush, doc_QtCharts_QAbstractAxis_setTitleBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_titleBrush, "titleBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_titleBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_titleBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->titleBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_titleBrush, doc_QtCharts_QAbstractAxis_titleBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setTitleFont, "setTitleFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setTitleFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setTitleFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setTitleFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setTitleFont, doc_QtCharts_QAbstractAxis_setTitleFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_titleFont, "titleFont(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_titleFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_titleFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->titleFont());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_titleFont, doc_QtCharts_QAbstractAxis_titleFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setTitleText, "setTitleText(self, title: str|None)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setTitleText(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setTitleText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTitleText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setTitleText, doc_QtCharts_QAbstractAxis_setTitleText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_titleText, "titleText(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_titleText(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_titleText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->titleText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_titleText, doc_QtCharts_QAbstractAxis_titleText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_alignment, "alignment(self) -> Qt.Alignment");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_alignment(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_alignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::Qt::Alignment*sipRes;

            sipRes = new ::Qt::Alignment(sipCpp->alignment());

            return sipConvertFromNewType(sipRes, sipType_Qt_Alignment, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_alignment, doc_QtCharts_QAbstractAxis_alignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_isMinorGridLineVisible, "isMinorGridLineVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_isMinorGridLineVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_isMinorGridLineVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMinorGridLineVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_isMinorGridLineVisible, doc_QtCharts_QAbstractAxis_isMinorGridLineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setMinorGridLineVisible, "setMinorGridLineVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setMinorGridLineVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setMinorGridLineVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setMinorGridLineVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setMinorGridLineVisible, doc_QtCharts_QAbstractAxis_setMinorGridLineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setMinorGridLinePen, "setMinorGridLinePen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setMinorGridLinePen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setMinorGridLinePen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setMinorGridLinePen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setMinorGridLinePen, doc_QtCharts_QAbstractAxis_setMinorGridLinePen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_minorGridLinePen, "minorGridLinePen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_minorGridLinePen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_minorGridLinePen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->minorGridLinePen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_minorGridLinePen, doc_QtCharts_QAbstractAxis_minorGridLinePen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setGridLineColor, "setGridLineColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setGridLineColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setGridLineColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setGridLineColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setGridLineColor, doc_QtCharts_QAbstractAxis_setGridLineColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_gridLineColor, "gridLineColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_gridLineColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_gridLineColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->gridLineColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_gridLineColor, doc_QtCharts_QAbstractAxis_gridLineColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setMinorGridLineColor, "setMinorGridLineColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setMinorGridLineColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setMinorGridLineColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setMinorGridLineColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setMinorGridLineColor, doc_QtCharts_QAbstractAxis_setMinorGridLineColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_minorGridLineColor, "minorGridLineColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_minorGridLineColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_minorGridLineColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->minorGridLineColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_minorGridLineColor, doc_QtCharts_QAbstractAxis_minorGridLineColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setReverse, "setReverse(self, reverse: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setReverse(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setReverse(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_reverse,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setReverse(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setReverse, doc_QtCharts_QAbstractAxis_setReverse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_isReverse, "isReverse(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_isReverse(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_isReverse(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReverse();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_isReverse, doc_QtCharts_QAbstractAxis_isReverse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_setLabelsEditable, "setLabelsEditable(self, editable: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_setLabelsEditable(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_setLabelsEditable(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractAxis *sipCpp;

        static const char *sipKwdList[] = {
            sipName_editable,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp, &a0))
        {
            sipCpp->setLabelsEditable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_setLabelsEditable, doc_QtCharts_QAbstractAxis_setLabelsEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractAxis_labelsEditable, "labelsEditable(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractAxis_labelsEditable(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractAxis_labelsEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->labelsEditable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxis, sipName_labelsEditable, doc_QtCharts_QAbstractAxis_labelsEditable);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QAbstractAxis(void *, const sipTypeDef *);}
static void *cast_QtCharts_QAbstractAxis(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QAbstractAxis *sipCpp = reinterpret_cast< ::QtCharts::QAbstractAxis *>(sipCppV);

    if (targetType == sipType_QtCharts_QAbstractAxis)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QAbstractAxis(void *, int);}
static void release_QtCharts_QAbstractAxis(void *sipCppV, int)
{
    ::QtCharts::QAbstractAxis *sipCpp = reinterpret_cast< ::QtCharts::QAbstractAxis *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtCharts_QAbstractAxis(sipSimpleWrapper *);}
static void dealloc_QtCharts_QAbstractAxis(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QAbstractAxis(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QAbstractAxis[] = {{10, 0, 1}};


static PyMethodDef methods_QtCharts_QAbstractAxis[] = {
    {sipName_alignment, meth_QtCharts_QAbstractAxis_alignment, METH_VARARGS, doc_QtCharts_QAbstractAxis_alignment},
    {sipName_gridLineColor, meth_QtCharts_QAbstractAxis_gridLineColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_gridLineColor},
    {sipName_gridLinePen, meth_QtCharts_QAbstractAxis_gridLinePen, METH_VARARGS, doc_QtCharts_QAbstractAxis_gridLinePen},
    {sipName_hide, meth_QtCharts_QAbstractAxis_hide, METH_VARARGS, doc_QtCharts_QAbstractAxis_hide},
    {sipName_isGridLineVisible, meth_QtCharts_QAbstractAxis_isGridLineVisible, METH_VARARGS, doc_QtCharts_QAbstractAxis_isGridLineVisible},
    {sipName_isLineVisible, meth_QtCharts_QAbstractAxis_isLineVisible, METH_VARARGS, doc_QtCharts_QAbstractAxis_isLineVisible},
    {sipName_isMinorGridLineVisible, meth_QtCharts_QAbstractAxis_isMinorGridLineVisible, METH_VARARGS, doc_QtCharts_QAbstractAxis_isMinorGridLineVisible},
    {sipName_isReverse, meth_QtCharts_QAbstractAxis_isReverse, METH_VARARGS, doc_QtCharts_QAbstractAxis_isReverse},
    {sipName_isTitleVisible, meth_QtCharts_QAbstractAxis_isTitleVisible, METH_VARARGS, doc_QtCharts_QAbstractAxis_isTitleVisible},
    {sipName_isVisible, meth_QtCharts_QAbstractAxis_isVisible, METH_VARARGS, doc_QtCharts_QAbstractAxis_isVisible},
    {sipName_labelsAngle, meth_QtCharts_QAbstractAxis_labelsAngle, METH_VARARGS, doc_QtCharts_QAbstractAxis_labelsAngle},
    {sipName_labelsBrush, meth_QtCharts_QAbstractAxis_labelsBrush, METH_VARARGS, doc_QtCharts_QAbstractAxis_labelsBrush},
    {sipName_labelsColor, meth_QtCharts_QAbstractAxis_labelsColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_labelsColor},
    {sipName_labelsEditable, meth_QtCharts_QAbstractAxis_labelsEditable, METH_VARARGS, doc_QtCharts_QAbstractAxis_labelsEditable},
    {sipName_labelsFont, meth_QtCharts_QAbstractAxis_labelsFont, METH_VARARGS, doc_QtCharts_QAbstractAxis_labelsFont},
    {sipName_labelsVisible, meth_QtCharts_QAbstractAxis_labelsVisible, METH_VARARGS, doc_QtCharts_QAbstractAxis_labelsVisible},
    {sipName_linePen, meth_QtCharts_QAbstractAxis_linePen, METH_VARARGS, doc_QtCharts_QAbstractAxis_linePen},
    {sipName_linePenColor, meth_QtCharts_QAbstractAxis_linePenColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_linePenColor},
    {sipName_minorGridLineColor, meth_QtCharts_QAbstractAxis_minorGridLineColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_minorGridLineColor},
    {sipName_minorGridLinePen, meth_QtCharts_QAbstractAxis_minorGridLinePen, METH_VARARGS, doc_QtCharts_QAbstractAxis_minorGridLinePen},
    {sipName_orientation, meth_QtCharts_QAbstractAxis_orientation, METH_VARARGS, doc_QtCharts_QAbstractAxis_orientation},
    {sipName_setGridLineColor, meth_QtCharts_QAbstractAxis_setGridLineColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_setGridLineColor},
    {sipName_setGridLinePen, meth_QtCharts_QAbstractAxis_setGridLinePen, METH_VARARGS, doc_QtCharts_QAbstractAxis_setGridLinePen},
    {sipName_setGridLineVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setGridLineVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setGridLineVisible},
    {sipName_setLabelsAngle, meth_QtCharts_QAbstractAxis_setLabelsAngle, METH_VARARGS, doc_QtCharts_QAbstractAxis_setLabelsAngle},
    {sipName_setLabelsBrush, meth_QtCharts_QAbstractAxis_setLabelsBrush, METH_VARARGS, doc_QtCharts_QAbstractAxis_setLabelsBrush},
    {sipName_setLabelsColor, meth_QtCharts_QAbstractAxis_setLabelsColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_setLabelsColor},
    {sipName_setLabelsEditable, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setLabelsEditable), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setLabelsEditable},
    {sipName_setLabelsFont, meth_QtCharts_QAbstractAxis_setLabelsFont, METH_VARARGS, doc_QtCharts_QAbstractAxis_setLabelsFont},
    {sipName_setLabelsVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setLabelsVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setLabelsVisible},
    {sipName_setLinePen, meth_QtCharts_QAbstractAxis_setLinePen, METH_VARARGS, doc_QtCharts_QAbstractAxis_setLinePen},
    {sipName_setLinePenColor, meth_QtCharts_QAbstractAxis_setLinePenColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_setLinePenColor},
    {sipName_setLineVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setLineVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setLineVisible},
    {sipName_setMax, meth_QtCharts_QAbstractAxis_setMax, METH_VARARGS, doc_QtCharts_QAbstractAxis_setMax},
    {sipName_setMin, meth_QtCharts_QAbstractAxis_setMin, METH_VARARGS, doc_QtCharts_QAbstractAxis_setMin},
    {sipName_setMinorGridLineColor, meth_QtCharts_QAbstractAxis_setMinorGridLineColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_setMinorGridLineColor},
    {sipName_setMinorGridLinePen, meth_QtCharts_QAbstractAxis_setMinorGridLinePen, METH_VARARGS, doc_QtCharts_QAbstractAxis_setMinorGridLinePen},
    {sipName_setMinorGridLineVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setMinorGridLineVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setMinorGridLineVisible},
    {sipName_setRange, meth_QtCharts_QAbstractAxis_setRange, METH_VARARGS, doc_QtCharts_QAbstractAxis_setRange},
    {sipName_setReverse, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setReverse), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setReverse},
    {sipName_setShadesBorderColor, meth_QtCharts_QAbstractAxis_setShadesBorderColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_setShadesBorderColor},
    {sipName_setShadesBrush, meth_QtCharts_QAbstractAxis_setShadesBrush, METH_VARARGS, doc_QtCharts_QAbstractAxis_setShadesBrush},
    {sipName_setShadesColor, meth_QtCharts_QAbstractAxis_setShadesColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_setShadesColor},
    {sipName_setShadesPen, meth_QtCharts_QAbstractAxis_setShadesPen, METH_VARARGS, doc_QtCharts_QAbstractAxis_setShadesPen},
    {sipName_setShadesVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setShadesVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setShadesVisible},
    {sipName_setTitleBrush, meth_QtCharts_QAbstractAxis_setTitleBrush, METH_VARARGS, doc_QtCharts_QAbstractAxis_setTitleBrush},
    {sipName_setTitleFont, meth_QtCharts_QAbstractAxis_setTitleFont, METH_VARARGS, doc_QtCharts_QAbstractAxis_setTitleFont},
    {sipName_setTitleText, meth_QtCharts_QAbstractAxis_setTitleText, METH_VARARGS, doc_QtCharts_QAbstractAxis_setTitleText},
    {sipName_setTitleVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setTitleVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setTitleVisible},
    {sipName_setVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractAxis_setVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractAxis_setVisible},
    {sipName_shadesBorderColor, meth_QtCharts_QAbstractAxis_shadesBorderColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_shadesBorderColor},
    {sipName_shadesBrush, meth_QtCharts_QAbstractAxis_shadesBrush, METH_VARARGS, doc_QtCharts_QAbstractAxis_shadesBrush},
    {sipName_shadesColor, meth_QtCharts_QAbstractAxis_shadesColor, METH_VARARGS, doc_QtCharts_QAbstractAxis_shadesColor},
    {sipName_shadesPen, meth_QtCharts_QAbstractAxis_shadesPen, METH_VARARGS, doc_QtCharts_QAbstractAxis_shadesPen},
    {sipName_shadesVisible, meth_QtCharts_QAbstractAxis_shadesVisible, METH_VARARGS, doc_QtCharts_QAbstractAxis_shadesVisible},
    {sipName_show, meth_QtCharts_QAbstractAxis_show, METH_VARARGS, doc_QtCharts_QAbstractAxis_show},
    {sipName_titleBrush, meth_QtCharts_QAbstractAxis_titleBrush, METH_VARARGS, doc_QtCharts_QAbstractAxis_titleBrush},
    {sipName_titleFont, meth_QtCharts_QAbstractAxis_titleFont, METH_VARARGS, doc_QtCharts_QAbstractAxis_titleFont},
    {sipName_titleText, meth_QtCharts_QAbstractAxis_titleText, METH_VARARGS, doc_QtCharts_QAbstractAxis_titleText},
    {sipName_type, meth_QtCharts_QAbstractAxis_type, METH_VARARGS, doc_QtCharts_QAbstractAxis_type}
};

static sipEnumMemberDef enummembers_QtCharts_QAbstractAxis[] = {
    {sipName_AxisTypeBarCategory, static_cast<int>(::QtCharts::QAbstractAxis::AxisTypeBarCategory), 9},
    {sipName_AxisTypeCategory, static_cast<int>(::QtCharts::QAbstractAxis::AxisTypeCategory), 9},
    {sipName_AxisTypeDateTime, static_cast<int>(::QtCharts::QAbstractAxis::AxisTypeDateTime), 9},
    {sipName_AxisTypeLogValue, static_cast<int>(::QtCharts::QAbstractAxis::AxisTypeLogValue), 9},
    {sipName_AxisTypeNoAxis, static_cast<int>(::QtCharts::QAbstractAxis::AxisTypeNoAxis), 9},
    {sipName_AxisTypeValue, static_cast<int>(::QtCharts::QAbstractAxis::AxisTypeValue), 9},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QAbstractAxis[] = {
    {"labelsEditableChanged(bool)", "\1labelsEditableChanged(self, editable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"reverseChanged(bool)", "\1reverseChanged(self, reverse: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"minorGridLineColorChanged(QColor)", "\1minorGridLineColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"gridLineColorChanged(QColor)", "\1gridLineColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"minorGridLinePenChanged(QPen)", "\1minorGridLinePenChanged(self, pen: QPen|QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"minorGridVisibleChanged(bool)", "\1minorGridVisibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"shadesBrushChanged(QBrush)", "\1shadesBrushChanged(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"shadesPenChanged(QPen)", "\1shadesPenChanged(self, pen: QPen|QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"titleFontChanged(QFont)", "\1titleFontChanged(self, font: QFont)", SIP_NULLPTR, SIP_NULLPTR},
    {"titleVisibleChanged(bool)", "\1titleVisibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"titleBrushChanged(QBrush)", "\1titleBrushChanged(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"titleTextChanged(QString)", "\1titleTextChanged(self, title: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"gridLinePenChanged(QPen)", "\1gridLinePenChanged(self, pen: QPen|QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsAngleChanged(int)", "\1labelsAngleChanged(self, angle: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsFontChanged(QFont)", "\1labelsFontChanged(self, pen: QFont)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsBrushChanged(QBrush)", "\1labelsBrushChanged(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"linePenChanged(QPen)", "\1linePenChanged(self, pen: QPen|QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"shadesBorderColorChanged(QColor)", "\1shadesBorderColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"shadesColorChanged(QColor)", "\1shadesColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"shadesVisibleChanged(bool)", "\1shadesVisibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsColorChanged(QColor)", "\1labelsColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorChanged(QColor)", "\1colorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"gridVisibleChanged(bool)", "\1gridVisibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsVisibleChanged(bool)", "\1labelsVisibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"lineVisibleChanged(bool)", "\1lineVisibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"visibleChanged(bool)", "\1visibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QAbstractAxis = {
    &::QtCharts::QAbstractAxis::staticMetaObject,
    0,
    signals_QtCharts_QAbstractAxis,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAbstractAxis = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QAbstractAxis,
        SIP_NULLPTR,
        &plugin_QtCharts_QAbstractAxis,
    },
    {
        sipNameNr_QAbstractAxis,
        {0, 0, 1},
        60, methods_QtCharts_QAbstractAxis,
        6, enummembers_QtCharts_QAbstractAxis,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtCharts_QAbstractAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QAbstractAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtCharts_QAbstractAxis,
    cast_QtCharts_QAbstractAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
