/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 103 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 181 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"


extern "C" {static long slot_QtCharts_QPolarChart_PolarOrientations___hash__(PyObject *);}
static long slot_QtCharts_QPolarChart_PolarOrientations___hash__(PyObject *sipSelf)
{
    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 122 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QtCharts::QPolarChart::PolarOrientations::Int();
#line 199 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static int slot_QtCharts_QPolarChart_PolarOrientations___bool__(PyObject *);}
static int slot_QtCharts_QPolarChart_PolarOrientations___bool__(PyObject *sipSelf)
{
    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return -1;


    {
        {
            int sipRes = 0;

#line 117 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QtCharts::QPolarChart::PolarOrientations::Int() != 0);
#line 224 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___ne__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPolarChart::PolarOrientations* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QtCharts_QPolarChart_PolarOrientations, &a0, &a0State))
        {
            bool sipRes = 0;

#line 112 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QtCharts::QPolarChart::PolarOrientations::Int() != a0->operator QtCharts::QPolarChart::PolarOrientations::Int());
#line 254 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"
            sipReleaseType(const_cast< ::QtCharts::QPolarChart::PolarOrientations *>(a0), sipType_QtCharts_QPolarChart_PolarOrientations, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtChart, ne_slot, sipType_QtCharts_QPolarChart_PolarOrientations, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___eq__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPolarChart::PolarOrientations* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QtCharts_QPolarChart_PolarOrientations, &a0, &a0State))
        {
            bool sipRes = 0;

#line 107 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QtCharts::QPolarChart::PolarOrientations::Int() == a0->operator QtCharts::QPolarChart::PolarOrientations::Int());
#line 287 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"
            sipReleaseType(const_cast< ::QtCharts::QPolarChart::PolarOrientations *>(a0), sipType_QtCharts_QPolarChart_PolarOrientations, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtChart, eq_slot, sipType_QtCharts_QPolarChart_PolarOrientations, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___ixor__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___ixor__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QtCharts_QPolarChart_PolarOrientations)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 101 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        *sipCpp = QtCharts::QPolarChart::PolarOrientations(*sipCpp ^ a0);
#line 323 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___xor__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___xor__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPolarChart::PolarOrientations* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QtCharts_QPolarChart_PolarOrientations, &a0, &a0State, &a1))
        {
            ::QtCharts::QPolarChart::PolarOrientations*sipRes;

            sipRes = new ::QtCharts::QPolarChart::PolarOrientations((*a0 ^ a1));
            sipReleaseType(a0, sipType_QtCharts_QPolarChart_PolarOrientations, a0State);

            return sipConvertFromNewType(sipRes, sipType_QtCharts_QPolarChart_PolarOrientations, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtChart, xor_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___ior__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___ior__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QtCharts_QPolarChart_PolarOrientations)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 95 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        *sipCpp = QtCharts::QPolarChart::PolarOrientations(*sipCpp | a0);
#line 395 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___or__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPolarChart::PolarOrientations* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QtCharts_QPolarChart_PolarOrientations, &a0, &a0State, &a1))
        {
            ::QtCharts::QPolarChart::PolarOrientations*sipRes;

            sipRes = new ::QtCharts::QPolarChart::PolarOrientations((*a0 | a1));
            sipReleaseType(a0, sipType_QtCharts_QPolarChart_PolarOrientations, a0State);

            return sipConvertFromNewType(sipRes, sipType_QtCharts_QPolarChart_PolarOrientations, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtChart, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___iand__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___iand__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QtCharts_QPolarChart_PolarOrientations)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            sipCpp->::QtCharts::QPolarChart::PolarOrientations::operator&=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___and__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___and__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPolarChart::PolarOrientations* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QtCharts_QPolarChart_PolarOrientations, &a0, &a0State, &a1))
        {
            ::QtCharts::QPolarChart::PolarOrientations*sipRes;

            sipRes = new ::QtCharts::QPolarChart::PolarOrientations((*a0 & a1));
            sipReleaseType(a0, sipType_QtCharts_QPolarChart_PolarOrientations, a0State);

            return sipConvertFromNewType(sipRes, sipType_QtCharts_QPolarChart_PolarOrientations, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtChart, and_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___invert__(PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___invert__(PyObject *sipSelf)
{
    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            ::QtCharts::QPolarChart::PolarOrientations*sipRes;

            sipRes = new ::QtCharts::QPolarChart::PolarOrientations(~(*sipCpp));

            return sipConvertFromNewType(sipRes, sipType_QtCharts_QPolarChart_PolarOrientations, SIP_NULLPTR);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___index__(PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___index__(PyObject *sipSelf)
{
    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes = 0;

#line 84 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QtCharts::QPolarChart::PolarOrientations::Int();
#line 552 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___int__(PyObject *);}
static PyObject *slot_QtCharts_QPolarChart_PolarOrientations___int__(PyObject *sipSelf)
{
    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPolarChart_PolarOrientations));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes;

            sipRes = int(*sipCpp);

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QPolarChart_PolarOrientations(void *, int);}
static void release_QtCharts_QPolarChart_PolarOrientations(void *sipCppV, int)
{
    delete reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipCppV);
}


extern "C" {static void *array_QtCharts_QPolarChart_PolarOrientations(Py_ssize_t);}
static void *array_QtCharts_QPolarChart_PolarOrientations(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QPolarChart::PolarOrientations[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QPolarChart_PolarOrientations(void *);}
static void array_delete_QtCharts_QPolarChart_PolarOrientations(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipCpp);
}


extern "C" {static void assign_QtCharts_QPolarChart_PolarOrientations(void *, Py_ssize_t, void *);}
static void assign_QtCharts_QPolarChart_PolarOrientations(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations *>(sipSrc);
}


extern "C" {static void *copy_QtCharts_QPolarChart_PolarOrientations(const void *, Py_ssize_t);}
static void *copy_QtCharts_QPolarChart_PolarOrientations(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QtCharts::QPolarChart::PolarOrientations(reinterpret_cast<const ::QtCharts::QPolarChart::PolarOrientations *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QtCharts_QPolarChart_PolarOrientations(sipSimpleWrapper *);}
static void dealloc_QtCharts_QPolarChart_PolarOrientations(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QPolarChart_PolarOrientations(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QtCharts_QPolarChart_PolarOrientations(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QPolarChart_PolarOrientations(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QtCharts::QPolarChart::PolarOrientations *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QtCharts::QPolarChart::PolarOrientations();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new ::QtCharts::QPolarChart::PolarOrientations(a0);

            return sipCpp;
        }
    }

    {
        const ::QtCharts::QPolarChart::PolarOrientations* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QtCharts_QPolarChart_PolarOrientations, &a0, &a0State))
        {
            sipCpp = new ::QtCharts::QPolarChart::PolarOrientations(*a0);
            sipReleaseType(const_cast< ::QtCharts::QPolarChart::PolarOrientations *>(a0), sipType_QtCharts_QPolarChart_PolarOrientations, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static int convertTo_QtCharts_QPolarChart_PolarOrientations(PyObject *, void **, int *, PyObject *);}
static int convertTo_QtCharts_QPolarChart_PolarOrientations(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj)
{
    ::QtCharts::QPolarChart::PolarOrientations **sipCppPtr = reinterpret_cast< ::QtCharts::QPolarChart::PolarOrientations **>(sipCppPtrV);

#line 127 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
// Allow an instance of the base enum whenever a QtCharts::QPolarChart::PolarOrientations is expected.

if (sipIsErr == NULL)
    return (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QtCharts_QPolarChart_PolarOrientation)) ||
            sipCanConvertToType(sipPy, sipType_QtCharts_QPolarChart_PolarOrientations, SIP_NO_CONVERTORS));

if (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QtCharts_QPolarChart_PolarOrientation)))
{
    *sipCppPtr = new QtCharts::QPolarChart::PolarOrientations(int(SIPLong_AsLong(sipPy)));

    return sipGetState(sipTransferObj);
}

*sipCppPtr = reinterpret_cast<QtCharts::QPolarChart::PolarOrientations *>(sipConvertToType(sipPy, sipType_QtCharts_QPolarChart_PolarOrientations, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));

return 0;
#line 695 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPolarChartPolarOrientations.cpp"
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QtCharts_QPolarChart_PolarOrientations[] = {
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___hash__, hash_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___bool__, bool_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___ne__, ne_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___eq__, eq_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___ixor__, ixor_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___xor__, xor_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___ior__, ior_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___or__, or_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___iand__, iand_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___and__, and_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___invert__, invert_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___index__, index_slot},
    {(void *)slot_QtCharts_QPolarChart_PolarOrientations___int__, int_slot},
    {0, (sipPySlotType)0}
};

PyDoc_STRVAR(doc_QtCharts_QPolarChart_PolarOrientations, "\1QPolarChart.PolarOrientations()\n"
"QPolarChart.PolarOrientations(f: QPolarChart.PolarOrientations|QPolarChart.PolarOrientation)\n"
"QPolarChart.PolarOrientations(a0: QPolarChart.PolarOrientations)");


static pyqt5ClassPluginDef plugin_QtCharts_QPolarChart_PolarOrientations = {
    SIP_NULLPTR,
    1,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPolarChart_PolarOrientations = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QPolarChart__PolarOrientations,
        SIP_NULLPTR,
        &plugin_QtCharts_QPolarChart_PolarOrientations,
    },
    {
        sipNameNr_PolarOrientations,
        {59, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QPolarChart_PolarOrientations,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QtCharts_QPolarChart_PolarOrientations,
    init_type_QtCharts_QPolarChart_PolarOrientations,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QPolarChart_PolarOrientations,
    assign_QtCharts_QPolarChart_PolarOrientations,
    array_QtCharts_QPolarChart_PolarOrientations,
    copy_QtCharts_QPolarChart_PolarOrientations,
    release_QtCharts_QPolarChart_PolarOrientations,
    SIP_NULLPTR,
    convertTo_QtCharts_QPolarChart_PolarOrientations,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QPolarChart_PolarOrientations,
    sizeof (::QtCharts::QPolarChart::PolarOrientations),
};
