/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 39 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 43 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 108 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 98 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 111 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 114 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 117 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 120 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 123 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 126 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 135 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 138 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 143 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 182 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 187 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 190 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 193 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 196 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 199 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 202 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 205 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 208 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 211 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 214 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 217 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 220 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 223 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 226 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 229 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAreaSeries.cpp"


class sipQtCharts_QAreaSeries : public ::QtCharts::QAreaSeries
{
public:
    sipQtCharts_QAreaSeries(::QObject*);
    sipQtCharts_QAreaSeries(::QtCharts::QLineSeries*, ::QtCharts::QLineSeries*);
    virtual ~sipQtCharts_QAreaSeries();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QtCharts::QAbstractSeries::SeriesType type() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QAreaSeries(const sipQtCharts_QAreaSeries &);
    sipQtCharts_QAreaSeries &operator = (const sipQtCharts_QAreaSeries &);

    char sipPyMethods[8];
};

sipQtCharts_QAreaSeries::sipQtCharts_QAreaSeries(::QObject*a0): ::QtCharts::QAreaSeries(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QAreaSeries::sipQtCharts_QAreaSeries(::QtCharts::QLineSeries*a0, ::QtCharts::QLineSeries*a1): ::QtCharts::QAreaSeries(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QAreaSeries::~sipQtCharts_QAreaSeries()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QAreaSeries::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QAreaSeries);

    return ::QtCharts::QAreaSeries::metaObject();
}

int sipQtCharts_QAreaSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QAreaSeries::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QAreaSeries, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QAreaSeries::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QAreaSeries, _clname, &sipCpp) ? sipCpp : ::QtCharts::QAreaSeries::qt_metacast(_clname));
}

void sipQtCharts_QAreaSeries::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QAreaSeries::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QAreaSeries::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QAreaSeries::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QAreaSeries::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QAreaSeries::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QAreaSeries::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QAreaSeries::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QAreaSeries::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QAreaSeries::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QAreaSeries::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QAreaSeries::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtCharts_QAreaSeries::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QAreaSeries::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QtCharts::QAbstractSeries::SeriesType sipQtCharts_QAreaSeries::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QtCharts::QAreaSeries::type();

    extern ::QtCharts::QAbstractSeries::SeriesType sipVH_QtChart_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_7(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_type, "type(self) -> QAbstractSeries.SeriesType");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_type(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QtCharts::QAbstractSeries::SeriesType sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtCharts::QAreaSeries::type() : sipCpp->type());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QAbstractSeries_SeriesType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_type, doc_QtCharts_QAreaSeries_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setUpperSeries, "setUpperSeries(self, series: QLineSeries|None)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setUpperSeries(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setUpperSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLineSeries* a0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QtCharts_QLineSeries, &a0))
        {
            sipCpp->setUpperSeries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setUpperSeries, doc_QtCharts_QAreaSeries_setUpperSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_upperSeries, "upperSeries(self) -> QLineSeries|None");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_upperSeries(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_upperSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QtCharts::QLineSeries*sipRes;

            sipRes = sipCpp->upperSeries();

            return sipConvertFromType(sipRes, sipType_QtCharts_QLineSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_upperSeries, doc_QtCharts_QAreaSeries_upperSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setLowerSeries, "setLowerSeries(self, series: QLineSeries|None)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setLowerSeries(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setLowerSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLineSeries* a0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QtCharts_QLineSeries, &a0))
        {
            sipCpp->setLowerSeries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setLowerSeries, doc_QtCharts_QAreaSeries_setLowerSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_lowerSeries, "lowerSeries(self) -> QLineSeries|None");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_lowerSeries(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_lowerSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QtCharts::QLineSeries*sipRes;

            sipRes = sipCpp->lowerSeries();

            return sipConvertFromType(sipRes, sipType_QtCharts_QLineSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_lowerSeries, doc_QtCharts_QAreaSeries_lowerSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setPen, doc_QtCharts_QAreaSeries_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_pen, doc_QtCharts_QAreaSeries_pen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setBrush, doc_QtCharts_QAreaSeries_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_brush, doc_QtCharts_QAreaSeries_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setPointsVisible, "setPointsVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setPointsVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setPointsVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAreaSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, &a0))
        {
            sipCpp->setPointsVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setPointsVisible, doc_QtCharts_QAreaSeries_setPointsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_pointsVisible, "pointsVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_pointsVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_pointsVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->pointsVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_pointsVisible, doc_QtCharts_QAreaSeries_pointsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setColor, "setColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setColor, doc_QtCharts_QAreaSeries_setColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_color, "color(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_color(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_color(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->color());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_color, doc_QtCharts_QAreaSeries_color);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setBorderColor, "setBorderColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setBorderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setBorderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setBorderColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setBorderColor, doc_QtCharts_QAreaSeries_setBorderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_borderColor, "borderColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_borderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_borderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->borderColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_borderColor, doc_QtCharts_QAreaSeries_borderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setPointLabelsFormat, "setPointLabelsFormat(self, format: str|None)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsFormat(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPointLabelsFormat(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setPointLabelsFormat, doc_QtCharts_QAreaSeries_setPointLabelsFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_pointLabelsFormat, "pointLabelsFormat(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_pointLabelsFormat(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_pointLabelsFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->pointLabelsFormat());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_pointLabelsFormat, doc_QtCharts_QAreaSeries_pointLabelsFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setPointLabelsVisible, "setPointLabelsVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAreaSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, &a0))
        {
            sipCpp->setPointLabelsVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setPointLabelsVisible, doc_QtCharts_QAreaSeries_setPointLabelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_pointLabelsVisible, "pointLabelsVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_pointLabelsVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_pointLabelsVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->pointLabelsVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_pointLabelsVisible, doc_QtCharts_QAreaSeries_pointLabelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setPointLabelsFont, "setPointLabelsFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setPointLabelsFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setPointLabelsFont, doc_QtCharts_QAreaSeries_setPointLabelsFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_pointLabelsFont, "pointLabelsFont(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_pointLabelsFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_pointLabelsFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->pointLabelsFont());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_pointLabelsFont, doc_QtCharts_QAreaSeries_pointLabelsFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setPointLabelsColor, "setPointLabelsColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setPointLabelsColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setPointLabelsColor, doc_QtCharts_QAreaSeries_setPointLabelsColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_pointLabelsColor, "pointLabelsColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_pointLabelsColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_pointLabelsColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->pointLabelsColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_pointLabelsColor, doc_QtCharts_QAreaSeries_pointLabelsColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_setPointLabelsClipping, "setPointLabelsClipping(self, enable: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsClipping(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_setPointLabelsClipping(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAreaSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_enable,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp, &a0))
        {
            sipCpp->setPointLabelsClipping(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_setPointLabelsClipping, doc_QtCharts_QAreaSeries_setPointLabelsClipping);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAreaSeries_pointLabelsClipping, "pointLabelsClipping(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAreaSeries_pointLabelsClipping(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAreaSeries_pointLabelsClipping(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAreaSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAreaSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->pointLabelsClipping();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAreaSeries, sipName_pointLabelsClipping, doc_QtCharts_QAreaSeries_pointLabelsClipping);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QAreaSeries(void *, const sipTypeDef *);}
static void *cast_QtCharts_QAreaSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QAreaSeries *sipCpp = reinterpret_cast< ::QtCharts::QAreaSeries *>(sipCppV);

    if (targetType == sipType_QtCharts_QAreaSeries)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtCharts_QAbstractSeries)->ctd_cast(static_cast< ::QtCharts::QAbstractSeries *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QAreaSeries(void *, int);}
static void release_QtCharts_QAreaSeries(void *sipCppV, int)
{
    ::QtCharts::QAreaSeries *sipCpp = reinterpret_cast< ::QtCharts::QAreaSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QAreaSeries(Py_ssize_t);}
static void *array_QtCharts_QAreaSeries(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QAreaSeries[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QAreaSeries(void *);}
static void array_delete_QtCharts_QAreaSeries(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QAreaSeries *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QAreaSeries(sipSimpleWrapper *);}
static void dealloc_QtCharts_QAreaSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QAreaSeries *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QAreaSeries(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QAreaSeries(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QAreaSeries(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QAreaSeries *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtCharts_QAreaSeries(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QtCharts::QLineSeries* a0;
        ::QtCharts::QLineSeries* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_lowerSeries,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|J8", sipType_QtCharts_QLineSeries, &a0, sipType_QtCharts_QLineSeries, &a1))
        {
            sipCpp = new sipQtCharts_QAreaSeries(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QAreaSeries[] = {{13, 255, 1}};


static PyMethodDef methods_QtCharts_QAreaSeries[] = {
    {sipName_borderColor, meth_QtCharts_QAreaSeries_borderColor, METH_VARARGS, doc_QtCharts_QAreaSeries_borderColor},
    {sipName_brush, meth_QtCharts_QAreaSeries_brush, METH_VARARGS, doc_QtCharts_QAreaSeries_brush},
    {sipName_color, meth_QtCharts_QAreaSeries_color, METH_VARARGS, doc_QtCharts_QAreaSeries_color},
    {sipName_lowerSeries, meth_QtCharts_QAreaSeries_lowerSeries, METH_VARARGS, doc_QtCharts_QAreaSeries_lowerSeries},
    {sipName_pen, meth_QtCharts_QAreaSeries_pen, METH_VARARGS, doc_QtCharts_QAreaSeries_pen},
    {sipName_pointLabelsClipping, meth_QtCharts_QAreaSeries_pointLabelsClipping, METH_VARARGS, doc_QtCharts_QAreaSeries_pointLabelsClipping},
    {sipName_pointLabelsColor, meth_QtCharts_QAreaSeries_pointLabelsColor, METH_VARARGS, doc_QtCharts_QAreaSeries_pointLabelsColor},
    {sipName_pointLabelsFont, meth_QtCharts_QAreaSeries_pointLabelsFont, METH_VARARGS, doc_QtCharts_QAreaSeries_pointLabelsFont},
    {sipName_pointLabelsFormat, meth_QtCharts_QAreaSeries_pointLabelsFormat, METH_VARARGS, doc_QtCharts_QAreaSeries_pointLabelsFormat},
    {sipName_pointLabelsVisible, meth_QtCharts_QAreaSeries_pointLabelsVisible, METH_VARARGS, doc_QtCharts_QAreaSeries_pointLabelsVisible},
    {sipName_pointsVisible, meth_QtCharts_QAreaSeries_pointsVisible, METH_VARARGS, doc_QtCharts_QAreaSeries_pointsVisible},
    {sipName_setBorderColor, meth_QtCharts_QAreaSeries_setBorderColor, METH_VARARGS, doc_QtCharts_QAreaSeries_setBorderColor},
    {sipName_setBrush, meth_QtCharts_QAreaSeries_setBrush, METH_VARARGS, doc_QtCharts_QAreaSeries_setBrush},
    {sipName_setColor, meth_QtCharts_QAreaSeries_setColor, METH_VARARGS, doc_QtCharts_QAreaSeries_setColor},
    {sipName_setLowerSeries, meth_QtCharts_QAreaSeries_setLowerSeries, METH_VARARGS, doc_QtCharts_QAreaSeries_setLowerSeries},
    {sipName_setPen, meth_QtCharts_QAreaSeries_setPen, METH_VARARGS, doc_QtCharts_QAreaSeries_setPen},
    {sipName_setPointLabelsClipping, SIP_MLMETH_CAST(meth_QtCharts_QAreaSeries_setPointLabelsClipping), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAreaSeries_setPointLabelsClipping},
    {sipName_setPointLabelsColor, meth_QtCharts_QAreaSeries_setPointLabelsColor, METH_VARARGS, doc_QtCharts_QAreaSeries_setPointLabelsColor},
    {sipName_setPointLabelsFont, meth_QtCharts_QAreaSeries_setPointLabelsFont, METH_VARARGS, doc_QtCharts_QAreaSeries_setPointLabelsFont},
    {sipName_setPointLabelsFormat, meth_QtCharts_QAreaSeries_setPointLabelsFormat, METH_VARARGS, doc_QtCharts_QAreaSeries_setPointLabelsFormat},
    {sipName_setPointLabelsVisible, SIP_MLMETH_CAST(meth_QtCharts_QAreaSeries_setPointLabelsVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAreaSeries_setPointLabelsVisible},
    {sipName_setPointsVisible, SIP_MLMETH_CAST(meth_QtCharts_QAreaSeries_setPointsVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAreaSeries_setPointsVisible},
    {sipName_setUpperSeries, meth_QtCharts_QAreaSeries_setUpperSeries, METH_VARARGS, doc_QtCharts_QAreaSeries_setUpperSeries},
    {sipName_type, meth_QtCharts_QAreaSeries_type, METH_VARARGS, doc_QtCharts_QAreaSeries_type},
    {sipName_upperSeries, meth_QtCharts_QAreaSeries_upperSeries, METH_VARARGS, doc_QtCharts_QAreaSeries_upperSeries}
};

PyDoc_STRVAR(doc_QtCharts_QAreaSeries, "\1QAreaSeries(parent: QObject|None = None)\n"
"QAreaSeries(upperSeries: QLineSeries|None, lowerSeries: QLineSeries|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QAreaSeries[] = {
    {"pointLabelsClippingChanged(bool)", "\1pointLabelsClippingChanged(self, clipping: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"doubleClicked(QPointF)", "\1doubleClicked(self, point: QPointF|QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"released(QPointF)", "\1released(self, point: QPointF|QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed(QPointF)", "\1pressed(self, point: QPointF|QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsColorChanged(QColor)", "\1pointLabelsColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsFontChanged(QFont)", "\1pointLabelsFontChanged(self, font: QFont)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsVisibilityChanged(bool)", "\1pointLabelsVisibilityChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"pointLabelsFormatChanged(QString)", "\1pointLabelsFormatChanged(self, format: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(QPointF,bool)", "\1hovered(self, point: QPointF|QPoint, state: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"selected()", "\1selected(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked(QPointF)", "\1clicked(self, point: QPointF|QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorChanged(QColor)", "\1colorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"borderColorChanged(QColor)", "\1borderColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QAreaSeries = {
    &::QtCharts::QAreaSeries::staticMetaObject,
    0,
    signals_QtCharts_QAreaSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAreaSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QAreaSeries,
        SIP_NULLPTR,
        &plugin_QtCharts_QAreaSeries,
    },
    {
        sipNameNr_QAreaSeries,
        {0, 0, 1},
        25, methods_QtCharts_QAreaSeries,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QAreaSeries,
    -1,
    -1,
    supers_QtCharts_QAreaSeries,
    SIP_NULLPTR,
    init_type_QtCharts_QAreaSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QAreaSeries,
    SIP_NULLPTR,
    array_QtCharts_QAreaSeries,
    SIP_NULLPTR,
    release_QtCharts_QAreaSeries,
    cast_QtCharts_QAreaSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QAreaSeries,
    sizeof (::QtCharts::QAreaSeries),
};
