/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 61 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 65 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 68 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 71 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 76 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 79 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 82 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 85 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 88 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 91 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 94 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 97 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 100 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 103 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 106 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 109 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 112 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 115 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 118 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 121 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSet.cpp"


class sipQtCharts_QCandlestickSet : public ::QtCharts::QCandlestickSet
{
public:
    sipQtCharts_QCandlestickSet(::qreal, ::QObject*);
    sipQtCharts_QCandlestickSet(::qreal, ::qreal, ::qreal, ::qreal, ::qreal, ::QObject*);
    virtual ~sipQtCharts_QCandlestickSet();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QCandlestickSet(const sipQtCharts_QCandlestickSet &);
    sipQtCharts_QCandlestickSet &operator = (const sipQtCharts_QCandlestickSet &);

    char sipPyMethods[7];
};

sipQtCharts_QCandlestickSet::sipQtCharts_QCandlestickSet(::qreal a0, ::QObject*a1): ::QtCharts::QCandlestickSet(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QCandlestickSet::sipQtCharts_QCandlestickSet(::qreal a0, ::qreal a1, ::qreal a2, ::qreal a3, ::qreal a4, ::QObject*a5): ::QtCharts::QCandlestickSet(a0, a1, a2, a3, a4, a5), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QCandlestickSet::~sipQtCharts_QCandlestickSet()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QCandlestickSet::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QCandlestickSet);

    return ::QtCharts::QCandlestickSet::metaObject();
}

int sipQtCharts_QCandlestickSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QCandlestickSet::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QCandlestickSet, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QCandlestickSet::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QCandlestickSet, _clname, &sipCpp) ? sipCpp : ::QtCharts::QCandlestickSet::qt_metacast(_clname));
}

bool sipQtCharts_QCandlestickSet::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QCandlestickSet::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QCandlestickSet::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QCandlestickSet::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QCandlestickSet::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSet::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QCandlestickSet::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSet::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QCandlestickSet::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSet::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QCandlestickSet::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSet::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QCandlestickSet::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSet::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_setTimestamp, "setTimestamp(self, timestamp: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_setTimestamp(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_setTimestamp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp, &a0))
        {
            sipCpp->setTimestamp(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_setTimestamp, doc_QtCharts_QCandlestickSet_setTimestamp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_timestamp, "timestamp(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_timestamp(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_timestamp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->timestamp();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_timestamp, doc_QtCharts_QCandlestickSet_timestamp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_setOpen, "setOpen(self, open: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_setOpen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_setOpen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp, &a0))
        {
            sipCpp->setOpen(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_setOpen, doc_QtCharts_QCandlestickSet_setOpen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_open, "open(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_open(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_open(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->open();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_open, doc_QtCharts_QCandlestickSet_open);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_setHigh, "setHigh(self, high: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_setHigh(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_setHigh(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp, &a0))
        {
            sipCpp->setHigh(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_setHigh, doc_QtCharts_QCandlestickSet_setHigh);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_high, "high(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_high(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_high(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->high();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_high, doc_QtCharts_QCandlestickSet_high);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_setLow, "setLow(self, low: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_setLow(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_setLow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp, &a0))
        {
            sipCpp->setLow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_setLow, doc_QtCharts_QCandlestickSet_setLow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_low, "low(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_low(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_low(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->low();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_low, doc_QtCharts_QCandlestickSet_low);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_setClose, "setClose(self, close: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_setClose(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_setClose(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp, &a0))
        {
            sipCpp->setClose(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_setClose, doc_QtCharts_QCandlestickSet_setClose);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_close, "close(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_close(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->close();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_close, doc_QtCharts_QCandlestickSet_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_setBrush, doc_QtCharts_QCandlestickSet_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_brush, doc_QtCharts_QCandlestickSet_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_setPen, doc_QtCharts_QCandlestickSet_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSet_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSet_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSet_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSet, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSet, sipName_pen, doc_QtCharts_QCandlestickSet_pen);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QCandlestickSet(void *, const sipTypeDef *);}
static void *cast_QtCharts_QCandlestickSet(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QCandlestickSet *sipCpp = reinterpret_cast< ::QtCharts::QCandlestickSet *>(sipCppV);

    if (targetType == sipType_QtCharts_QCandlestickSet)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QCandlestickSet(void *, int);}
static void release_QtCharts_QCandlestickSet(void *sipCppV, int)
{
    ::QtCharts::QCandlestickSet *sipCpp = reinterpret_cast< ::QtCharts::QCandlestickSet *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QCandlestickSet(Py_ssize_t);}
static void *array_QtCharts_QCandlestickSet(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QCandlestickSet[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QCandlestickSet(void *);}
static void array_delete_QtCharts_QCandlestickSet(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QCandlestickSet *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QCandlestickSet(sipSimpleWrapper *);}
static void dealloc_QtCharts_QCandlestickSet(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QCandlestickSet *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QCandlestickSet(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QCandlestickSet(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QCandlestickSet(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QCandlestickSet *sipCpp = SIP_NULLPTR;

    {
        ::qreal a0 = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            sipName_timestamp,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|dJH", &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQtCharts_QCandlestickSet(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::qreal a2;
        ::qreal a3;
        ::qreal a4 = 0;
        ::QObject* a5 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_timestamp,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "dddd|dJH", &a0, &a1, &a2, &a3, &a4, sipType_QObject, &a5, sipOwner))
        {
            sipCpp = new sipQtCharts_QCandlestickSet(a0, a1, a2, a3, a4, a5);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QCandlestickSet[] = {{10, 0, 1}};


static PyMethodDef methods_QtCharts_QCandlestickSet[] = {
    {sipName_brush, meth_QtCharts_QCandlestickSet_brush, METH_VARARGS, doc_QtCharts_QCandlestickSet_brush},
    {sipName_close, meth_QtCharts_QCandlestickSet_close, METH_VARARGS, doc_QtCharts_QCandlestickSet_close},
    {sipName_high, meth_QtCharts_QCandlestickSet_high, METH_VARARGS, doc_QtCharts_QCandlestickSet_high},
    {sipName_low, meth_QtCharts_QCandlestickSet_low, METH_VARARGS, doc_QtCharts_QCandlestickSet_low},
    {sipName_open, meth_QtCharts_QCandlestickSet_open, METH_VARARGS, doc_QtCharts_QCandlestickSet_open},
    {sipName_pen, meth_QtCharts_QCandlestickSet_pen, METH_VARARGS, doc_QtCharts_QCandlestickSet_pen},
    {sipName_setBrush, meth_QtCharts_QCandlestickSet_setBrush, METH_VARARGS, doc_QtCharts_QCandlestickSet_setBrush},
    {sipName_setClose, meth_QtCharts_QCandlestickSet_setClose, METH_VARARGS, doc_QtCharts_QCandlestickSet_setClose},
    {sipName_setHigh, meth_QtCharts_QCandlestickSet_setHigh, METH_VARARGS, doc_QtCharts_QCandlestickSet_setHigh},
    {sipName_setLow, meth_QtCharts_QCandlestickSet_setLow, METH_VARARGS, doc_QtCharts_QCandlestickSet_setLow},
    {sipName_setOpen, meth_QtCharts_QCandlestickSet_setOpen, METH_VARARGS, doc_QtCharts_QCandlestickSet_setOpen},
    {sipName_setPen, meth_QtCharts_QCandlestickSet_setPen, METH_VARARGS, doc_QtCharts_QCandlestickSet_setPen},
    {sipName_setTimestamp, meth_QtCharts_QCandlestickSet_setTimestamp, METH_VARARGS, doc_QtCharts_QCandlestickSet_setTimestamp},
    {sipName_timestamp, meth_QtCharts_QCandlestickSet_timestamp, METH_VARARGS, doc_QtCharts_QCandlestickSet_timestamp}
};

PyDoc_STRVAR(doc_QtCharts_QCandlestickSet, "\1QCandlestickSet(timestamp: float = 0, parent: QObject|None = None)\n"
"QCandlestickSet(open: float, high: float, low: float, close: float, timestamp: float = 0, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QCandlestickSet[] = {
    {"penChanged()", "\1penChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"brushChanged()", "\1brushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"closeChanged()", "\1closeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"lowChanged()", "\1lowChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"highChanged()", "\1highChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"openChanged()", "\1openChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"timestampChanged()", "\1timestampChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"doubleClicked()", "\1doubleClicked(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"released()", "\1released(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed()", "\1pressed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(bool)", "\1hovered(self, status: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked()", "\1clicked(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QCandlestickSet = {
    &::QtCharts::QCandlestickSet::staticMetaObject,
    0,
    signals_QtCharts_QCandlestickSet,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QCandlestickSet = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QCandlestickSet,
        SIP_NULLPTR,
        &plugin_QtCharts_QCandlestickSet,
    },
    {
        sipNameNr_QCandlestickSet,
        {0, 0, 1},
        14, methods_QtCharts_QCandlestickSet,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QCandlestickSet,
    -1,
    -1,
    supers_QtCharts_QCandlestickSet,
    SIP_NULLPTR,
    init_type_QtCharts_QCandlestickSet,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QCandlestickSet,
    SIP_NULLPTR,
    array_QtCharts_QCandlestickSet,
    SIP_NULLPTR,
    release_QtCharts_QCandlestickSet,
    cast_QtCharts_QCandlestickSet,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QCandlestickSet,
    sizeof (::QtCharts::QCandlestickSet),
};
