/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 99 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 103 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 178 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 181 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 184 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 193 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 196 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 201 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 240 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 245 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 248 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 251 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 254 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 257 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 260 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 263 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 266 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 269 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 272 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 275 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 278 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 281 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 284 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 287 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"


class sipQtCharts_QPieSeries : public ::QtCharts::QPieSeries
{
public:
    sipQtCharts_QPieSeries(::QObject*);
    virtual ~sipQtCharts_QPieSeries();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QtCharts::QAbstractSeries::SeriesType type() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QPieSeries(const sipQtCharts_QPieSeries &);
    sipQtCharts_QPieSeries &operator = (const sipQtCharts_QPieSeries &);

    char sipPyMethods[8];
};

sipQtCharts_QPieSeries::sipQtCharts_QPieSeries(::QObject*a0): ::QtCharts::QPieSeries(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QPieSeries::~sipQtCharts_QPieSeries()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QPieSeries::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QPieSeries);

    return ::QtCharts::QPieSeries::metaObject();
}

int sipQtCharts_QPieSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QPieSeries::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QPieSeries, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QPieSeries::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QPieSeries, _clname, &sipCpp) ? sipCpp : ::QtCharts::QPieSeries::qt_metacast(_clname));
}

void sipQtCharts_QPieSeries::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QPieSeries::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QPieSeries::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QPieSeries::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QPieSeries::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QPieSeries::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QPieSeries::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QPieSeries::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QPieSeries::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QPieSeries::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QPieSeries::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QPieSeries::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtCharts_QPieSeries::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QPieSeries::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QtCharts::QAbstractSeries::SeriesType sipQtCharts_QPieSeries::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QtCharts::QPieSeries::type();

    extern ::QtCharts::QAbstractSeries::SeriesType sipVH_QtChart_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_7(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_type, "type(self) -> QAbstractSeries.SeriesType");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_type(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            ::QtCharts::QAbstractSeries::SeriesType sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtCharts::QPieSeries::type() : sipCpp->type());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QAbstractSeries_SeriesType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_type, doc_QtCharts_QPieSeries_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_append, "append(self, slice: QPieSlice|None) -> bool\n"
"append(self, slices: Iterable[QPieSlice]) -> bool\n"
"append(self, label: str|None, value: float) -> QPieSlice|None");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_append(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_append(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice* a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, sipType_QtCharts_QPieSlice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->append(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        QList< ::QtCharts::QPieSlice*>* a0;
        int a0State = 0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, sipType_QList_0101QtCharts_QPieSlice, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->append(*a0);
            sipReleaseType(a0, sipType_QList_0101QtCharts_QPieSlice, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QString* a0;
        int a0State = 0;
        ::qreal a1;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1d", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, sipType_QString, &a0, &a0State, &a1))
        {
            ::QtCharts::QPieSlice*sipRes;

            sipRes = sipCpp->append(*a0, a1);
            sipReleaseType(a0, sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QtCharts_QPieSlice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_append, doc_QtCharts_QPieSeries_append);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_insert, "insert(self, index: int, slice: QPieSlice|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_insert(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_insert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QPieSlice* a1;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, &a0, sipType_QtCharts_QPieSlice, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->insert(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_insert, doc_QtCharts_QPieSeries_insert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_remove, "remove(self, slice: QPieSlice|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_remove(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_remove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice* a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, sipType_QtCharts_QPieSlice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->remove(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_remove, doc_QtCharts_QPieSeries_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_clear, "clear(self)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_clear(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_clear, doc_QtCharts_QPieSeries_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_slices, "slices(self) -> list[QPieSlice]");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_slices(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_slices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            QList< ::QtCharts::QPieSlice*>*sipRes;

            sipRes = new QList< ::QtCharts::QPieSlice*>(sipCpp->slices());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtCharts_QPieSlice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_slices, doc_QtCharts_QPieSeries_slices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_count, "count(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_count(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_count, doc_QtCharts_QPieSeries_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_isEmpty, doc_QtCharts_QPieSeries_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_sum, "sum(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_sum(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_sum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->sum();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_sum, doc_QtCharts_QPieSeries_sum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_setHorizontalPosition, "setHorizontalPosition(self, relativePosition: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_setHorizontalPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_setHorizontalPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, &a0))
        {
            sipCpp->setHorizontalPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_setHorizontalPosition, doc_QtCharts_QPieSeries_setHorizontalPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_horizontalPosition, "horizontalPosition(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_horizontalPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_horizontalPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->horizontalPosition();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_horizontalPosition, doc_QtCharts_QPieSeries_horizontalPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_setVerticalPosition, "setVerticalPosition(self, relativePosition: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_setVerticalPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_setVerticalPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, &a0))
        {
            sipCpp->setVerticalPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_setVerticalPosition, doc_QtCharts_QPieSeries_setVerticalPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_verticalPosition, "verticalPosition(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_verticalPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_verticalPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->verticalPosition();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_verticalPosition, doc_QtCharts_QPieSeries_verticalPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_setPieSize, "setPieSize(self, relativeSize: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_setPieSize(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_setPieSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, &a0))
        {
            sipCpp->setPieSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_setPieSize, doc_QtCharts_QPieSeries_setPieSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_pieSize, "pieSize(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_pieSize(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_pieSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->pieSize();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_pieSize, doc_QtCharts_QPieSeries_pieSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_setPieStartAngle, "setPieStartAngle(self, startAngle: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_setPieStartAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_setPieStartAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, &a0))
        {
            sipCpp->setPieStartAngle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_setPieStartAngle, doc_QtCharts_QPieSeries_setPieStartAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_pieStartAngle, "pieStartAngle(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_pieStartAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_pieStartAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->pieStartAngle();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_pieStartAngle, doc_QtCharts_QPieSeries_pieStartAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_setPieEndAngle, "setPieEndAngle(self, endAngle: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_setPieEndAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_setPieEndAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, &a0))
        {
            sipCpp->setPieEndAngle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_setPieEndAngle, doc_QtCharts_QPieSeries_setPieEndAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_pieEndAngle, "pieEndAngle(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_pieEndAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_pieEndAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->pieEndAngle();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_pieEndAngle, doc_QtCharts_QPieSeries_pieEndAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_setLabelsVisible, "setLabelsVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_setLabelsVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_setLabelsVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QPieSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, &a0))
        {
            sipCpp->setLabelsVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_setLabelsVisible, doc_QtCharts_QPieSeries_setLabelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_take, "take(self, slice: QPieSlice|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_take(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_take(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice* a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, sipType_QtCharts_QPieSlice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->take(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_take, doc_QtCharts_QPieSeries_take);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_setHoleSize, "setHoleSize(self, holeSize: float)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_setHoleSize(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_setHoleSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, &a0))
        {
            sipCpp->setHoleSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_setHoleSize, doc_QtCharts_QPieSeries_setHoleSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_holeSize, "holeSize(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_holeSize(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_holeSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->holeSize();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_holeSize, doc_QtCharts_QPieSeries_holeSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QPieSeries_setLabelsPosition, "setLabelsPosition(self, position: QPieSlice.LabelPosition)");

extern "C" {static PyObject *meth_QtCharts_QPieSeries_setLabelsPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QPieSeries_setLabelsPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSlice::LabelPosition a0;
        ::QtCharts::QPieSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtCharts_QPieSeries, &sipCpp, sipType_QtCharts_QPieSlice_LabelPosition, &a0))
        {
            sipCpp->setLabelsPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPieSeries, sipName_setLabelsPosition, doc_QtCharts_QPieSeries_setLabelsPosition);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QtCharts_QPieSeries___len__(PyObject *);}
static Py_ssize_t slot_QtCharts_QPieSeries___len__(PyObject *sipSelf)
{
    ::QtCharts::QPieSeries *sipCpp = reinterpret_cast< ::QtCharts::QPieSeries *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QPieSeries));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 1182 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQPieSeries.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtCharts_QPieSeries___lshift__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QPieSeries___lshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSeries* a0;
        ::QtCharts::QPieSlice* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J:", sipType_QtCharts_QPieSeries, &a0, sipType_QtCharts_QPieSlice, &a1))
        {
            ::QtCharts::QPieSeries*sipRes;

            sipRes = &(*a0 << a1);

            return sipConvertFromType(sipRes, sipType_QtCharts_QPieSeries, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtChart, lshift_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QPieSeries(void *, const sipTypeDef *);}
static void *cast_QtCharts_QPieSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QPieSeries *sipCpp = reinterpret_cast< ::QtCharts::QPieSeries *>(sipCppV);

    if (targetType == sipType_QtCharts_QPieSeries)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtCharts_QAbstractSeries)->ctd_cast(static_cast< ::QtCharts::QAbstractSeries *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QPieSeries(void *, int);}
static void release_QtCharts_QPieSeries(void *sipCppV, int)
{
    ::QtCharts::QPieSeries *sipCpp = reinterpret_cast< ::QtCharts::QPieSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QPieSeries(Py_ssize_t);}
static void *array_QtCharts_QPieSeries(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QPieSeries[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QPieSeries(void *);}
static void array_delete_QtCharts_QPieSeries(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QPieSeries *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QPieSeries(sipSimpleWrapper *);}
static void dealloc_QtCharts_QPieSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QPieSeries *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QPieSeries(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QPieSeries(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QPieSeries(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QPieSeries *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtCharts_QPieSeries(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QPieSeries[] = {{13, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QtCharts_QPieSeries[] = {
    {(void *)slot_QtCharts_QPieSeries___len__, len_slot},
    {(void *)slot_QtCharts_QPieSeries___lshift__, lshift_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QtCharts_QPieSeries[] = {
    {sipName_append, meth_QtCharts_QPieSeries_append, METH_VARARGS, doc_QtCharts_QPieSeries_append},
    {sipName_clear, meth_QtCharts_QPieSeries_clear, METH_VARARGS, doc_QtCharts_QPieSeries_clear},
    {sipName_count, meth_QtCharts_QPieSeries_count, METH_VARARGS, doc_QtCharts_QPieSeries_count},
    {sipName_holeSize, meth_QtCharts_QPieSeries_holeSize, METH_VARARGS, doc_QtCharts_QPieSeries_holeSize},
    {sipName_horizontalPosition, meth_QtCharts_QPieSeries_horizontalPosition, METH_VARARGS, doc_QtCharts_QPieSeries_horizontalPosition},
    {sipName_insert, meth_QtCharts_QPieSeries_insert, METH_VARARGS, doc_QtCharts_QPieSeries_insert},
    {sipName_isEmpty, meth_QtCharts_QPieSeries_isEmpty, METH_VARARGS, doc_QtCharts_QPieSeries_isEmpty},
    {sipName_pieEndAngle, meth_QtCharts_QPieSeries_pieEndAngle, METH_VARARGS, doc_QtCharts_QPieSeries_pieEndAngle},
    {sipName_pieSize, meth_QtCharts_QPieSeries_pieSize, METH_VARARGS, doc_QtCharts_QPieSeries_pieSize},
    {sipName_pieStartAngle, meth_QtCharts_QPieSeries_pieStartAngle, METH_VARARGS, doc_QtCharts_QPieSeries_pieStartAngle},
    {sipName_remove, meth_QtCharts_QPieSeries_remove, METH_VARARGS, doc_QtCharts_QPieSeries_remove},
    {sipName_setHoleSize, meth_QtCharts_QPieSeries_setHoleSize, METH_VARARGS, doc_QtCharts_QPieSeries_setHoleSize},
    {sipName_setHorizontalPosition, meth_QtCharts_QPieSeries_setHorizontalPosition, METH_VARARGS, doc_QtCharts_QPieSeries_setHorizontalPosition},
    {sipName_setLabelsPosition, meth_QtCharts_QPieSeries_setLabelsPosition, METH_VARARGS, doc_QtCharts_QPieSeries_setLabelsPosition},
    {sipName_setLabelsVisible, SIP_MLMETH_CAST(meth_QtCharts_QPieSeries_setLabelsVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QPieSeries_setLabelsVisible},
    {sipName_setPieEndAngle, meth_QtCharts_QPieSeries_setPieEndAngle, METH_VARARGS, doc_QtCharts_QPieSeries_setPieEndAngle},
    {sipName_setPieSize, meth_QtCharts_QPieSeries_setPieSize, METH_VARARGS, doc_QtCharts_QPieSeries_setPieSize},
    {sipName_setPieStartAngle, meth_QtCharts_QPieSeries_setPieStartAngle, METH_VARARGS, doc_QtCharts_QPieSeries_setPieStartAngle},
    {sipName_setVerticalPosition, meth_QtCharts_QPieSeries_setVerticalPosition, METH_VARARGS, doc_QtCharts_QPieSeries_setVerticalPosition},
    {sipName_slices, meth_QtCharts_QPieSeries_slices, METH_VARARGS, doc_QtCharts_QPieSeries_slices},
    {sipName_sum, meth_QtCharts_QPieSeries_sum, METH_VARARGS, doc_QtCharts_QPieSeries_sum},
    {sipName_take, meth_QtCharts_QPieSeries_take, METH_VARARGS, doc_QtCharts_QPieSeries_take},
    {sipName_type, meth_QtCharts_QPieSeries_type, METH_VARARGS, doc_QtCharts_QPieSeries_type},
    {sipName_verticalPosition, meth_QtCharts_QPieSeries_verticalPosition, METH_VARARGS, doc_QtCharts_QPieSeries_verticalPosition}
};

PyDoc_STRVAR(doc_QtCharts_QPieSeries, "\1QPieSeries(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QPieSeries[] = {
    {"doubleClicked(QPieSlice*)|(QtCharts::QPieSlice*)", "\1doubleClicked(self, slice: QPieSlice|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"released(QPieSlice*)|(QtCharts::QPieSlice*)", "\1released(self, slice: QPieSlice|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed(QPieSlice*)|(QtCharts::QPieSlice*)", "\1pressed(self, slice: QPieSlice|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"sumChanged()", "\1sumChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"countChanged()", "\1countChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(QPieSlice*,bool)|(QtCharts::QPieSlice*,bool)", "\1hovered(self, slice: QPieSlice|None, state: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked(QPieSlice*)|(QtCharts::QPieSlice*)", "\1clicked(self, slice: QPieSlice|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"removed(QList<QPieSlice*>)|(QList<QtCharts::QPieSlice*>)", "\1removed(self, slices: Iterable[QPieSlice])", SIP_NULLPTR, SIP_NULLPTR},
    {"added(QList<QPieSlice*>)|(QList<QtCharts::QPieSlice*>)", "\1added(self, slices: Iterable[QPieSlice])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QPieSeries = {
    &::QtCharts::QPieSeries::staticMetaObject,
    0,
    signals_QtCharts_QPieSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPieSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QPieSeries,
        SIP_NULLPTR,
        &plugin_QtCharts_QPieSeries,
    },
    {
        sipNameNr_QPieSeries,
        {0, 0, 1},
        24, methods_QtCharts_QPieSeries,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QPieSeries,
    -1,
    -1,
    supers_QtCharts_QPieSeries,
    slots_QtCharts_QPieSeries,
    init_type_QtCharts_QPieSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QPieSeries,
    SIP_NULLPTR,
    array_QtCharts_QPieSeries,
    SIP_NULLPTR,
    release_QtCharts_QPieSeries,
    cast_QtCharts_QPieSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QPieSeries,
    sizeof (::QtCharts::QPieSeries),
};
