/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 89 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 151 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 160 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 163 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 166 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 169 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 172 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 177 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 180 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 183 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 186 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 189 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 192 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 195 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 198 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 201 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 204 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 207 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 210 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 213 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 216 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 219 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 222 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegendMarker.cpp"


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_type, "type(self) -> QLegendMarker.LegendMarkerType");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_type(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            ::QtCharts::QLegendMarker::LegendMarkerType sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QLegendMarker, sipName_type);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QLegendMarker_LegendMarkerType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_type, doc_QtCharts_QLegendMarker_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_label, "label(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_label(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_label(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->label());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_label, doc_QtCharts_QLegendMarker_label);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_setLabel, "setLabel(self, label: str|None)");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_setLabel(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_setLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLabel(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_setLabel, doc_QtCharts_QLegendMarker_setLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_labelBrush, "labelBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_labelBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_labelBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->labelBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_labelBrush, doc_QtCharts_QLegendMarker_labelBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_setLabelBrush, "setLabelBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_setLabelBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_setLabelBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setLabelBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_setLabelBrush, doc_QtCharts_QLegendMarker_setLabelBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_font, "font(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_font(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_font(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->font());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_font, doc_QtCharts_QLegendMarker_font);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_setFont, "setFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_setFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_setFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_setFont, doc_QtCharts_QLegendMarker_setFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_pen, doc_QtCharts_QLegendMarker_pen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_setPen, doc_QtCharts_QLegendMarker_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_brush, doc_QtCharts_QLegendMarker_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_setBrush, doc_QtCharts_QLegendMarker_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_isVisible, "isVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_isVisible, doc_QtCharts_QLegendMarker_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_setVisible, "setVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp, &a0))
        {
            sipCpp->setVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_setVisible, doc_QtCharts_QLegendMarker_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_series, "series(self) -> QAbstractSeries|None");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_series(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_series(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            ::QtCharts::QAbstractSeries*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QLegendMarker, sipName_series);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->series();

            return sipConvertFromType(sipRes, sipType_QtCharts_QAbstractSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_series, doc_QtCharts_QLegendMarker_series);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_shape, "shape(self) -> QLegend.MarkerShape");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_shape(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_shape(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp))
        {
            ::QtCharts::QLegend::MarkerShape sipRes;

            sipRes = sipCpp->shape();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QLegend_MarkerShape);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_shape, doc_QtCharts_QLegendMarker_shape);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegendMarker_setShape, "setShape(self, shape: QLegend.MarkerShape)");

extern "C" {static PyObject *meth_QtCharts_QLegendMarker_setShape(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegendMarker_setShape(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLegend::MarkerShape a0;
        ::QtCharts::QLegendMarker *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtCharts_QLegendMarker, &sipCpp, sipType_QtCharts_QLegend_MarkerShape, &a0))
        {
            sipCpp->setShape(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegendMarker, sipName_setShape, doc_QtCharts_QLegendMarker_setShape);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QLegendMarker(void *, const sipTypeDef *);}
static void *cast_QtCharts_QLegendMarker(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QLegendMarker *sipCpp = reinterpret_cast< ::QtCharts::QLegendMarker *>(sipCppV);

    if (targetType == sipType_QtCharts_QLegendMarker)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QLegendMarker(void *, int);}
static void release_QtCharts_QLegendMarker(void *sipCppV, int)
{
    ::QtCharts::QLegendMarker *sipCpp = reinterpret_cast< ::QtCharts::QLegendMarker *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtCharts_QLegendMarker(sipSimpleWrapper *);}
static void dealloc_QtCharts_QLegendMarker(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QLegendMarker(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QLegendMarker[] = {{10, 0, 1}};


static PyMethodDef methods_QtCharts_QLegendMarker[] = {
    {sipName_brush, meth_QtCharts_QLegendMarker_brush, METH_VARARGS, doc_QtCharts_QLegendMarker_brush},
    {sipName_font, meth_QtCharts_QLegendMarker_font, METH_VARARGS, doc_QtCharts_QLegendMarker_font},
    {sipName_isVisible, meth_QtCharts_QLegendMarker_isVisible, METH_VARARGS, doc_QtCharts_QLegendMarker_isVisible},
    {sipName_label, meth_QtCharts_QLegendMarker_label, METH_VARARGS, doc_QtCharts_QLegendMarker_label},
    {sipName_labelBrush, meth_QtCharts_QLegendMarker_labelBrush, METH_VARARGS, doc_QtCharts_QLegendMarker_labelBrush},
    {sipName_pen, meth_QtCharts_QLegendMarker_pen, METH_VARARGS, doc_QtCharts_QLegendMarker_pen},
    {sipName_series, meth_QtCharts_QLegendMarker_series, METH_VARARGS, doc_QtCharts_QLegendMarker_series},
    {sipName_setBrush, meth_QtCharts_QLegendMarker_setBrush, METH_VARARGS, doc_QtCharts_QLegendMarker_setBrush},
    {sipName_setFont, meth_QtCharts_QLegendMarker_setFont, METH_VARARGS, doc_QtCharts_QLegendMarker_setFont},
    {sipName_setLabel, meth_QtCharts_QLegendMarker_setLabel, METH_VARARGS, doc_QtCharts_QLegendMarker_setLabel},
    {sipName_setLabelBrush, meth_QtCharts_QLegendMarker_setLabelBrush, METH_VARARGS, doc_QtCharts_QLegendMarker_setLabelBrush},
    {sipName_setPen, meth_QtCharts_QLegendMarker_setPen, METH_VARARGS, doc_QtCharts_QLegendMarker_setPen},
    {sipName_setShape, meth_QtCharts_QLegendMarker_setShape, METH_VARARGS, doc_QtCharts_QLegendMarker_setShape},
    {sipName_setVisible, meth_QtCharts_QLegendMarker_setVisible, METH_VARARGS, doc_QtCharts_QLegendMarker_setVisible},
    {sipName_shape, meth_QtCharts_QLegendMarker_shape, METH_VARARGS, doc_QtCharts_QLegendMarker_shape},
    {sipName_type, meth_QtCharts_QLegendMarker_type, METH_VARARGS, doc_QtCharts_QLegendMarker_type}
};

static sipEnumMemberDef enummembers_QtCharts_QLegendMarker[] = {
    {sipName_LegendMarkerTypeArea, static_cast<int>(::QtCharts::QLegendMarker::LegendMarkerTypeArea), 51},
    {sipName_LegendMarkerTypeBar, static_cast<int>(::QtCharts::QLegendMarker::LegendMarkerTypeBar), 51},
    {sipName_LegendMarkerTypeBoxPlot, static_cast<int>(::QtCharts::QLegendMarker::LegendMarkerTypeBoxPlot), 51},
    {sipName_LegendMarkerTypeCandlestick, static_cast<int>(::QtCharts::QLegendMarker::LegendMarkerTypeCandlestick), 51},
    {sipName_LegendMarkerTypePie, static_cast<int>(::QtCharts::QLegendMarker::LegendMarkerTypePie), 51},
    {sipName_LegendMarkerTypeXY, static_cast<int>(::QtCharts::QLegendMarker::LegendMarkerTypeXY), 51},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QLegendMarker[] = {
    {"shapeChanged()", "\1shapeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"visibleChanged()", "\1visibleChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"brushChanged()", "\1brushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"penChanged()", "\1penChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"fontChanged()", "\1fontChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelBrushChanged()", "\1labelBrushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelChanged()", "\1labelChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(bool)", "\1hovered(self, status: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked()", "\1clicked(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QLegendMarker = {
    &::QtCharts::QLegendMarker::staticMetaObject,
    0,
    signals_QtCharts_QLegendMarker,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QLegendMarker = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QLegendMarker,
        SIP_NULLPTR,
        &plugin_QtCharts_QLegendMarker,
    },
    {
        sipNameNr_QLegendMarker,
        {0, 0, 1},
        16, methods_QtCharts_QLegendMarker,
        6, enummembers_QtCharts_QLegendMarker,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtCharts_QLegendMarker,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QLegendMarker,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtCharts_QLegendMarker,
    cast_QtCharts_QLegendMarker,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
