/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 33 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 55 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 58 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 61 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 64 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 69 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 108 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 117 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 122 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 125 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 128 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 131 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 134 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 137 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 140 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 143 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 146 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 149 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 152 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 155 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 158 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 161 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 164 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 167 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_setBarWidth, "setBarWidth(self, width: float)");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_setBarWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_setBarWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, &a0))
        {
            sipCpp->setBarWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_setBarWidth, doc_QtCharts_QAbstractBarSeries_setBarWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_barWidth, "barWidth(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_barWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_barWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->barWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_barWidth, doc_QtCharts_QAbstractBarSeries_barWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_append, "append(self, set: QBarSet|None) -> bool\n"
"append(self, sets: Iterable[QBarSet]) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_append(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_append(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBarSet* a0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, sipType_QtCharts_QBarSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->append(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        QList< ::QtCharts::QBarSet*>* a0;
        int a0State = 0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, sipType_QList_0101QtCharts_QBarSet, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->append(*a0);
            sipReleaseType(a0, sipType_QList_0101QtCharts_QBarSet, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_append, doc_QtCharts_QAbstractBarSeries_append);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_remove, "remove(self, set: QBarSet|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_remove(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_remove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBarSet* a0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, sipType_QtCharts_QBarSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->remove(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_remove, doc_QtCharts_QAbstractBarSeries_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_insert, "insert(self, index: int, set: QBarSet|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_insert(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_insert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QBarSet* a1;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, &a0, sipType_QtCharts_QBarSet, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->insert(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_insert, doc_QtCharts_QAbstractBarSeries_insert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_count, "count(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_count(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_count, doc_QtCharts_QAbstractBarSeries_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_barSets, "barSets(self) -> list[QBarSet]");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_barSets(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_barSets(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            QList< ::QtCharts::QBarSet*>*sipRes;

            sipRes = new QList< ::QtCharts::QBarSet*>(sipCpp->barSets());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtCharts_QBarSet, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_barSets, doc_QtCharts_QAbstractBarSeries_barSets);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_clear, "clear(self)");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_clear(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_clear, doc_QtCharts_QAbstractBarSeries_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_setLabelsVisible, "setLabelsVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, &a0))
        {
            sipCpp->setLabelsVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_setLabelsVisible, doc_QtCharts_QAbstractBarSeries_setLabelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_isLabelsVisible, "isLabelsVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_isLabelsVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_isLabelsVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLabelsVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_isLabelsVisible, doc_QtCharts_QAbstractBarSeries_isLabelsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_take, "take(self, set: QBarSet|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_take(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_take(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBarSet* a0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, sipType_QtCharts_QBarSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->take(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_take, doc_QtCharts_QAbstractBarSeries_take);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_setLabelsFormat, "setLabelsFormat(self, format: str|None)");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsFormat(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLabelsFormat(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_setLabelsFormat, doc_QtCharts_QAbstractBarSeries_setLabelsFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_labelsFormat, "labelsFormat(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_labelsFormat(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_labelsFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->labelsFormat());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_labelsFormat, doc_QtCharts_QAbstractBarSeries_labelsFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_setLabelsPosition, "setLabelsPosition(self, position: QAbstractBarSeries.LabelsPosition)");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractBarSeries::LabelsPosition a0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, sipType_QtCharts_QAbstractBarSeries_LabelsPosition, &a0))
        {
            sipCpp->setLabelsPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_setLabelsPosition, doc_QtCharts_QAbstractBarSeries_setLabelsPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_labelsPosition, "labelsPosition(self) -> QAbstractBarSeries.LabelsPosition");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_labelsPosition(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_labelsPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            ::QtCharts::QAbstractBarSeries::LabelsPosition sipRes;

            sipRes = sipCpp->labelsPosition();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QAbstractBarSeries_LabelsPosition);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_labelsPosition, doc_QtCharts_QAbstractBarSeries_labelsPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_setLabelsAngle, "setLabelsAngle(self, angle: float)");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, &a0))
        {
            sipCpp->setLabelsAngle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_setLabelsAngle, doc_QtCharts_QAbstractBarSeries_setLabelsAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_labelsAngle, "labelsAngle(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_labelsAngle(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_labelsAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->labelsAngle();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_labelsAngle, doc_QtCharts_QAbstractBarSeries_labelsAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_setLabelsPrecision, "setLabelsPrecision(self, precision: int)");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsPrecision(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_setLabelsPrecision(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp, &a0))
        {
            sipCpp->setLabelsPrecision(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_setLabelsPrecision, doc_QtCharts_QAbstractBarSeries_setLabelsPrecision);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractBarSeries_labelsPrecision, "labelsPrecision(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QAbstractBarSeries_labelsPrecision(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractBarSeries_labelsPrecision(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractBarSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractBarSeries, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->labelsPrecision();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractBarSeries, sipName_labelsPrecision, doc_QtCharts_QAbstractBarSeries_labelsPrecision);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QtCharts_QAbstractBarSeries___len__(PyObject *);}
static Py_ssize_t slot_QtCharts_QAbstractBarSeries___len__(PyObject *sipSelf)
{
    ::QtCharts::QAbstractBarSeries *sipCpp = reinterpret_cast< ::QtCharts::QAbstractBarSeries *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QAbstractBarSeries));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 706 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractBarSeries.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QAbstractBarSeries(void *, const sipTypeDef *);}
static void *cast_QtCharts_QAbstractBarSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QAbstractBarSeries *sipCpp = reinterpret_cast< ::QtCharts::QAbstractBarSeries *>(sipCppV);

    if (targetType == sipType_QtCharts_QAbstractBarSeries)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtCharts_QAbstractSeries)->ctd_cast(static_cast< ::QtCharts::QAbstractSeries *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QAbstractBarSeries(void *, int);}
static void release_QtCharts_QAbstractBarSeries(void *sipCppV, int)
{
    ::QtCharts::QAbstractBarSeries *sipCpp = reinterpret_cast< ::QtCharts::QAbstractBarSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtCharts_QAbstractBarSeries(sipSimpleWrapper *);}
static void dealloc_QtCharts_QAbstractBarSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QAbstractBarSeries(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QAbstractBarSeries[] = {{13, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QtCharts_QAbstractBarSeries[] = {
    {(void *)slot_QtCharts_QAbstractBarSeries___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QtCharts_QAbstractBarSeries[] = {
    {sipName_append, meth_QtCharts_QAbstractBarSeries_append, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_append},
    {sipName_barSets, meth_QtCharts_QAbstractBarSeries_barSets, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_barSets},
    {sipName_barWidth, meth_QtCharts_QAbstractBarSeries_barWidth, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_barWidth},
    {sipName_clear, meth_QtCharts_QAbstractBarSeries_clear, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_clear},
    {sipName_count, meth_QtCharts_QAbstractBarSeries_count, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_count},
    {sipName_insert, meth_QtCharts_QAbstractBarSeries_insert, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_insert},
    {sipName_isLabelsVisible, meth_QtCharts_QAbstractBarSeries_isLabelsVisible, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_isLabelsVisible},
    {sipName_labelsAngle, meth_QtCharts_QAbstractBarSeries_labelsAngle, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_labelsAngle},
    {sipName_labelsFormat, meth_QtCharts_QAbstractBarSeries_labelsFormat, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_labelsFormat},
    {sipName_labelsPosition, meth_QtCharts_QAbstractBarSeries_labelsPosition, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_labelsPosition},
    {sipName_labelsPrecision, meth_QtCharts_QAbstractBarSeries_labelsPrecision, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_labelsPrecision},
    {sipName_remove, meth_QtCharts_QAbstractBarSeries_remove, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_remove},
    {sipName_setBarWidth, meth_QtCharts_QAbstractBarSeries_setBarWidth, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_setBarWidth},
    {sipName_setLabelsAngle, meth_QtCharts_QAbstractBarSeries_setLabelsAngle, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_setLabelsAngle},
    {sipName_setLabelsFormat, meth_QtCharts_QAbstractBarSeries_setLabelsFormat, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_setLabelsFormat},
    {sipName_setLabelsPosition, meth_QtCharts_QAbstractBarSeries_setLabelsPosition, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_setLabelsPosition},
    {sipName_setLabelsPrecision, meth_QtCharts_QAbstractBarSeries_setLabelsPrecision, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_setLabelsPrecision},
    {sipName_setLabelsVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractBarSeries_setLabelsVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractBarSeries_setLabelsVisible},
    {sipName_take, meth_QtCharts_QAbstractBarSeries_take, METH_VARARGS, doc_QtCharts_QAbstractBarSeries_take}
};

static sipEnumMemberDef enummembers_QtCharts_QAbstractBarSeries[] = {
    {sipName_LabelsCenter, static_cast<int>(::QtCharts::QAbstractBarSeries::LabelsCenter), 12},
    {sipName_LabelsInsideBase, static_cast<int>(::QtCharts::QAbstractBarSeries::LabelsInsideBase), 12},
    {sipName_LabelsInsideEnd, static_cast<int>(::QtCharts::QAbstractBarSeries::LabelsInsideEnd), 12},
    {sipName_LabelsOutsideEnd, static_cast<int>(::QtCharts::QAbstractBarSeries::LabelsOutsideEnd), 12},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QAbstractBarSeries[] = {
    {"labelsPrecisionChanged(int)", "\1labelsPrecisionChanged(self, precision: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsAngleChanged(qreal)", "\1labelsAngleChanged(self, angle: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"doubleClicked(int,QBarSet*)|(int,QtCharts::QBarSet*)", "\1doubleClicked(self, index: int, barset: QBarSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"released(int,QBarSet*)|(int,QtCharts::QBarSet*)", "\1released(self, index: int, barset: QBarSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed(int,QBarSet*)|(int,QtCharts::QBarSet*)", "\1pressed(self, index: int, barset: QBarSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsPositionChanged(QAbstractBarSeries::LabelsPosition)|(QtCharts::QAbstractBarSeries::LabelsPosition)", "\1labelsPositionChanged(self, position: QAbstractBarSeries.LabelsPosition)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsFormatChanged(QString)", "\1labelsFormatChanged(self, format: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"barsetsRemoved(QList<QBarSet*>)|(QList<QtCharts::QBarSet*>)", "\1barsetsRemoved(self, sets: Iterable[QBarSet])", SIP_NULLPTR, SIP_NULLPTR},
    {"barsetsAdded(QList<QBarSet*>)|(QList<QtCharts::QBarSet*>)", "\1barsetsAdded(self, sets: Iterable[QBarSet])", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsVisibleChanged()", "\1labelsVisibleChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"countChanged()", "\1countChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(bool,int,QBarSet*)|(bool,int,QtCharts::QBarSet*)", "\1hovered(self, status: bool, index: int, barset: QBarSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked(int,QBarSet*)|(int,QtCharts::QBarSet*)", "\1clicked(self, index: int, barset: QBarSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QAbstractBarSeries = {
    &::QtCharts::QAbstractBarSeries::staticMetaObject,
    0,
    signals_QtCharts_QAbstractBarSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAbstractBarSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QAbstractBarSeries,
        SIP_NULLPTR,
        &plugin_QtCharts_QAbstractBarSeries,
    },
    {
        sipNameNr_QAbstractBarSeries,
        {0, 0, 1},
        19, methods_QtCharts_QAbstractBarSeries,
        4, enummembers_QtCharts_QAbstractBarSeries,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtCharts_QAbstractBarSeries,
    slots_QtCharts_QAbstractBarSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QAbstractBarSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtCharts_QAbstractBarSeries,
    cast_QtCharts_QAbstractBarSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
