/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 53 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"

#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 57 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 60 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 63 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 66 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 751 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 69 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 74 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 77 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 89 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 101 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 104 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 107 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 110 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 113 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 116 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"


class sipQtCharts_QBoxSet : public ::QtCharts::QBoxSet
{
public:
    sipQtCharts_QBoxSet(const ::QString, ::QObject*);
    sipQtCharts_QBoxSet(const ::qreal, const ::qreal, const ::qreal, const ::qreal, const ::qreal, const ::QString, ::QObject*);
    virtual ~sipQtCharts_QBoxSet();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QBoxSet(const sipQtCharts_QBoxSet &);
    sipQtCharts_QBoxSet &operator = (const sipQtCharts_QBoxSet &);

    char sipPyMethods[7];
};

sipQtCharts_QBoxSet::sipQtCharts_QBoxSet(const ::QString a0, ::QObject*a1): ::QtCharts::QBoxSet(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QBoxSet::sipQtCharts_QBoxSet(const ::qreal a0, const ::qreal a1, const ::qreal a2, const ::qreal a3, const ::qreal a4, const ::QString a5, ::QObject*a6): ::QtCharts::QBoxSet(a0, a1, a2, a3, a4, a5, a6), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QBoxSet::~sipQtCharts_QBoxSet()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QBoxSet::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QBoxSet);

    return ::QtCharts::QBoxSet::metaObject();
}

int sipQtCharts_QBoxSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QBoxSet::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QBoxSet, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QBoxSet::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QBoxSet, _clname, &sipCpp) ? sipCpp : ::QtCharts::QBoxSet::qt_metacast(_clname));
}

bool sipQtCharts_QBoxSet::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QBoxSet::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QBoxSet::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QBoxSet::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QBoxSet::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBoxSet::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBoxSet::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBoxSet::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBoxSet::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBoxSet::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBoxSet::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QBoxSet::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBoxSet::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QBoxSet::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_append, "append(self, value: float)\n"
"append(self, values: Iterable[float])");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_append(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_append(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp, &a0))
        {
            sipCpp->append(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QList< ::qreal>* a0;
        int a0State = 0;
        ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp, sipType_QList_2400, &a0, &a0State))
        {
            sipCpp->append(*a0);
            sipReleaseType(const_cast< ::QList< ::qreal> *>(a0), sipType_QList_2400, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_append, doc_QtCharts_QBoxSet_append);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_clear, "clear(self)");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_clear(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_clear, doc_QtCharts_QBoxSet_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_setLabel, "setLabel(self, label: str|None)");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_setLabel(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_setLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLabel(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_setLabel, doc_QtCharts_QBoxSet_setLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_label, "label(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_label(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_label(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->label());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_label, doc_QtCharts_QBoxSet_label);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_setValue, "setValue(self, index: int, value: float)");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_setValue(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_setValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::qreal a1;
        ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bid", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp, &a0, &a1))
        {
            sipCpp->setValue(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_setValue, doc_QtCharts_QBoxSet_setValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_at, "at(self, index: int) -> float");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_at(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_at(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp, &a0))
        {
            ::qreal sipRes;

            sipRes = sipCpp->at(a0);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_at, doc_QtCharts_QBoxSet_at);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_count, "count(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_count(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_count, doc_QtCharts_QBoxSet_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_setPen, doc_QtCharts_QBoxSet_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_pen, doc_QtCharts_QBoxSet_pen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_setBrush, doc_QtCharts_QBoxSet_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxSet_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QBoxSet_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxSet_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBoxSet *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxSet, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName_brush, doc_QtCharts_QBoxSet_brush);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QtCharts_QBoxSet___len__(PyObject *);}
static Py_ssize_t slot_QtCharts_QBoxSet___len__(PyObject *sipSelf)
{
    ::QtCharts::QBoxSet *sipCpp = reinterpret_cast< ::QtCharts::QBoxSet *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QBoxSet));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 642 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxSet.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtCharts_QBoxSet___getitem__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QBoxSet___getitem__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QtCharts::QBoxSet *sipCpp = reinterpret_cast< ::QtCharts::QBoxSet *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QBoxSet));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            ::qreal sipRes;

            if (a0 < 0 || a0 >= sipCpp->count())
            {
                PyErr_SetNone(PyExc_IndexError);
                return SIP_NULLPTR;
            }

            sipRes = (*sipCpp)[a0];

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxSet, sipName___getitem__, SIP_NULLPTR);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QtCharts_QBoxSet___lshift__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QBoxSet___lshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBoxSet* a0;
        ::qreal a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9d", sipType_QtCharts_QBoxSet, &a0, &a1))
        {
            ::QtCharts::QBoxSet*sipRes;

            sipRes = &(*a0 << a1);

            return sipConvertFromType(sipRes, sipType_QtCharts_QBoxSet, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtChart, lshift_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QBoxSet(void *, const sipTypeDef *);}
static void *cast_QtCharts_QBoxSet(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QBoxSet *sipCpp = reinterpret_cast< ::QtCharts::QBoxSet *>(sipCppV);

    if (targetType == sipType_QtCharts_QBoxSet)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QBoxSet(void *, int);}
static void release_QtCharts_QBoxSet(void *sipCppV, int)
{
    ::QtCharts::QBoxSet *sipCpp = reinterpret_cast< ::QtCharts::QBoxSet *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QBoxSet(Py_ssize_t);}
static void *array_QtCharts_QBoxSet(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QBoxSet[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QBoxSet(void *);}
static void array_delete_QtCharts_QBoxSet(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QBoxSet *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QBoxSet(sipSimpleWrapper *);}
static void dealloc_QtCharts_QBoxSet(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QBoxSet *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QBoxSet(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QBoxSet(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QBoxSet(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QBoxSet *sipCpp = SIP_NULLPTR;

    {
        const ::QString a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            sipName_label,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J1JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQtCharts_QBoxSet(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::qreal a2;
        ::qreal a3;
        ::qreal a4;
        const ::QString a5def = QString();
        const ::QString* a5 = &a5def;
        int a5State = 0;
        ::QObject* a6 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_label,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "ddddd|J1JH", &a0, &a1, &a2, &a3, &a4, sipType_QString, &a5, &a5State, sipType_QObject, &a6, sipOwner))
        {
            sipCpp = new sipQtCharts_QBoxSet(a0, a1, a2, a3, a4, *a5, a6);
            sipReleaseType(const_cast< ::QString *>(a5), sipType_QString, a5State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QBoxSet[] = {{10, 0, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QtCharts_QBoxSet[] = {
    {(void *)slot_QtCharts_QBoxSet___len__, len_slot},
    {(void *)slot_QtCharts_QBoxSet___getitem__, getitem_slot},
    {(void *)slot_QtCharts_QBoxSet___lshift__, lshift_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QtCharts_QBoxSet[] = {
    {sipName_append, meth_QtCharts_QBoxSet_append, METH_VARARGS, doc_QtCharts_QBoxSet_append},
    {sipName_at, meth_QtCharts_QBoxSet_at, METH_VARARGS, doc_QtCharts_QBoxSet_at},
    {sipName_brush, meth_QtCharts_QBoxSet_brush, METH_VARARGS, doc_QtCharts_QBoxSet_brush},
    {sipName_clear, meth_QtCharts_QBoxSet_clear, METH_VARARGS, doc_QtCharts_QBoxSet_clear},
    {sipName_count, meth_QtCharts_QBoxSet_count, METH_VARARGS, doc_QtCharts_QBoxSet_count},
    {sipName_label, meth_QtCharts_QBoxSet_label, METH_VARARGS, doc_QtCharts_QBoxSet_label},
    {sipName_pen, meth_QtCharts_QBoxSet_pen, METH_VARARGS, doc_QtCharts_QBoxSet_pen},
    {sipName_setBrush, meth_QtCharts_QBoxSet_setBrush, METH_VARARGS, doc_QtCharts_QBoxSet_setBrush},
    {sipName_setLabel, meth_QtCharts_QBoxSet_setLabel, METH_VARARGS, doc_QtCharts_QBoxSet_setLabel},
    {sipName_setPen, meth_QtCharts_QBoxSet_setPen, METH_VARARGS, doc_QtCharts_QBoxSet_setPen},
    {sipName_setValue, meth_QtCharts_QBoxSet_setValue, METH_VARARGS, doc_QtCharts_QBoxSet_setValue}
};

static sipEnumMemberDef enummembers_QtCharts_QBoxSet[] = {
    {sipName_LowerExtreme, static_cast<int>(::QtCharts::QBoxSet::LowerExtreme), 24},
    {sipName_LowerQuartile, static_cast<int>(::QtCharts::QBoxSet::LowerQuartile), 24},
    {sipName_Median, static_cast<int>(::QtCharts::QBoxSet::Median), 24},
    {sipName_UpperExtreme, static_cast<int>(::QtCharts::QBoxSet::UpperExtreme), 24},
    {sipName_UpperQuartile, static_cast<int>(::QtCharts::QBoxSet::UpperQuartile), 24},
};

PyDoc_STRVAR(doc_QtCharts_QBoxSet, "\1QBoxSet(label: str|None = '', parent: QObject|None = None)\n"
"QBoxSet(le: float, lq: float, m: float, uq: float, ue: float, label: str|None = '', parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QBoxSet[] = {
    {"doubleClicked()", "\1doubleClicked(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"released()", "\1released(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed()", "\1pressed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"cleared()", "\1cleared(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"valueChanged(int)", "\1valueChanged(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"valuesChanged()", "\1valuesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"brushChanged()", "\1brushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"penChanged()", "\1penChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(bool)", "\1hovered(self, status: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked()", "\1clicked(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QBoxSet = {
    &::QtCharts::QBoxSet::staticMetaObject,
    0,
    signals_QtCharts_QBoxSet,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBoxSet = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QBoxSet,
        SIP_NULLPTR,
        &plugin_QtCharts_QBoxSet,
    },
    {
        sipNameNr_QBoxSet,
        {0, 0, 1},
        11, methods_QtCharts_QBoxSet,
        5, enummembers_QtCharts_QBoxSet,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QBoxSet,
    -1,
    -1,
    supers_QtCharts_QBoxSet,
    slots_QtCharts_QBoxSet,
    init_type_QtCharts_QBoxSet,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QBoxSet,
    SIP_NULLPTR,
    array_QtCharts_QBoxSet,
    SIP_NULLPTR,
    release_QtCharts_QBoxSet,
    cast_QtCharts_QBoxSet,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QBoxSet,
    sizeof (::QtCharts::QBoxSet),
};
