/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 59 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 63 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 66 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 101 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 104 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 107 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 110 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 119 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 122 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 127 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 166 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 169 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 174 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 177 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 180 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 183 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 186 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 189 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 192 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 195 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 198 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 201 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 204 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 207 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 210 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 213 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 216 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"


class sipQtCharts_QCandlestickSeries : public ::QtCharts::QCandlestickSeries
{
public:
    sipQtCharts_QCandlestickSeries(::QObject*);
    virtual ~sipQtCharts_QCandlestickSeries();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QtCharts::QAbstractSeries::SeriesType type() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QCandlestickSeries(const sipQtCharts_QCandlestickSeries &);
    sipQtCharts_QCandlestickSeries &operator = (const sipQtCharts_QCandlestickSeries &);

    char sipPyMethods[8];
};

sipQtCharts_QCandlestickSeries::sipQtCharts_QCandlestickSeries(::QObject*a0): ::QtCharts::QCandlestickSeries(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QCandlestickSeries::~sipQtCharts_QCandlestickSeries()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QCandlestickSeries::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QCandlestickSeries);

    return ::QtCharts::QCandlestickSeries::metaObject();
}

int sipQtCharts_QCandlestickSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QCandlestickSeries::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QCandlestickSeries, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QCandlestickSeries::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QCandlestickSeries, _clname, &sipCpp) ? sipCpp : ::QtCharts::QCandlestickSeries::qt_metacast(_clname));
}

void sipQtCharts_QCandlestickSeries::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSeries::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QCandlestickSeries::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSeries::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QCandlestickSeries::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSeries::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QCandlestickSeries::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSeries::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QCandlestickSeries::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QCandlestickSeries::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QCandlestickSeries::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QCandlestickSeries::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtCharts_QCandlestickSeries::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QCandlestickSeries::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QtCharts::QAbstractSeries::SeriesType sipQtCharts_QCandlestickSeries::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QtCharts::QCandlestickSeries::type();

    extern ::QtCharts::QAbstractSeries::SeriesType sipVH_QtChart_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_7(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_append, "append(self, set: QCandlestickSet|None) -> bool\n"
"append(self, sets: Iterable[QCandlestickSet]) -> bool");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_append(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_append(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QCandlestickSet* a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QtCharts_QCandlestickSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->append(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const QList< ::QtCharts::QCandlestickSet*>* a0;
        int a0State = 0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QList_0101QtCharts_QCandlestickSet, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->append(*a0);
            sipReleaseType(const_cast<QList< ::QtCharts::QCandlestickSet*> *>(a0), sipType_QList_0101QtCharts_QCandlestickSet, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_append, doc_QtCharts_QCandlestickSeries_append);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_remove, "remove(self, set: QCandlestickSet|None) -> bool\n"
"remove(self, sets: Iterable[QCandlestickSet]) -> bool");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_remove(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_remove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QCandlestickSet* a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QtCharts_QCandlestickSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->remove(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const QList< ::QtCharts::QCandlestickSet*>* a0;
        int a0State = 0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QList_0101QtCharts_QCandlestickSet, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->remove(*a0);
            sipReleaseType(const_cast<QList< ::QtCharts::QCandlestickSet*> *>(a0), sipType_QList_0101QtCharts_QCandlestickSet, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_remove, doc_QtCharts_QCandlestickSeries_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_insert, "insert(self, index: int, set: QCandlestickSet|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_insert(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_insert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QCandlestickSet* a1;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, &a0, sipType_QtCharts_QCandlestickSet, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->insert(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_insert, doc_QtCharts_QCandlestickSeries_insert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_take, "take(self, set: QCandlestickSet|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_take(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_take(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QCandlestickSet* a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QtCharts_QCandlestickSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->take(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_take, doc_QtCharts_QCandlestickSeries_take);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_clear, "clear(self)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_clear(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_clear, doc_QtCharts_QCandlestickSeries_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_sets, "sets(self) -> list[QCandlestickSet]");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_sets(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_sets(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            QList< ::QtCharts::QCandlestickSet*>*sipRes;

            sipRes = new QList< ::QtCharts::QCandlestickSet*>(sipCpp->sets());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtCharts_QCandlestickSet, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_sets, doc_QtCharts_QCandlestickSeries_sets);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_count, "count(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_count(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_count, doc_QtCharts_QCandlestickSeries_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_type, "type(self) -> QAbstractSeries.SeriesType");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_type(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::QtCharts::QAbstractSeries::SeriesType sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtCharts::QCandlestickSeries::type() : sipCpp->type());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QAbstractSeries_SeriesType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_type, doc_QtCharts_QCandlestickSeries_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setMaximumColumnWidth, "setMaximumColumnWidth(self, maximumColumnWidth: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setMaximumColumnWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setMaximumColumnWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, &a0))
        {
            sipCpp->setMaximumColumnWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setMaximumColumnWidth, doc_QtCharts_QCandlestickSeries_setMaximumColumnWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_maximumColumnWidth, "maximumColumnWidth(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_maximumColumnWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_maximumColumnWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->maximumColumnWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_maximumColumnWidth, doc_QtCharts_QCandlestickSeries_maximumColumnWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setMinimumColumnWidth, "setMinimumColumnWidth(self, minimumColumnWidth: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setMinimumColumnWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setMinimumColumnWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, &a0))
        {
            sipCpp->setMinimumColumnWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setMinimumColumnWidth, doc_QtCharts_QCandlestickSeries_setMinimumColumnWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_minimumColumnWidth, "minimumColumnWidth(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_minimumColumnWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_minimumColumnWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->minimumColumnWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_minimumColumnWidth, doc_QtCharts_QCandlestickSeries_minimumColumnWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setBodyWidth, "setBodyWidth(self, bodyWidth: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setBodyWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setBodyWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, &a0))
        {
            sipCpp->setBodyWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setBodyWidth, doc_QtCharts_QCandlestickSeries_setBodyWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_bodyWidth, "bodyWidth(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_bodyWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_bodyWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->bodyWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_bodyWidth, doc_QtCharts_QCandlestickSeries_bodyWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setBodyOutlineVisible, "setBodyOutlineVisible(self, bodyOutlineVisible: bool)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setBodyOutlineVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setBodyOutlineVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, &a0))
        {
            sipCpp->setBodyOutlineVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setBodyOutlineVisible, doc_QtCharts_QCandlestickSeries_setBodyOutlineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_bodyOutlineVisible, "bodyOutlineVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_bodyOutlineVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_bodyOutlineVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->bodyOutlineVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_bodyOutlineVisible, doc_QtCharts_QCandlestickSeries_bodyOutlineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setCapsWidth, "setCapsWidth(self, capsWidth: float)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setCapsWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setCapsWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, &a0))
        {
            sipCpp->setCapsWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setCapsWidth, doc_QtCharts_QCandlestickSeries_setCapsWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_capsWidth, "capsWidth(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_capsWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_capsWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->capsWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_capsWidth, doc_QtCharts_QCandlestickSeries_capsWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setCapsVisible, "setCapsVisible(self, capsVisible: bool)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setCapsVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setCapsVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, &a0))
        {
            sipCpp->setCapsVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setCapsVisible, doc_QtCharts_QCandlestickSeries_setCapsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_capsVisible, "capsVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_capsVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_capsVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->capsVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_capsVisible, doc_QtCharts_QCandlestickSeries_capsVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setIncreasingColor, "setIncreasingColor(self, increasingColor: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setIncreasingColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setIncreasingColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setIncreasingColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setIncreasingColor, doc_QtCharts_QCandlestickSeries_setIncreasingColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_increasingColor, "increasingColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_increasingColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_increasingColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->increasingColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_increasingColor, doc_QtCharts_QCandlestickSeries_increasingColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setDecreasingColor, "setDecreasingColor(self, decreasingColor: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setDecreasingColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setDecreasingColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setDecreasingColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setDecreasingColor, doc_QtCharts_QCandlestickSeries_setDecreasingColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_decreasingColor, "decreasingColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_decreasingColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_decreasingColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->decreasingColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_decreasingColor, doc_QtCharts_QCandlestickSeries_decreasingColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setBrush, doc_QtCharts_QCandlestickSeries_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_brush, doc_QtCharts_QCandlestickSeries_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_setPen, doc_QtCharts_QCandlestickSeries_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QCandlestickSeries_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QCandlestickSeries_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QCandlestickSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QCandlestickSeries, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCandlestickSeries, sipName_pen, doc_QtCharts_QCandlestickSeries_pen);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QtCharts_QCandlestickSeries___len__(PyObject *);}
static Py_ssize_t slot_QtCharts_QCandlestickSeries___len__(PyObject *sipSelf)
{
    ::QtCharts::QCandlestickSeries *sipCpp = reinterpret_cast< ::QtCharts::QCandlestickSeries *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QCandlestickSeries));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 1218 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQCandlestickSeries.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QCandlestickSeries(void *, const sipTypeDef *);}
static void *cast_QtCharts_QCandlestickSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QCandlestickSeries *sipCpp = reinterpret_cast< ::QtCharts::QCandlestickSeries *>(sipCppV);

    if (targetType == sipType_QtCharts_QCandlestickSeries)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtCharts_QAbstractSeries)->ctd_cast(static_cast< ::QtCharts::QAbstractSeries *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QCandlestickSeries(void *, int);}
static void release_QtCharts_QCandlestickSeries(void *sipCppV, int)
{
    ::QtCharts::QCandlestickSeries *sipCpp = reinterpret_cast< ::QtCharts::QCandlestickSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QCandlestickSeries(Py_ssize_t);}
static void *array_QtCharts_QCandlestickSeries(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QCandlestickSeries[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QCandlestickSeries(void *);}
static void array_delete_QtCharts_QCandlestickSeries(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QCandlestickSeries *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QCandlestickSeries(sipSimpleWrapper *);}
static void dealloc_QtCharts_QCandlestickSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QCandlestickSeries *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QCandlestickSeries(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QCandlestickSeries(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QCandlestickSeries(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QCandlestickSeries *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtCharts_QCandlestickSeries(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QCandlestickSeries[] = {{13, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QtCharts_QCandlestickSeries[] = {
    {(void *)slot_QtCharts_QCandlestickSeries___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QtCharts_QCandlestickSeries[] = {
    {sipName_append, meth_QtCharts_QCandlestickSeries_append, METH_VARARGS, doc_QtCharts_QCandlestickSeries_append},
    {sipName_bodyOutlineVisible, meth_QtCharts_QCandlestickSeries_bodyOutlineVisible, METH_VARARGS, doc_QtCharts_QCandlestickSeries_bodyOutlineVisible},
    {sipName_bodyWidth, meth_QtCharts_QCandlestickSeries_bodyWidth, METH_VARARGS, doc_QtCharts_QCandlestickSeries_bodyWidth},
    {sipName_brush, meth_QtCharts_QCandlestickSeries_brush, METH_VARARGS, doc_QtCharts_QCandlestickSeries_brush},
    {sipName_capsVisible, meth_QtCharts_QCandlestickSeries_capsVisible, METH_VARARGS, doc_QtCharts_QCandlestickSeries_capsVisible},
    {sipName_capsWidth, meth_QtCharts_QCandlestickSeries_capsWidth, METH_VARARGS, doc_QtCharts_QCandlestickSeries_capsWidth},
    {sipName_clear, meth_QtCharts_QCandlestickSeries_clear, METH_VARARGS, doc_QtCharts_QCandlestickSeries_clear},
    {sipName_count, meth_QtCharts_QCandlestickSeries_count, METH_VARARGS, doc_QtCharts_QCandlestickSeries_count},
    {sipName_decreasingColor, meth_QtCharts_QCandlestickSeries_decreasingColor, METH_VARARGS, doc_QtCharts_QCandlestickSeries_decreasingColor},
    {sipName_increasingColor, meth_QtCharts_QCandlestickSeries_increasingColor, METH_VARARGS, doc_QtCharts_QCandlestickSeries_increasingColor},
    {sipName_insert, meth_QtCharts_QCandlestickSeries_insert, METH_VARARGS, doc_QtCharts_QCandlestickSeries_insert},
    {sipName_maximumColumnWidth, meth_QtCharts_QCandlestickSeries_maximumColumnWidth, METH_VARARGS, doc_QtCharts_QCandlestickSeries_maximumColumnWidth},
    {sipName_minimumColumnWidth, meth_QtCharts_QCandlestickSeries_minimumColumnWidth, METH_VARARGS, doc_QtCharts_QCandlestickSeries_minimumColumnWidth},
    {sipName_pen, meth_QtCharts_QCandlestickSeries_pen, METH_VARARGS, doc_QtCharts_QCandlestickSeries_pen},
    {sipName_remove, meth_QtCharts_QCandlestickSeries_remove, METH_VARARGS, doc_QtCharts_QCandlestickSeries_remove},
    {sipName_setBodyOutlineVisible, meth_QtCharts_QCandlestickSeries_setBodyOutlineVisible, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setBodyOutlineVisible},
    {sipName_setBodyWidth, meth_QtCharts_QCandlestickSeries_setBodyWidth, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setBodyWidth},
    {sipName_setBrush, meth_QtCharts_QCandlestickSeries_setBrush, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setBrush},
    {sipName_setCapsVisible, meth_QtCharts_QCandlestickSeries_setCapsVisible, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setCapsVisible},
    {sipName_setCapsWidth, meth_QtCharts_QCandlestickSeries_setCapsWidth, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setCapsWidth},
    {sipName_setDecreasingColor, meth_QtCharts_QCandlestickSeries_setDecreasingColor, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setDecreasingColor},
    {sipName_setIncreasingColor, meth_QtCharts_QCandlestickSeries_setIncreasingColor, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setIncreasingColor},
    {sipName_setMaximumColumnWidth, meth_QtCharts_QCandlestickSeries_setMaximumColumnWidth, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setMaximumColumnWidth},
    {sipName_setMinimumColumnWidth, meth_QtCharts_QCandlestickSeries_setMinimumColumnWidth, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setMinimumColumnWidth},
    {sipName_setPen, meth_QtCharts_QCandlestickSeries_setPen, METH_VARARGS, doc_QtCharts_QCandlestickSeries_setPen},
    {sipName_sets, meth_QtCharts_QCandlestickSeries_sets, METH_VARARGS, doc_QtCharts_QCandlestickSeries_sets},
    {sipName_take, meth_QtCharts_QCandlestickSeries_take, METH_VARARGS, doc_QtCharts_QCandlestickSeries_take},
    {sipName_type, meth_QtCharts_QCandlestickSeries_type, METH_VARARGS, doc_QtCharts_QCandlestickSeries_type}
};

PyDoc_STRVAR(doc_QtCharts_QCandlestickSeries, "\1QCandlestickSeries(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QCandlestickSeries[] = {
    {"penChanged()", "\1penChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"brushChanged()", "\1brushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"decreasingColorChanged()", "\1decreasingColorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"increasingColorChanged()", "\1increasingColorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"capsVisibilityChanged()", "\1capsVisibilityChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"capsWidthChanged()", "\1capsWidthChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"bodyOutlineVisibilityChanged()", "\1bodyOutlineVisibilityChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"bodyWidthChanged()", "\1bodyWidthChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"minimumColumnWidthChanged()", "\1minimumColumnWidthChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"maximumColumnWidthChanged()", "\1maximumColumnWidthChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"countChanged()", "\1countChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"candlestickSetsRemoved(QList<QCandlestickSet*>)|(QList<QtCharts::QCandlestickSet*>)", "\1candlestickSetsRemoved(self, sets: Iterable[QCandlestickSet])", SIP_NULLPTR, SIP_NULLPTR},
    {"candlestickSetsAdded(QList<QCandlestickSet*>)|(QList<QtCharts::QCandlestickSet*>)", "\1candlestickSetsAdded(self, sets: Iterable[QCandlestickSet])", SIP_NULLPTR, SIP_NULLPTR},
    {"doubleClicked(QCandlestickSet*)|(QtCharts::QCandlestickSet*)", "\1doubleClicked(self, set: QCandlestickSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"released(QCandlestickSet*)|(QtCharts::QCandlestickSet*)", "\1released(self, set: QCandlestickSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed(QCandlestickSet*)|(QtCharts::QCandlestickSet*)", "\1pressed(self, set: QCandlestickSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(bool,QCandlestickSet*)|(bool,QtCharts::QCandlestickSet*)", "\1hovered(self, status: bool, set: QCandlestickSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked(QCandlestickSet*)|(QtCharts::QCandlestickSet*)", "\1clicked(self, set: QCandlestickSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QCandlestickSeries = {
    &::QtCharts::QCandlestickSeries::staticMetaObject,
    0,
    signals_QtCharts_QCandlestickSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QCandlestickSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QCandlestickSeries,
        SIP_NULLPTR,
        &plugin_QtCharts_QCandlestickSeries,
    },
    {
        sipNameNr_QCandlestickSeries,
        {0, 0, 1},
        28, methods_QtCharts_QCandlestickSeries,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QCandlestickSeries,
    -1,
    -1,
    supers_QtCharts_QCandlestickSeries,
    slots_QtCharts_QCandlestickSeries,
    init_type_QtCharts_QCandlestickSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QCandlestickSeries,
    SIP_NULLPTR,
    array_QtCharts_QCandlestickSeries,
    SIP_NULLPTR,
    release_QtCharts_QCandlestickSeries,
    cast_QtCharts_QCandlestickSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QCandlestickSeries,
    sizeof (::QtCharts::QCandlestickSeries),
};
