/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 83 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 87 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 160 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 111 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 163 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 168 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 171 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 174 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 177 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 180 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 183 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 186 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 189 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 192 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 195 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 198 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 201 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 204 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 207 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 210 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 213 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQHPieModelMapper.cpp"


class sipQtCharts_QHPieModelMapper : public ::QtCharts::QHPieModelMapper
{
public:
    sipQtCharts_QHPieModelMapper(::QObject*);
    virtual ~sipQtCharts_QHPieModelMapper();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QHPieModelMapper(const sipQtCharts_QHPieModelMapper &);
    sipQtCharts_QHPieModelMapper &operator = (const sipQtCharts_QHPieModelMapper &);

    char sipPyMethods[7];
};

sipQtCharts_QHPieModelMapper::sipQtCharts_QHPieModelMapper(::QObject*a0): ::QtCharts::QHPieModelMapper(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QHPieModelMapper::~sipQtCharts_QHPieModelMapper()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QHPieModelMapper::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QHPieModelMapper);

    return ::QtCharts::QHPieModelMapper::metaObject();
}

int sipQtCharts_QHPieModelMapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QHPieModelMapper::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QHPieModelMapper, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QHPieModelMapper::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QHPieModelMapper, _clname, &sipCpp) ? sipCpp : ::QtCharts::QHPieModelMapper::qt_metacast(_clname));
}

bool sipQtCharts_QHPieModelMapper::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QHPieModelMapper::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QHPieModelMapper::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QHPieModelMapper::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtCharts_QHPieModelMapper::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QHPieModelMapper::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QHPieModelMapper::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QHPieModelMapper::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QHPieModelMapper::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QHPieModelMapper::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QHPieModelMapper::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QHPieModelMapper::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QHPieModelMapper::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QHPieModelMapper::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_valuesRow, "valuesRow(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_valuesRow(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_valuesRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->valuesRow();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_valuesRow, doc_QtCharts_QHPieModelMapper_valuesRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_setValuesRow, "setValuesRow(self, valuesRow: int)");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_setValuesRow(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_setValuesRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp, &a0))
        {
            sipCpp->setValuesRow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_setValuesRow, doc_QtCharts_QHPieModelMapper_setValuesRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_labelsRow, "labelsRow(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_labelsRow(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_labelsRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->labelsRow();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_labelsRow, doc_QtCharts_QHPieModelMapper_labelsRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_setLabelsRow, "setLabelsRow(self, labelsRow: int)");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_setLabelsRow(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_setLabelsRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp, &a0))
        {
            sipCpp->setLabelsRow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_setLabelsRow, doc_QtCharts_QHPieModelMapper_setLabelsRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_model, "model(self) -> QAbstractItemModel|None");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_model(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_model(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp))
        {
            ::QAbstractItemModel*sipRes;

            sipRes = sipCpp->model();

            return sipConvertFromType(sipRes, sipType_QAbstractItemModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_model, doc_QtCharts_QHPieModelMapper_model);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_setModel, "setModel(self, model: QAbstractItemModel|None)");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_setModel(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_setModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp, &a0Keep, sipType_QAbstractItemModel, &a0))
        {
            sipCpp->setModel(a0);

            sipKeepReference(sipSelf, -4, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_setModel, doc_QtCharts_QHPieModelMapper_setModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_series, "series(self) -> QPieSeries|None");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_series(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_series(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp))
        {
            ::QtCharts::QPieSeries*sipRes;

            sipRes = sipCpp->series();

            return sipConvertFromType(sipRes, sipType_QtCharts_QPieSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_series, doc_QtCharts_QHPieModelMapper_series);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_setSeries, "setSeries(self, series: QPieSeries|None)");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_setSeries(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_setSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QPieSeries* a0;
        ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp, sipType_QtCharts_QPieSeries, &a0))
        {
            sipCpp->setSeries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_setSeries, doc_QtCharts_QHPieModelMapper_setSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_firstColumn, "firstColumn(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_firstColumn(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_firstColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->firstColumn();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_firstColumn, doc_QtCharts_QHPieModelMapper_firstColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_setFirstColumn, "setFirstColumn(self, firstColumn: int)");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_setFirstColumn(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_setFirstColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp, &a0))
        {
            sipCpp->setFirstColumn(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_setFirstColumn, doc_QtCharts_QHPieModelMapper_setFirstColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_columnCount, "columnCount(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_columnCount(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_columnCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->columnCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_columnCount, doc_QtCharts_QHPieModelMapper_columnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper_setColumnCount, "setColumnCount(self, columnCount: int)");

extern "C" {static PyObject *meth_QtCharts_QHPieModelMapper_setColumnCount(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QHPieModelMapper_setColumnCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QHPieModelMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QHPieModelMapper, &sipCpp, &a0))
        {
            sipCpp->setColumnCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHPieModelMapper, sipName_setColumnCount, doc_QtCharts_QHPieModelMapper_setColumnCount);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QHPieModelMapper(void *, const sipTypeDef *);}
static void *cast_QtCharts_QHPieModelMapper(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QHPieModelMapper *sipCpp = reinterpret_cast< ::QtCharts::QHPieModelMapper *>(sipCppV);

    if (targetType == sipType_QtCharts_QHPieModelMapper)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QHPieModelMapper(void *, int);}
static void release_QtCharts_QHPieModelMapper(void *sipCppV, int)
{
    ::QtCharts::QHPieModelMapper *sipCpp = reinterpret_cast< ::QtCharts::QHPieModelMapper *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QHPieModelMapper(Py_ssize_t);}
static void *array_QtCharts_QHPieModelMapper(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QHPieModelMapper[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QHPieModelMapper(void *);}
static void array_delete_QtCharts_QHPieModelMapper(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QHPieModelMapper *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QHPieModelMapper(sipSimpleWrapper *);}
static void dealloc_QtCharts_QHPieModelMapper(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QHPieModelMapper *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QHPieModelMapper(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QHPieModelMapper(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QHPieModelMapper(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QHPieModelMapper *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtCharts_QHPieModelMapper(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QHPieModelMapper[] = {{10, 0, 1}};


static PyMethodDef methods_QtCharts_QHPieModelMapper[] = {
    {sipName_columnCount, meth_QtCharts_QHPieModelMapper_columnCount, METH_VARARGS, doc_QtCharts_QHPieModelMapper_columnCount},
    {sipName_firstColumn, meth_QtCharts_QHPieModelMapper_firstColumn, METH_VARARGS, doc_QtCharts_QHPieModelMapper_firstColumn},
    {sipName_labelsRow, meth_QtCharts_QHPieModelMapper_labelsRow, METH_VARARGS, doc_QtCharts_QHPieModelMapper_labelsRow},
    {sipName_model, meth_QtCharts_QHPieModelMapper_model, METH_VARARGS, doc_QtCharts_QHPieModelMapper_model},
    {sipName_series, meth_QtCharts_QHPieModelMapper_series, METH_VARARGS, doc_QtCharts_QHPieModelMapper_series},
    {sipName_setColumnCount, meth_QtCharts_QHPieModelMapper_setColumnCount, METH_VARARGS, doc_QtCharts_QHPieModelMapper_setColumnCount},
    {sipName_setFirstColumn, meth_QtCharts_QHPieModelMapper_setFirstColumn, METH_VARARGS, doc_QtCharts_QHPieModelMapper_setFirstColumn},
    {sipName_setLabelsRow, meth_QtCharts_QHPieModelMapper_setLabelsRow, METH_VARARGS, doc_QtCharts_QHPieModelMapper_setLabelsRow},
    {sipName_setModel, meth_QtCharts_QHPieModelMapper_setModel, METH_VARARGS, doc_QtCharts_QHPieModelMapper_setModel},
    {sipName_setSeries, meth_QtCharts_QHPieModelMapper_setSeries, METH_VARARGS, doc_QtCharts_QHPieModelMapper_setSeries},
    {sipName_setValuesRow, meth_QtCharts_QHPieModelMapper_setValuesRow, METH_VARARGS, doc_QtCharts_QHPieModelMapper_setValuesRow},
    {sipName_valuesRow, meth_QtCharts_QHPieModelMapper_valuesRow, METH_VARARGS, doc_QtCharts_QHPieModelMapper_valuesRow}
};

PyDoc_STRVAR(doc_QtCharts_QHPieModelMapper, "\1QHPieModelMapper(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QHPieModelMapper[] = {
    {"columnCountChanged()", "\1columnCountChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"firstColumnChanged()", "\1firstColumnChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsRowChanged()", "\1labelsRowChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"valuesRowChanged()", "\1valuesRowChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"modelReplaced()", "\1modelReplaced(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"seriesReplaced()", "\1seriesReplaced(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QHPieModelMapper = {
    &::QtCharts::QHPieModelMapper::staticMetaObject,
    0,
    signals_QtCharts_QHPieModelMapper,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHPieModelMapper = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QHPieModelMapper,
        SIP_NULLPTR,
        &plugin_QtCharts_QHPieModelMapper,
    },
    {
        sipNameNr_QHPieModelMapper,
        {0, 0, 1},
        12, methods_QtCharts_QHPieModelMapper,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QHPieModelMapper,
    -1,
    -1,
    supers_QtCharts_QHPieModelMapper,
    SIP_NULLPTR,
    init_type_QtCharts_QHPieModelMapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QHPieModelMapper,
    SIP_NULLPTR,
    array_QtCharts_QHPieModelMapper,
    SIP_NULLPTR,
    release_QtCharts_QHPieModelMapper,
    cast_QtCharts_QHPieModelMapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QHPieModelMapper,
    sizeof (::QtCharts::QHPieModelMapper),
};
