/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 71 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 74 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 88 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 97 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 160 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 173 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 180 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 205 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 238 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 241 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 460 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 244 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 224 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 247 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 250 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 471 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 253 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 438 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 256 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 98 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 259 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 262 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpainter.sip"
#include <qpainter.h>
#line 265 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 1031 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 268 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 271 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 164 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 274 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 103 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 277 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 119 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 280 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 88 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 283 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 363 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 286 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 289 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 509 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 292 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 164 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 295 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 384 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 298 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 199 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 301 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 304 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 307 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 310 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 52 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 313 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 316 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 205 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 319 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 253 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 322 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 398 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 325 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 412 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 328 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 425 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 331 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 482 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 334 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 302 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 337 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 675 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 340 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 608 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 343 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 592 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 346 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 619 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 349 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 570 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 352 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 355 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 358 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 361 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 364 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 437 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvbarmodelmapper.sip"
#include <qvbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvboxplotmodelmapper.sip"
#include <qvboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvcandlestickmodelmapper.sip"
#include <qvcandlestickmodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvpiemodelmapper.sip"
#include <qvpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvxymodelmapper.sip"
#include <qvxymodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qxylegendmarker.sip"
#include <qxylegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qxyseries.sip"
#include <qxyseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qxyseries.sip"
#include <qxyseries.h>
#line 536 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 541 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 556 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 575 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 602 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 637 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 722 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 759 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 798 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 839 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 880 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 923 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 968 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 1015 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 1064 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 1115 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 1168 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 1223 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 1280 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 1339 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 1404 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 1471 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 1540 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 1615 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 1692 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 1769 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 1848 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 1929 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 2012 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvbarmodelmapper.sip"
#include <qvbarmodelmapper.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvbarmodelmapper.sip"
#include <qvbarmodelmapper.h>
#line 2099 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvbarmodelmapper.sip"
#include <qvbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvboxplotmodelmapper.sip"
#include <qvboxplotmodelmapper.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvboxplotmodelmapper.sip"
#include <qvboxplotmodelmapper.h>
#line 2188 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvbarmodelmapper.sip"
#include <qvbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvboxplotmodelmapper.sip"
#include <qvboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvcandlestickmodelmapper.sip"
#include <qvcandlestickmodelmapper.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvcandlestickmodelmapper.sip"
#include <qvcandlestickmodelmapper.h>
#line 2279 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvbarmodelmapper.sip"
#include <qvbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvboxplotmodelmapper.sip"
#include <qvboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvcandlestickmodelmapper.sip"
#include <qvcandlestickmodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvpiemodelmapper.sip"
#include <qvpiemodelmapper.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvpiemodelmapper.sip"
#include <qvpiemodelmapper.h>
#line 2372 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlineseries.sip"
#include <qlineseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlogvalueaxis.sip"
#include <qlogvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpercentbarseries.sip"
#include <qpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpielegendmarker.sip"
#include <qpielegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieseries.sip"
#include <qpieseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpieslice.sip"
#include <qpieslice.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qpolarchart.sip"
#include <qpolarchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qscatterseries.sip"
#include <qscatterseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qsplineseries.sip"
#include <qsplineseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qstackedbarseries.sip"
#include <qstackedbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvalueaxis.sip"
#include <qvalueaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvbarmodelmapper.sip"
#include <qvbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvboxplotmodelmapper.sip"
#include <qvboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvcandlestickmodelmapper.sip"
#include <qvcandlestickmodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvpiemodelmapper.sip"
#include <qvpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvxymodelmapper.sip"
#include <qvxymodelmapper.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qvxymodelmapper.sip"
#include <qvxymodelmapper.h>
#line 2467 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtChart[] = {
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'B', 'a', 'r', 'S', 'e', 'r', 'i', 'e', 's', ':', ':', 'L', 'a', 'b', 'e', 'l', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'A', 'x', 'i', 's', ':', ':', 'A', 'x', 'i', 's', 'L', 'a', 'b', 'e', 'l', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', ':', ':', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'o', 'l', 'a', 'r', 'C', 'h', 'a', 'r', 't', ':', ':', 'P', 'o', 'l', 'a', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'o', 'l', 'a', 'r', 'C', 'h', 'a', 'r', 't', ':', ':', 'P', 'o', 'l', 'a', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'e', 'r', 'i', 'e', 's', ':', ':', 'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'P', 'e', 'r', 'c', 'e', 'n', 't', 'B', 'a', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'S', 't', 'a', 'c', 'k', 'e', 'd', 'B', 'a', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'S', 'c', 'a', 't', 't', 'e', 'r', 'S', 'e', 'r', 'i', 'e', 's', ':', ':', 'M', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'x', 'i', 's', ':', ':', 'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'h', 'a', 'r', 't', ':', ':', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'H', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'i', 'e', 'S', 'l', 'i', 'c', 'e', ':', ':', 'L', 'a', 'b', 'e', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'V', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'e', 'r', 'i', 'e', 's', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'S', 'e', 't', '*', '>', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'x', 'i', 's', ':', ':', 'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'o', 'x', 'S', 'e', 't', ':', ':', 'V', 'a', 'l', 'u', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'h', 'a', 'r', 't', ':', ':', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'h', 'a', 'r', 't', 'V', 'i', 'e', 'w', ':', ':', 'R', 'u', 'b', 'b', 'e', 'r', 'B', 'a', 'n', 'd', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'h', 'a', 'r', 't', 'V', 'i', 'e', 'w', ':', ':', 'R', 'u', 'b', 'b', 'e', 'r', 'B', 'a', 'n', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'x', 'i', 's', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', '*', '>', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'o', 'x', 'P', 'l', 'o', 't', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'H', 'B', 'o', 'x', 'P', 'l', 'o', 't', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'B', 'a', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'L', 'e', 'g', 'e', 'n', 'd', ':', ':', 'M', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'V', 'B', 'o', 'x', 'P', 'l', 'o', 't', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'V', 'a', 'l', 'u', 'e', 'A', 'x', 'i', 's', ':', ':', 'T', 'i', 'c', 'k', 'T', 'y', 'p', 'e', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'P', 'e', 'r', 'c', 'e', 'n', 't', 'B', 'a', 'r', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'S', 't', 'a', 'c', 'k', 'e', 'd', 'B', 'a', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'B', 'a', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'h', 'a', 'r', 't', ':', ':', 'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 0,
    'b', 'o', 'd', 'y', 'O', 'u', 't', 'l', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'P', 'l', 'o', 't', 'A', 'r', 'e', 'a', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'i', 'e', 'S', 'l', 'i', 'c', 'e', '*', '>', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'r', 'e', 'a', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'h', 'a', 'r', 't', ':', ':', 'C', 'h', 'a', 'r', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'e', 'r', 'c', 'e', 'n', 't', 'B', 'a', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'S', 't', 'a', 'c', 'k', 'e', 'd', 'B', 'a', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'b', 'o', 'x', 'O', 'u', 't', 'l', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'P', 'l', 'o', 't', 'A', 'r', 'e', 'a', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'a', 'r', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'A', 'x', 'i', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'a', 'r', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'H', 'B', 'a', 'r', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'H', 'P', 'i', 'e', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'i', 'e', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'V', 'B', 'a', 'r', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'V', 'P', 'i', 'e', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'l', 'i', 'p', 'p', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'P', 'l', 'o', 't', 'A', 'r', 'e', 'a', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'A', 'x', 'i', 's', 'L', 'a', 'b', 'e', 'l', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'O', 'n', 'V', 'a', 'l', 'u', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'a', 'r', 'S', 'e', 't', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'o', 'x', 'S', 'e', 't', '*', '>', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'S', 'e', 't', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'H', 'X', 'Y', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'V', 'X', 'Y', 'M', 'o', 'd', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'X', 'Y', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'x', 'i', 's', 'L', 'a', 'b', 'e', 'l', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'o', 'x', 'P', 'l', 'o', 't', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'S', 'c', 'a', 't', 't', 'e', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'E', 'x', 'p', 'l', 'o', 'd', 'e', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'P', 'l', 'o', 't', 'A', 'r', 'e', 'a', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'P', 'e', 'n', 0,
    's', 'h', 'a', 'd', 'e', 's', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'B', 'o', 'x', 'P', 'l', 'o', 't', 0,
    'P', 'o', 'l', 'a', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'A', 'n', 'g', 'u', 'l', 'a', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'x', 'i', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'A', 'x', 'i', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'D', 'a', 't', 'e', 'T', 'i', 'm', 'e', 'A', 'x', 'i', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'L', 'o', 'g', 'V', 'a', 'l', 'u', 'e', 'A', 'x', 'i', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'S', 'p', 'l', 'i', 'n', 'e', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'B', 'a', 'r', 0,
    'l', 'a', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'P', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'l', 'o', 't', 'A', 'r', 'e', 'a', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'E', 'a', 's', 'i', 'n', 'g', 'C', 'u', 'r', 'v', 'e', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'A', 'r', 'm', 'L', 'e', 'n', 'g', 't', 'h', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'M', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 'B', 'l', 'u', 'e', 'C', 'e', 'r', 'u', 'l', 'e', 'a', 'n', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 'H', 'i', 'g', 'h', 'C', 'o', 'n', 't', 'r', 'a', 's', 't', 0,
    'P', 'Y', 'Q', 'T', '_', 'C', 'H', 'A', 'R', 'T', '_', 'V', 'E', 'R', 'S', 'I', 'O', 'N', '_', 'S', 'T', 'R', 0,
    'P', 'o', 'l', 'a', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'R', 'a', 'd', 'i', 'a', 'l', 0,
    'c', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'S', 'e', 't', 's', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'd', 'e', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'M', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'R', 'o', 'u', 'n', 'd', 'n', 'e', 's', 's', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'l', 'i', 'p', 'p', 'i', 'n', 'g', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'L', 'a', 'b', 'e', 'l', 'I', 'n', 's', 'i', 'd', 'e', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 0,
    'L', 'a', 'b', 'e', 'l', 'I', 'n', 's', 'i', 'd', 'e', 'T', 'a', 'n', 'g', 'e', 'n', 't', 'i', 'a', 'l', 0,
    'M', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 'F', 'r', 'o', 'm', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'A', 'r', 'e', 'a', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'L', 'i', 'n', 'e', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'o', 'l', 'a', 'r', 'C', 'h', 'a', 'r', 't', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'C', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 0,
    'c', 'a', 'p', 's', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 'p', 'l', 'o', 'd', 'e', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'f', 'i', 'r', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'T', 'i', 'c', 'k', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'l', 'o', 't', 'A', 'r', 'e', 'a', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'P', 'e', 'n', 0,
    'r', 'e', 'v', 'e', 'r', 's', 'e', 'M', 'a', 'r', 'k', 'e', 'r', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'o', 'd', 'y', 'O', 'u', 't', 'l', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'M', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'R', 'u', 'b', 'b', 'e', 'r', 'B', 'a', 'n', 'd', 0,
    'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'A', 'r', 'e', 'a', 0,
    'M', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'a', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'h', 'a', 'r', 't', 'V', 'i', 'e', 'w', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'i', 'e', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'V', 'a', 'l', 'u', 'e', 'A', 'x', 'i', 's', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'P', 'e', 'r', 'c', 'e', 'n', 't', 'B', 'a', 'r', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'S', 't', 'a', 'c', 'k', 'e', 'd', 'B', 'a', 'r', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'E', 'a', 's', 'i', 'n', 'g', 'C', 'u', 'r', 'v', 'e', 0,
    'a', 'x', 'i', 's', 'P', 'o', 'l', 'a', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 'S', 'e', 't', 's', 'A', 'd', 'd', 'e', 'd', 0,
    'g', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'A', 'r', 'm', 'L', 'e', 'n', 'g', 't', 'h', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 's', 't', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'B', 'o', 'x', 'O', 'u', 't', 'l', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'D', 'r', 'o', 'p', 'S', 'h', 'a', 'd', 'o', 'w', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 's', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'h', 'a', 'd', 'e', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'F', 'r', 'a', 'm', 'e', 'S', 'e', 'c', 't', 'i', 'o', 'n', 'A', 't', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'B', 'a', 'r', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 'B', 'r', 'o', 'w', 'n', 'S', 'a', 'n', 'd', 0,
    'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'B', 'a', 'r', 0,
    'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'P', 'i', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'P', 'i', 'e', 'S', 'l', 'i', 'c', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'X', 'Y', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'R', 'u', 'b', 'b', 'e', 'r', 'B', 'a', 'n', 'd', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'R', 'o', 'u', 'n', 'd', 'n', 'e', 's', 's', 0,
    'i', 's', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'i', 's', 'D', 'r', 'o', 'p', 'S', 'h', 'a', 'd', 'o', 'w', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'l', 'i', 'p', 'p', 'i', 'n', 'g', 0,
    's', 'e', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'M', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'P', 'e', 'n', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'h', 'o', 'w', 'T', 'o', 'o', 'l', 'T', 'i', 'p', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 'c', 'k', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 't', 'l', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 'n', 'g', 'r', 'a', 'b', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'v', 'a', 'l', 'u', 'e', 's', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'y', 'p', 'e', 'C', 'a', 'r', 't', 'e', 's', 'i', 'a', 'n', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'y', 'p', 'e', 'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'G', 'r', 'i', 'd', 'A', 'x', 'i', 's', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 's', 0,
    'L', 'e', 'g', 'e', 'n', 'd', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'X', 'Y', 0,
    'M', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'P', 'Y', 'Q', 'T', '_', 'C', 'H', 'A', 'R', 'T', '_', 'V', 'E', 'R', 'S', 'I', 'O', 'N', 0,
    'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'R', 'u', 'b', 'b', 'e', 'r', 'B', 'a', 'n', 'd', 0,
    'b', 'o', 'd', 'y', 'O', 'u', 't', 'l', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'o', 's', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'S', 'e', 't', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'N', 'e', 'x', 't', 'P', 'r', 'e', 'v', 'C', 'h', 'i', 'l', 'd', 0,
    'g', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'g', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'P', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'r', 'i', 'd', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'A', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'B', 'r', 'u', 's', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'D', 'e', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'S', 'e', 't', 'S', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'I', 'n', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'i', 'z', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 's', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'h', 'a', 'd', 'e', 's', 'B', 'r', 'u', 's', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'h', 'a', 'd', 'e', 's', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 'B', 'l', 'u', 'e', 'I', 'c', 'y', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 'B', 'l', 'u', 'e', 'N', 'c', 's', 0,
    'L', 'a', 'b', 'e', 'l', 'I', 'n', 's', 'i', 'd', 'e', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    'M', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 'C', 'i', 'r', 'c', 'l', 'e', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'a', 'r', 'S', 'e', 't', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'B', 'o', 'x', 'S', 'e', 't', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'L', 'e', 'g', 'e', 'n', 'd', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'B', 'o', 'x', 'P', 'l', 'o', 't', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'S', 'c', 'a', 't', 't', 'e', 'r', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'b', 'o', 'x', 'O', 'u', 't', 'l', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'A', 'x', 'e', 's', 0,
    'f', 'i', 'r', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'f', 'i', 'r', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'h', 'a', 's', 'H', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'h', 'i', 'g', 'h', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'A', 't', 't', 'a', 'c', 'h', 'e', 'd', 'T', 'o', 'C', 'h', 'a', 'r', 't', 0,
    'i', 's', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 'B', 'r', 'u', 's', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 's', 't', 'S', 'e', 't', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'r', 'k', 'e', 'r', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'p', 'e', 'n', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'S', 'e', 't', 'S', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'i', 'n', 'o', 'r', 'T', 'i', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'R', 'e', 'v', 'e', 'r', 's', 'e', 'M', 'a', 'r', 'k', 'e', 'r', 's', 0,
    's', 'h', 'a', 'd', 'e', 's', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    's', 't', 'a', 'r', 't', 'A', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 'c', 'k', 'A', 'n', 'c', 'h', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 't', 'l', 'e', 'B', 'r', 'u', 's', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'D', 'a', 't', 'e', 'T', 'i', 'm', 'e', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'L', 'o', 'g', 'V', 'a', 'l', 'u', 'e', 0,
    'L', 'a', 'b', 'e', 'l', 's', 'I', 'n', 's', 'i', 'd', 'e', 'B', 'a', 's', 'e', 0,
    'L', 'a', 'b', 'e', 'l', 's', 'O', 'u', 't', 's', 'i', 'd', 'e', 'E', 'n', 'd', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', ':', ':', 'Q', 'C', 'h', 'a', 'r', 't', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 's', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'S', 'p', 'l', 'i', 'n', 'e', 0,
    'a', 'n', 'g', 'l', 'e', 'S', 'p', 'a', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'a', 'p', 'p', 'l', 'y', 'N', 'i', 'c', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 's', 0,
    'b', 'o', 'd', 'y', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'p', 's', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 'L', 'a', 'b', 'e', 'l', 's', 0,
    'c', 'o', 'l', 'l', 'i', 'd', 'e', 's', 'W', 'i', 't', 'h', 'I', 't', 'e', 'm', 0,
    'c', 'o', 'l', 'l', 'i', 'd', 'e', 's', 'W', 'i', 't', 'h', 'P', 'a', 't', 'h', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'Q', 'u', 'e', 'r', 'y', 0,
    'l', 'a', 'b', 'e', 'l', 'F', 'o', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'l', 'a', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'l', 'o', 'w', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'P', 'e', 'n', 0,
    'p', 'a', 'i', 'n', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'F', 'r', 'a', 'm', 'e', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'o', 'r', 0,
    'p', 'o', 'l', 'a', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'c', 'e', 'n', 'e', 'E', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'B', 'y', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'P', 'e', 'n', 0,
    's', 'e', 't', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'P', 'i', 'e', 'S', 't', 'a', 'r', 't', 'A', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'h', 'a', 'd', 'e', 's', 'P', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 'c', 'k', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 't', 'l', 'e', 'F', 'o', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 't', 'l', 'e', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 'n', 'g', 'r', 'a', 'b', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'u', 's', 'e', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 's', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'F', 'r', 'a', 'm', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 'L', 'i', 'g', 'h', 't', 0,
    'L', 'a', 'b', 'e', 'l', 's', 'I', 'n', 's', 'i', 'd', 'e', 'E', 'n', 'd', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'b', 'o', 'x', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'o', 's', 'e', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', 'C', 'o', 'l', 'o', 'r', 0,
    'd', 'e', 't', 'a', 'c', 'h', 'F', 'r', 'o', 'm', 'C', 'h', 'a', 'r', 't', 0,
    'f', 'i', 'r', 's', 't', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'S', 'e', 't', 'S', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'h', 'o', 'v', 'e', 'r', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'o', 'v', 'e', 'r', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', 'C', 'o', 'l', 'o', 'r', 0,
    'i', 'n', 'i', 't', 'S', 't', 'y', 'l', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'i', 's', 'L', 'a', 'b', 'e', 'l', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 0,
    'l', 'o', 'c', 'a', 'l', 'i', 'z', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 's', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'l', 'o', 't', 'A', 'r', 'e', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 'L', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'l', 'l', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'P', 'e', 'n', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'S', 'h', 'o', 'w', 'T', 'o', 'o', 'l', 'T', 'i', 'p', 's', 0,
    's', 'e', 't', 'T', 'i', 'c', 'k', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'R', 'o', 'w', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 's', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    't', 'i', 'c', 'k', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'N', 'o', 'A', 'x', 'i', 's', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 'D', 'a', 'r', 'k', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'y', 'p', 'e', 'P', 'o', 'l', 'a', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'o', 'i', 'n', 't', 'F', '>', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'A', 'r', 'e', 'a', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'L', 'i', 'n', 'e', 0,
    'b', 'a', 'r', 's', 'e', 't', 's', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'b', 'o', 'x', 's', 'e', 't', 's', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'd', 'r', 'a', 'g', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'g', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'w', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'd', 'r', 'a', 'w', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'f', 'i', 'r', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'R', 'o', 'w', 0,
    'f', 'i', 'r', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'R', 'o', 'w', 0,
    'f', 'i', 'r', 's', 't', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'h', 'i', 'g', 'h', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'o', 'v', 'e', 'r', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'L', 'a', 'b', 'e', 'l', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'i', 's', 'T', 'i', 't', 'l', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'a', 's', 't', 'S', 'e', 't', 'S', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'l', 'i', 'n', 'e', 'P', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'T', 'i', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'p', 'a', 'c', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'p', 'e', 'n', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 's', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'd', 0,
    'r', 'e', 'v', 'e', 'r', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'v', 'e', 'r', 's', 'e', 'M', 'a', 'r', 'k', 'e', 'r', 's', 0,
    's', 'e', 'r', 'i', 'e', 's', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'd', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'C', 'a', 'p', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'C', 'l', 'o', 's', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'S', 'e', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'P', 'e', 'n', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'A', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'L', 'o', 'w', 'e', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'M', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 0,
    's', 'e', 't', 'P', 'i', 'e', 'E', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 's', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 's', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'U', 'p', 'p', 'e', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'v', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'x', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'l', 'l', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 's', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'L', 'o', 'w', 'e', 'r', 'Q', 'u', 'a', 'r', 't', 'i', 'l', 'e', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'C', 'h', 'a', 'r', 't', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'B', 'a', 'r', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'P', 'i', 'e', 0,
    'U', 'p', 'p', 'e', 'r', 'Q', 'u', 'a', 'r', 't', 'i', 'l', 'e', 0,
    'a', 't', 't', 'a', 'c', 'h', 'T', 'o', 'C', 'h', 'a', 'r', 't', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'P', 'e', 'n', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'L', 'a', 'b', 'e', 'l', 0,
    'd', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'e', 'd', 0,
    'd', 'r', 'a', 'g', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'i', 's', 'L', 'i', 'n', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'a', 'b', 'e', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'l', 'a', 's', 't', 'B', 'a', 'r', 'S', 'e', 't', 'R', 'o', 'w', 0,
    'l', 'a', 's', 't', 'B', 'o', 'x', 'S', 'e', 't', 'R', 'o', 'w', 0,
    'l', 'a', 's', 't', 'S', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'l', 'o', 'w', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'p', 'T', 'o', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'm', 'o', 'd', 'e', 'l', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'd', 0,
    'p', 'i', 'e', 'S', 't', 'a', 'r', 't', 'A', 'n', 'g', 'l', 'e', 0,
    'p', 'o', 'i', 'n', 't', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 's', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'H', 'i', 'g', 'h', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'S', 'e', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'M', 'a', 'r', 'k', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'O', 'p', 'e', 'n', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'R', 'u', 'b', 'b', 'e', 'r', 'B', 'a', 'n', 'd', 0,
    's', 'e', 't', 'S', 't', 'a', 'r', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'T', 'i', 'c', 'k', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'u', 'p', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    's', 'h', 'a', 'd', 'e', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'h', 'a', 'r', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'v', 'a', 'l', 'u', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 's', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'E', 'v', 'e', 'n', 't', 0,
    'C', 'h', 'a', 'r', 't', 'T', 'h', 'e', 'm', 'e', 'Q', 't', 0,
    'L', 'a', 'b', 'e', 'l', 'O', 'u', 't', 's', 'i', 'd', 'e', 0,
    'L', 'a', 'b', 'e', 'l', 's', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'L', 'o', 'w', 'e', 'r', 'E', 'x', 't', 'r', 'e', 'm', 'e', 0,
    'N', 'o', 'R', 'u', 'b', 'b', 'e', 'r', 'B', 'a', 'n', 'd', 0,
    'T', 'i', 'c', 'k', 's', 'D', 'y', 'n', 'a', 'm', 'i', 'c', 0,
    'U', 'p', 'p', 'e', 'r', 'E', 'x', 't', 'r', 'e', 'm', 'e', 0,
    'a', 't', 't', 'a', 'c', 'h', 'e', 'd', 'A', 'x', 'e', 's', 0,
    'b', 'a', 'r', 's', 'e', 't', 's', 'A', 'd', 'd', 'e', 'd', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'b', 'o', 'x', 's', 'e', 't', 's', 'A', 'd', 'd', 'e', 'd', 0,
    'b', 'r', 'u', 's', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'o', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'O', 'b', 's', 'c', 'u', 'r', 'e', 'd', 'B', 'y', 0,
    'l', 'a', 'b', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'l', 'i', 'n', 'e', 'P', 'e', 'n', 'C', 'o', 'l', 'o', 'r', 0,
    'p', 'o', 'i', 'n', 't', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'p', 'o', 'i', 'n', 't', 's', 'V', 'e', 'c', 't', 'o', 'r', 0,
    'r', 'a', 'n', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'P', 'o', 'i', 'n', 't', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 'L', 'a', 'b', 'e', 'l', 0,
    's', 'e', 't', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'B', 'o', 'd', 'y', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'C', 'a', 'p', 's', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 'R', 'o', 'w', 0,
    's', 'e', 't', 'L', 'o', 'w', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 's', 'P', 'e', 'n', 0,
    's', 'e', 't', 'T', 'i', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'U', 's', 'e', 'O', 'p', 'e', 'n', 'G', 'L', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 's', 'R', 'o', 'w', 0,
    's', 'h', 'a', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'h', 'o', 'w', 'T', 'o', 'o', 'l', 'T', 'i', 'p', 's', 0,
    't', 'i', 'c', 'k', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'R', 'o', 'w', 0,
    'v', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 's', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'N', 'o', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    '_', '_', 'g', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'b', 'a', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'a', 'p', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'o', 's', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'i', 'r', 's', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'f', 'i', 'r', 's', 't', 'S', 'e', 't', 'R', 'o', 'w', 0,
    'f', 'o', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'P', 'e', 'n', 0,
    'h', 'i', 'g', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'i', 't', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'l', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'A', 'n', 'g', 'l', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'B', 'r', 'u', 's', 'h', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'C', 'o', 'l', 'o', 'r', 0,
    'l', 'o', 'w', 'e', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'm', 'a', 'r', 'k', 'e', 'r', 'S', 'h', 'a', 'p', 'e', 0,
    'n', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'p', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'p', 'i', 'e', 'E', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    'p', 'o', 'l', 'i', 's', 'h', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'B', 'a', 'r', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'B', 'o', 'x', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'C', 'l', 'o', 's', 'e', 'R', 'o', 'w', 0,
    's', 'e', 't', 'E', 'x', 'p', 'l', 'o', 'd', 'e', 'd', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    's', 'e', 't', 'H', 'o', 'l', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'P', 'l', 'o', 't', 'A', 'r', 'e', 'a', 0,
    's', 'e', 't', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'T', 'i', 'c', 'k', 'T', 'y', 'p', 'e', 0,
    's', 'h', 'a', 'd', 'e', 's', 'B', 'r', 'u', 's', 'h', 0,
    's', 'h', 'a', 'd', 'e', 's', 'C', 'o', 'l', 'o', 'r', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    'u', 'p', 'p', 'e', 'r', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'v', 'a', 'l', 'u', 'e', 's', 'A', 'd', 'd', 'e', 'd', 0,
    'x', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'T', 'i', 'c', 'k', 's', 'F', 'i', 'x', 'e', 'd', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    '_', '_', 'l', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    'a', 't', 't', 'a', 'c', 'h', 'A', 'x', 'i', 's', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 't', 'a', 'c', 'h', 'A', 'x', 'i', 's', 0,
    'e', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'i', 'g', 'h', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'i', 's', 'E', 'x', 'p', 'l', 'o', 'd', 'e', 'd', 0,
    'i', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 'B', 'r', 'u', 's', 'h', 0,
    'l', 'a', 'b', 'e', 'l', 'C', 'o', 'l', 'o', 'r', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'F', 'o', 'n', 't', 0,
    'l', 'a', 's', 't', 'S', 'e', 't', 'R', 'o', 'w', 0,
    'l', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'p', 'T', 'o', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'a', 'r', 'k', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'm', 'a', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'p', 'a', 'q', 'u', 'e', 'A', 'r', 'e', 'a', 0,
    'o', 'p', 'e', 'n', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 0,
    'p', 'o', 'i', 'n', 't', 'A', 'd', 'd', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'x', 'i', 's', 0,
    'r', 'u', 'b', 'b', 'e', 'r', 'B', 'a', 'n', 'd', 0,
    's', 'c', 'e', 'n', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'H', 'i', 'g', 'h', 'R', 'o', 'w', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'P', 'e', 'n', 0,
    's', 'e', 't', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    's', 'e', 't', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    's', 'e', 't', 'O', 'p', 'e', 'n', 'R', 'o', 'w', 0,
    's', 'e', 't', 'P', 'i', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'R', 'e', 'v', 'e', 'r', 's', 'e', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'X', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'Y', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 't', 'a', 'r', 't', 'A', 'n', 'g', 'l', 'e', 0,
    's', 't', 'a', 'r', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'u', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 'c', 'k', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'i', 't', 'l', 'e', 'B', 'r', 'u', 's', 'h', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'a', 'd', 'd', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'a', 'n', 'g', 'l', 'e', 'S', 'p', 'a', 'n', 0,
    'b', 'o', 'd', 'y', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'a', 'p', 's', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'h', 'a', 'r', 't', 'T', 'y', 'p', 'e', 0,
    'd', 'r', 'o', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'R', 'e', 'v', 'e', 'r', 's', 'e', 0,
    'i', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 'F', 'o', 'n', 't', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'R', 'o', 'w', 0,
    'l', 'o', 'w', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'e', 0,
    's', 'e', 't', 'L', 'o', 'w', 'R', 'o', 'w', 0,
    's', 'e', 't', 'S', 'e', 'r', 'i', 'e', 's', 0,
    's', 'h', 'a', 'd', 'e', 's', 'P', 'e', 'n', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    't', 'i', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    't', 'i', 't', 'l', 'e', 'F', 'o', 'n', 't', 0,
    't', 'i', 't', 'l', 'e', 'T', 'e', 'x', 't', 0,
    'u', 's', 'e', 'O', 'p', 'e', 'n', 'G', 'L', 0,
    'v', 'a', 'l', 'u', 'e', 's', 'R', 'o', 'w', 0,
    'z', 'o', 'o', 'm', 'R', 'e', 's', 'e', 't', 0,
    'Q', 't', 'C', 'h', 'a', 'r', 't', 's', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'b', 'a', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'b', 'o', 'x', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'l', 'o', 's', 'e', 'R', 'o', 'w', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'e', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'e', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'e', 'x', 'p', 'l', 'o', 'd', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'R', 'o', 'w', 0,
    'h', 'o', 'l', 'e', 'S', 'i', 'z', 'e', 0,
    'i', 's', 'Z', 'o', 'o', 'm', 'e', 'd', 0,
    'p', 'l', 'o', 't', 'A', 'r', 'e', 'a', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'd', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 0,
    's', 'e', 't', 'A', 'x', 'i', 's', 'X', 0,
    's', 'e', 't', 'A', 'x', 'i', 's', 'Y', 0,
    's', 'e', 't', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'C', 'h', 'a', 'r', 't', 0,
    's', 'e', 't', 'C', 'l', 'o', 's', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 0,
    's', 'e', 't', 'M', 'o', 'd', 'e', 'l', 0,
    's', 'e', 't', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'S', 'h', 'a', 'p', 'e', 0,
    's', 'e', 't', 'T', 'h', 'e', 'm', 'e', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    't', 'i', 'c', 'k', 'T', 'y', 'p', 'e', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'a', 'd', 'd', 'A', 'x', 'i', 's', 0,
    'a', 'd', 'v', 'a', 'n', 'c', 'e', 0,
    'b', 'a', 'r', 'S', 'e', 't', 's', 0,
    'b', 'o', 'x', 'S', 'e', 't', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'e', 'd', 0,
    'c', 'l', 'i', 'c', 'k', 'e', 'd', 0,
    'd', 'e', 'v', 'T', 'y', 'p', 'e', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'h', 'i', 'g', 'h', 'R', 'o', 'w', 0,
    'h', 'o', 'v', 'e', 'r', 'e', 'd', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'l', 'i', 'n', 'e', 'P', 'e', 'n', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'm', 'a', 'r', 'k', 'e', 'r', 's', 0,
    'o', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'o', 'p', 'e', 'n', 'R', 'o', 'w', 0,
    'p', 'i', 'e', 'S', 'i', 'z', 'e', 0,
    'p', 'r', 'e', 's', 's', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'r', 'e', 'v', 'e', 'r', 's', 'e', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'H', 'i', 'g', 'h', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'O', 'p', 'e', 'n', 0,
    's', 'e', 't', 'X', 'R', 'o', 'w', 0,
    's', 'e', 't', 'Y', 'R', 'o', 'w', 0,
    'v', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'x', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'y', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'z', 'o', 'o', 'm', 'O', 'u', 't', 0,
    'M', 'e', 'd', 'i', 'a', 'n', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 0,
    'b', 'a', 'r', 's', 'e', 't', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 0,
    'l', 'e', 'g', 'e', 'n', 'd', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 0,
    'l', 'o', 'w', 'R', 'o', 'w', 0,
    'm', 'e', 't', 'r', 'i', 'c', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'p', 'o', 'i', 'n', 't', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 0,
    's', 'c', 'r', 'o', 'l', 'l', 0,
    's', 'e', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'L', 'o', 'w', 0,
    's', 'e', 't', 'M', 'a', 'x', 0,
    's', 'e', 't', 'M', 'i', 'n', 0,
    's', 'e', 't', 'P', 'e', 'n', 0,
    's', 'l', 'i', 'c', 'e', 's', 0,
    'w', 'i', 'd', 'g', 'e', 't', 0,
    'z', 'o', 'o', 'm', 'I', 'n', 0,
    'a', 'd', 'd', 'e', 'd', 0,
    'a', 'x', 'i', 's', 'X', 0,
    'a', 'x', 'i', 's', 'Y', 0,
    'b', 'r', 'u', 's', 'h', 0,
    'c', 'h', 'a', 'r', 't', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'l', 'a', 'b', 'e', 'l', 0,
    'm', 'o', 'd', 'e', 'l', 0,
    'p', 'a', 'i', 'n', 't', 0,
    's', 'h', 'a', 'p', 'e', 0,
    's', 'l', 'i', 'c', 'e', 0,
    't', 'h', 'e', 'm', 'e', 0,
    't', 'i', 't', 'l', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'a', 'x', 'e', 's', 0,
    'b', 'a', 's', 'e', 0,
    'f', 'o', 'n', 't', 0,
    'h', 'i', 'd', 'e', 0,
    'h', 'i', 'g', 'h', 0,
    'n', 'a', 'm', 'e', 0,
    'o', 'p', 'e', 'n', 0,
    's', 'e', 't', 's', 0,
    's', 'h', 'o', 'w', 0,
    't', 'a', 'k', 'e', 0,
    't', 'y', 'p', 'e', 0,
    'x', 'R', 'o', 'w', 0,
    'y', 'R', 'o', 'w', 0,
    'z', 'o', 'o', 'm', 0,
    'l', 'o', 'w', 0,
    'm', 'a', 'x', 0,
    'm', 'i', 'n', 0,
    's', 'u', 'm', 0,
};
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartglobal.sip"
static int PYQT_CHART_VERSION = 0x050f07;
static const char *PYQT_CHART_VERSION_STR = "5.15.7";
#line 3233 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"

::QtCharts::QXYSeries* sipVH_QtChart_76(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QXYSeries* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QtCharts_QXYSeries, &sipRes);

    return sipRes;
}

::QtCharts::QPieSeries* sipVH_QtChart_75(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QPieSeries* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QtCharts_QPieSeries, &sipRes);

    return sipRes;
}

::QColor sipVH_QtChart_74(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QColor sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QColor, &sipRes);

    return sipRes;
}

void sipVH_QtChart_73(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QColor& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QColor(a0), sipType_QColor, SIP_NULLPTR);
}

void sipVH_QtChart_72(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QBrush& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QBrush(a0), sipType_QBrush, SIP_NULLPTR);
}

void sipVH_QtChart_71(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPen& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QPen(a0), sipType_QPen, SIP_NULLPTR);
}

void sipVH_QtChart_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWidget, SIP_NULLPTR);
}

void sipVH_QtChart_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ii", a0, a1);
}

void sipVH_QtChart_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPainter, SIP_NULLPTR);
}

::QPainter* sipVH_QtChart_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPainter* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPainter, &sipRes);

    return sipRes;
}

bool sipVH_QtChart_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QByteArray& a0, void*a1, long*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NV", new ::QByteArray(a0), sipType_QByteArray, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(bl)", &sipRes, a2);

    return sipRes;
}

bool sipVH_QtChart_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtChart_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDropEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDropEvent, SIP_NULLPTR);
}

void sipVH_QtChart_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragLeaveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragLeaveEvent, SIP_NULLPTR);
}

void sipVH_QtChart_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragMoveEvent, SIP_NULLPTR);
}

void sipVH_QtChart_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragEnterEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragEnterEvent, SIP_NULLPTR);
}

void sipVH_QtChart_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QActionEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QActionEvent, SIP_NULLPTR);
}

void sipVH_QtChart_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

void sipVH_QtChart_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QContextMenuEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QContextMenuEvent, SIP_NULLPTR);
}

void sipVH_QtChart_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtChart_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtChart_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPaintEvent, SIP_NULLPTR);
}

void sipVH_QtChart_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtChart_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

int sipVH_QtChart_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QSize sipVH_QtChart_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

void sipVH_QtChart_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

::QPaintEngine* sipVH_QtChart_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPaintEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPaintEngine, &sipRes);

    return sipRes;
}

int sipVH_QtChart_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintDevice::PaintDeviceMetric a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPaintDevice_PaintDeviceMetric);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtChart_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QRectF& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DN", a0, sipType_QPainter, SIP_NULLPTR, new ::QRectF(a1), sipType_QRectF, SIP_NULLPTR);
}

void sipVH_QtChart_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "i", a0);
}

::QRectF sipVH_QtChart_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRectF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRectF, &sipRes);

    return sipRes;
}

bool sipVH_QtChart_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPointF(a0), sipType_QPointF, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtChart_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QGraphicsItem*a0, ::Qt::ItemSelectionMode a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DF", const_cast< ::QGraphicsItem *>(a0), sipType_QGraphicsItem, SIP_NULLPTR, a1, sipType_Qt_ItemSelectionMode);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtChart_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPainterPath& a0, ::Qt::ItemSelectionMode a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NF", new ::QPainterPath(a0), sipType_QPainterPath, SIP_NULLPTR, a1, sipType_Qt_ItemSelectionMode);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtChart_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QGraphicsItem*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::QGraphicsItem *>(a0), sipType_QGraphicsItem, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QPainterPath sipVH_QtChart_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPainterPath sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPainterPath, &sipRes);

    return sipRes;
}

int sipVH_QtChart_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtChart_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneContextMenuEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneContextMenuEvent, SIP_NULLPTR);
}

void sipVH_QtChart_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneDragDropEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneDragDropEvent, SIP_NULLPTR);
}

void sipVH_QtChart_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtChart_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneHoverEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneHoverEvent, SIP_NULLPTR);
}

void sipVH_QtChart_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QInputMethodEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QInputMethodEvent, SIP_NULLPTR);
}

::QVariant sipVH_QtChart_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::InputMethodQuery a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_Qt_InputMethodQuery);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

::QVariant sipVH_QtChart_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsItem::GraphicsItemChange a0, const ::QVariant& a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FN", a0, sipType_QGraphicsItem_GraphicsItemChange, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_QtChart_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtChart_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneMouseEvent, SIP_NULLPTR);
}

bool sipVH_QtChart_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsItem*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QGraphicsItem, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtChart_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneWheelEvent, SIP_NULLPTR);
}

::QSizeF sipVH_QtChart_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::SizeHint a0, const ::QSizeF& a1)
{
    ::QSizeF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FN", a0, sipType_Qt_SizeHint, new ::QSizeF(a1), sipType_QSizeF, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSizeF, &sipRes);

    return sipRes;
}

void sipVH_QtChart_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::qreal*a0, ::qreal*a1, ::qreal*a2, ::qreal*a3)
{
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(dddd)", a0, a1, a2, a3);
}

void sipVH_QtChart_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRectF& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QRectF(a0), sipType_QRectF, SIP_NULLPTR);
}

void sipVH_QtChart_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDD", a0, sipType_QPainter, SIP_NULLPTR, const_cast< ::QStyleOptionGraphicsItem *>(a1), sipType_QStyleOptionGraphicsItem, SIP_NULLPTR, a2, sipType_QWidget, SIP_NULLPTR);
}

void sipVH_QtChart_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QStyleOption*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QStyleOption, SIP_NULLPTR);
}

::Qt::WindowFrameSection sipVH_QtChart_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF& a0)
{
    ::Qt::WindowFrameSection sipRes = ::Qt::NoSection;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPointF(a0), sipType_QPointF, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_Qt_WindowFrameSection, &sipRes);

    return sipRes;
}

void sipVH_QtChart_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCloseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QCloseEvent, SIP_NULLPTR);
}

bool sipVH_QtChart_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "b", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtChart_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtChart_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneMoveEvent, SIP_NULLPTR);
}

void sipVH_QtChart_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

void sipVH_QtChart_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneResizeEvent, SIP_NULLPTR);
}

void sipVH_QtChart_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

::Qt::Orientation sipVH_QtChart_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt::Orientation sipRes = ::Qt::Horizontal;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_Qt_Orientation, &sipRes);

    return sipRes;
}

::QtCharts::QCandlestickSeries* sipVH_QtChart_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QCandlestickSeries* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QtCharts_QCandlestickSeries, &sipRes);

    return sipRes;
}

::QtCharts::QBoxPlotSeries* sipVH_QtChart_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QBoxPlotSeries* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QtCharts_QBoxPlotSeries, &sipRes);

    return sipRes;
}

::QtCharts::QAbstractBarSeries* sipVH_QtChart_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QAbstractBarSeries* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QtCharts_QAbstractBarSeries, &sipRes);

    return sipRes;
}

::QtCharts::QAreaSeries* sipVH_QtChart_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QAreaSeries* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QtCharts_QAreaSeries, &sipRes);

    return sipRes;
}

::QtCharts::QAbstractSeries* sipVH_QtChart_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QAbstractSeries* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QtCharts_QAbstractSeries, &sipRes);

    return sipRes;
}

::QtCharts::QLegendMarker::LegendMarkerType sipVH_QtChart_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QLegendMarker::LegendMarkerType sipRes = ::QtCharts::QLegendMarker::LegendMarkerTypeArea;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QtCharts_QLegendMarker_LegendMarkerType, &sipRes);

    return sipRes;
}

::QtCharts::QAbstractSeries::SeriesType sipVH_QtChart_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QAbstractSeries::SeriesType sipRes = ::QtCharts::QAbstractSeries::SeriesTypeLine;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QtCharts_QAbstractSeries_SeriesType, &sipRes);

    return sipRes;
}

::QtCharts::QAbstractAxis::AxisType sipVH_QtChart_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtCharts::QAbstractAxis::AxisType sipRes = ::QtCharts::QAbstractAxis::AxisTypeNoAxis;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QtCharts_QAbstractAxis_AxisType, &sipRes);

    return sipRes;
}

bool sipVH_QtChart_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtChart_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtChart_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtChart_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtChart_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtChart_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QtCharts_QAbstractSeries(void **);}
static const sipTypeDef *sipSubClass_QtCharts_QAbstractSeries(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 66 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
static struct class_graph {
    const char *name;
    sipTypeDef **type;
    int yes, no;
} graph[] = {
    {sipName_QtCharts__QAbstractAxis, &sipType_QtCharts_QAbstractAxis, 19, 1},
    {sipName_QtCharts__QAbstractSeries, &sipType_QtCharts_QAbstractSeries, 24, 2},
    {sipName_QtCharts__QLegendMarker, &sipType_QtCharts_QLegendMarker, 39, 3},
    {sipName_QtCharts__QBarSet, &sipType_QtCharts_QBarSet, -1, 4},
    {sipName_QtCharts__QBoxSet, &sipType_QtCharts_QBoxSet, -1, 5},
#if QTCHARTS_VERSION >= 0x050800
    {sipName_QtCharts__QCandlestickModelMapper, &sipType_QtCharts_QCandlestickModelMapper, 45, 6},
#else
    {0, 0, 45, 6},
#endif
#if QTCHARTS_VERSION >= 0x050800
    {sipName_QtCharts__QCandlestickSet, &sipType_QtCharts_QCandlestickSet, -1, 7},
#else
    {0, 0, -1, 7},
#endif
    {sipName_QtCharts__QChart, &sipType_QtCharts_QChart, 47, 8},
    {sipName_QtCharts__QChartView, &sipType_QtCharts_QChartView, -1, 9},
    {sipName_QtCharts__QHBarModelMapper, &sipType_QtCharts_QHBarModelMapper, -1, 10},
#if QTCHARTS_VERSION >= 0x050800
    {sipName_QtCharts__QHBoxPlotModelMapper, &sipType_QtCharts_QHBoxPlotModelMapper, -1, 11},
#else
    {0, 0, -1, 11},
#endif
    {sipName_QtCharts__QHPieModelMapper, &sipType_QtCharts_QHPieModelMapper, -1, 12},
    {sipName_QtCharts__QHXYModelMapper, &sipType_QtCharts_QHXYModelMapper, -1, 13},
    {sipName_QtCharts__QLegend, &sipType_QtCharts_QLegend, -1, 14},
    {sipName_QtCharts__QPieSlice, &sipType_QtCharts_QPieSlice, -1, 15},
    {sipName_QtCharts__QVBarModelMapper, &sipType_QtCharts_QVBarModelMapper, -1, 16},
#if QTCHARTS_VERSION >= 0x050800
    {sipName_QtCharts__QVBoxPlotModelMapper, &sipType_QtCharts_QVBoxPlotModelMapper, -1, 17},
#else
    {0, 0, -1, 17},
#endif
    {sipName_QtCharts__QVPieModelMapper, &sipType_QtCharts_QVPieModelMapper, -1, 18},
    {sipName_QtCharts__QVXYModelMapper, &sipType_QtCharts_QVXYModelMapper, -1, -1},
    {sipName_QtCharts__QBarCategoryAxis, &sipType_QtCharts_QBarCategoryAxis, -1, 20},
    {sipName_QtCharts__QValueAxis, &sipType_QtCharts_QValueAxis, 23, 21},
    {sipName_QtCharts__QDateTimeAxis, &sipType_QtCharts_QDateTimeAxis, -1, 22},
    {sipName_QtCharts__QLogValueAxis, &sipType_QtCharts_QLogValueAxis, -1, -1},
    {sipName_QtCharts__QCategoryAxis, &sipType_QtCharts_QCategoryAxis, -1, -1},
    {sipName_QtCharts__QAbstractBarSeries, &sipType_QtCharts_QAbstractBarSeries, 30, 25},
    {sipName_QtCharts__QAreaSeries, &sipType_QtCharts_QAreaSeries, -1, 26},
    {sipName_QtCharts__QBoxPlotSeries, &sipType_QtCharts_QBoxPlotSeries, -1, 27},
#if QTCHARTS_VERSION >= 0x050800
    {sipName_QtCharts__QCandlestickSeries, &sipType_QtCharts_QCandlestickSeries, -1, 28},
#else
    {0, 0, -1, 28},
#endif
    {sipName_QtCharts__QXYSeries, &sipType_QtCharts_QXYSeries, 36, 29},
    {sipName_QtCharts__QPieSeries, &sipType_QtCharts_QPieSeries, -1, -1},
    {sipName_QtCharts__QBarSeries, &sipType_QtCharts_QBarSeries, -1, 31},
    {sipName_QtCharts__QHorizontalBarSeries, &sipType_QtCharts_QHorizontalBarSeries, -1, 32},
    {sipName_QtCharts__QHorizontalPercentBarSeries, &sipType_QtCharts_QHorizontalPercentBarSeries, -1, 33},
    {sipName_QtCharts__QHorizontalStackedBarSeries, &sipType_QtCharts_QHorizontalStackedBarSeries, -1, 34},
    {sipName_QtCharts__QPercentBarSeries, &sipType_QtCharts_QPercentBarSeries, -1, 35},
    {sipName_QtCharts__QStackedBarSeries, &sipType_QtCharts_QStackedBarSeries, -1, -1},
    {sipName_QtCharts__QLineSeries, &sipType_QtCharts_QLineSeries, 38, 37},
    {sipName_QtCharts__QScatterSeries, &sipType_QtCharts_QScatterSeries, -1, -1},
    {sipName_QtCharts__QSplineSeries, &sipType_QtCharts_QSplineSeries, -1, -1},
    {sipName_QtCharts__QAreaLegendMarker, &sipType_QtCharts_QAreaLegendMarker, -1, 40},
    {sipName_QtCharts__QBarLegendMarker, &sipType_QtCharts_QBarLegendMarker, -1, 41},
    {sipName_QtCharts__QBoxPlotLegendMarker, &sipType_QtCharts_QBoxPlotLegendMarker, -1, 42},
#if QTCHARTS_VERSION >= 0x050800
    {sipName_QtCharts__QCandlestickLegendMarker, &sipType_QtCharts_QCandlestickLegendMarker, -1, 43},
#else
    {0, 0, -1, 43},
#endif
    {sipName_QtCharts__QPieLegendMarker, &sipType_QtCharts_QPieLegendMarker, -1, 44},
    {sipName_QtCharts__QXYLegendMarker, &sipType_QtCharts_QXYLegendMarker, -1, -1},
#if QTCHARTS_VERSION >= 0x050800
    {sipName_QtCharts__QHCandlestickModelMapper, &sipType_QtCharts_QHCandlestickModelMapper, -1, 46},
#else
    {0, 0, -1, 46},
#endif
#if QTCHARTS_VERSION >= 0x050800
    {sipName_QtCharts__QVCandlestickModelMapper, &sipType_QtCharts_QVCandlestickModelMapper, -1, -1},
#else
    {0, 0, -1, -1},
#endif
    {sipName_QtCharts__QPolarChart, &sipType_QtCharts_QPolarChart, -1, -1},
};

int i = 0;

sipType = NULL;

do
{
    struct class_graph *cg = &graph[i];

    if (cg->name != NULL && sipCpp->inherits(cg->name))
    {
        sipType = *cg->type;
        i = cg->yes;
    }
    else
        i = cg->no;
}
while (i >= 0);
#line 3905 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartcmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QtCharts_QChart_AnimationOption___or__(PyObject *, PyObject *);}
static PyObject *slot_QtCharts_QChart_AnimationOption___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QChart::AnimationOption a0;
        ::QtCharts::QChart::AnimationOption a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EE", sipType_QtCharts_QChart_AnimationOption, &a0, sipType_QtCharts_QChart_AnimationOption, &a1))
        {
            ::QtCharts::QChart::AnimationOptions*sipRes;

            sipRes = new ::QtCharts::QChart::AnimationOptions((a0 | a1));

            return sipConvertFromNewType(sipRes, sipType_QtCharts_QChart_AnimationOptions, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QtCharts_QChart_AnimationOption[] = {
    {(void *)slot_QtCharts_QChart_AnimationOption___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QAbstractAxis__AxisType, SIP_NULLPTR, 0}, sipNameNr_AxisType, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QAbstractBarSeries__LabelsPosition, SIP_NULLPTR, 0}, sipNameNr_LabelsPosition, 11, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QAbstractSeries__SeriesType, SIP_NULLPTR, 0}, sipNameNr_SeriesType, 13, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QBoxSet__ValuePositions, SIP_NULLPTR, 0}, sipNameNr_ValuePositions, 23, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QCategoryAxis__AxisLabelsPosition, SIP_NULLPTR, 0}, sipNameNr_AxisLabelsPosition, 29, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QChart__AnimationOption, SIP_NULLPTR, 0}, sipNameNr_AnimationOption, 31, slots_QtCharts_QChart_AnimationOption},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QChart__ChartTheme, SIP_NULLPTR, 0}, sipNameNr_ChartTheme, 31, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QChart__ChartType, SIP_NULLPTR, 0}, sipNameNr_ChartType, 31, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QChartView__RubberBand, SIP_NULLPTR, 0}, sipNameNr_RubberBand, 36, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QLegend__MarkerShape, SIP_NULLPTR, 0}, sipNameNr_MarkerShape, 48, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QLegendMarker__LegendMarkerType, SIP_NULLPTR, 0}, sipNameNr_LegendMarkerType, 50, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QPieSlice__LabelPosition, SIP_NULLPTR, 0}, sipNameNr_LabelPosition, 57, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QPolarChart__PolarOrientation, SIP_NULLPTR, 0}, sipNameNr_PolarOrientation, 59, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QScatterSeries__MarkerShape, SIP_NULLPTR, 0}, sipNameNr_MarkerShape, 62, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtCharts__QValueAxis__TickType, SIP_NULLPTR, 0}, sipNameNr_TickType, 71, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtChart[] = {
    &sipTypeDef_QtChart_QList_0100QPointF.mtd_base,
    &sipTypeDef_QtChart_QList_0101QtCharts_QAbstractAxis.mtd_base,
    &sipTypeDef_QtChart_QList_0101QtCharts_QAbstractSeries.mtd_base,
    &sipTypeDef_QtChart_QList_0101QtCharts_QBarSet.mtd_base,
    &sipTypeDef_QtChart_QList_0101QtCharts_QBoxSet.mtd_base,
    &sipTypeDef_QtChart_QList_0101QtCharts_QCandlestickSet.mtd_base,
    &sipTypeDef_QtChart_QList_0101QtCharts_QLegendMarker.mtd_base,
    &sipTypeDef_QtChart_QList_0101QtCharts_QPieSlice.mtd_base,
    &sipTypeDef_QtChart_QtCharts_QAbstractAxis.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtChart_QtCharts_QAbstractAxis_AxisTypes.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QAbstractBarSeries.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtChart_QtCharts_QAbstractSeries.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtChart_QtCharts_QAreaLegendMarker.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QAreaSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QBarCategoryAxis.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QBarLegendMarker.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QBarSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QBarSet.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QBoxPlotLegendMarker.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QBoxPlotSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QBoxSet.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtChart_QtCharts_QCandlestickLegendMarker.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QCandlestickModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QCandlestickSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QCandlestickSet.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QCategoryAxis.ctd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtChart_QtCharts_QChart.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_QtChart_QtCharts_QChart_AnimationOptions.ctd_base,
    &enumTypes[6].etd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtChart_QtCharts_QChartView.ctd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtChart_QtCharts_QChartView_RubberBands.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QDateTimeAxis.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QHBarModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QHBoxPlotModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QHCandlestickModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QHPieModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QHXYModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QHorizontalBarSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QHorizontalPercentBarSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QHorizontalStackedBarSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QLegend.ctd_base,
    &enumTypes[9].etd_base,
    &sipTypeDef_QtChart_QtCharts_QLegendMarker.ctd_base,
    &enumTypes[10].etd_base,
    &sipTypeDef_QtChart_QtCharts_QLineSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QLogValueAxis.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QPercentBarSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QPieLegendMarker.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QPieSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QPieSlice.ctd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtChart_QtCharts_QPolarChart.ctd_base,
    &enumTypes[12].etd_base,
    &sipTypeDef_QtChart_QtCharts_QPolarChart_PolarOrientations.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QScatterSeries.ctd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtChart_QtCharts_QSplineSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QStackedBarSeries.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QVBarModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QVBoxPlotModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QVCandlestickModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QVPieModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QVXYModelMapper.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QValueAxis.ctd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtChart_QtCharts_QXYLegendMarker.ctd_base,
    &sipTypeDef_QtChart_QtCharts_QXYSeries.ctd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtChart_QtCore[] = {
    {"QAbstractItemModel"},
    {"QByteArray"},
    {"QChildEvent"},
    {"QDateTime"},
    {"QEasingCurve"},
    {"QEvent"},
    {"QList<qreal>"},
    {"QLocale"},
    {"QMargins"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPointF"},
    {"QRectF"},
    {"QSize"},
    {"QSizeF"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QVariant"},
    {"QVector<QPointF>"},
    {"Qt::Alignment"},
    {"Qt::InputMethodQuery"},
    {"Qt::ItemSelectionMode"},
    {"Qt::Orientation"},
    {"Qt::Orientations"},
    {"Qt::SizeHint"},
    {"Qt::WindowFlags"},
    {"Qt::WindowFrameSection"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtChart_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtChart_QtGui[] = {
    {"QActionEvent"},
    {"QBrush"},
    {"QCloseEvent"},
    {"QColor"},
    {"QContextMenuEvent"},
    {"QDragEnterEvent"},
    {"QDragLeaveEvent"},
    {"QDragMoveEvent"},
    {"QDropEvent"},
    {"QFocusEvent"},
    {"QFont"},
    {"QHideEvent"},
    {"QInputMethodEvent"},
    {"QKeyEvent"},
    {"QMouseEvent"},
    {"QMoveEvent"},
    {"QPaintDevice"},
    {"QPaintDevice::PaintDeviceMetric"},
    {"QPaintEngine"},
    {"QPaintEvent"},
    {"QPainter"},
    {"QPainterPath"},
    {"QPen"},
    {"QResizeEvent"},
    {"QShowEvent"},
    {"QTabletEvent"},
    {"QWheelEvent"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtWidgets. */
sipImportedTypeDef sipImportedTypes_QtChart_QtWidgets[] = {
    {"QAbstractScrollArea"},
    {"QFrame"},
    {"QGraphicsItem"},
    {"QGraphicsItem::GraphicsItemChange"},
    {"QGraphicsLayoutItem"},
    {"QGraphicsObject"},
    {"QGraphicsSceneContextMenuEvent"},
    {"QGraphicsSceneDragDropEvent"},
    {"QGraphicsSceneHoverEvent"},
    {"QGraphicsSceneMouseEvent"},
    {"QGraphicsSceneMoveEvent"},
    {"QGraphicsSceneResizeEvent"},
    {"QGraphicsSceneWheelEvent"},
    {"QGraphicsView"},
    {"QGraphicsWidget"},
    {"QStyleOption"},
    {"QStyleOptionGraphicsItem"},
    {"QWidget"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtChart_QtCore, sipImportedVirtErrorHandlers_QtChart_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtChart_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtWidgets", sipImportedTypes_QtChart_QtWidgets, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QtCharts_QAbstractSeries, {10, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* Define the strings to be added to this module dictionary. */
static sipStringInstanceDef stringInstances[] = {
    {sipName_PYQT_CHART_VERSION_STR, PYQT_CHART_VERSION_STR, 'A'},
    {0, 0, 0}
};


/* Define the enum members and ints to be added to this module. */
static sipIntInstanceDef intInstances[] = {
    {sipName_PYQT_CHART_VERSION, PYQT_CHART_VERSION},
    {0, 0}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtChart = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtChart,
    0,
    sipStrings_QtChart,
    importsTable,
    SIP_NULLPTR,
    75,
    sipExportedTypes_QtChart,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, stringInstances, intInstances, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtChart;

sip_qt_metaobject_func sip_QtChart_qt_metaobject;
sip_qt_metacall_func sip_QtChart_qt_metacall;
sip_qt_metacast_func sip_QtChart_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtChart()
#else
PyMODINIT_FUNC PyInit_QtChart()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtChart",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtChart = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtChart == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtChart, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtChart_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtChart_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtChart_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtChart_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtChart, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
